import * as React from 'react';
import { IgrGridActionsBaseDirectiveCollection } from "./igr-grid-actions-base-directive-collection";
import { IgrDisplayDensityBaseElement } from "./igr-display-density-base-element";
import { ActionStrip } from "./ActionStrip";
import { ContentChildrenManager } from "igniteui-react-core";
import { CollectionAdapter, ensureBool, interfaceToInternal } from "igniteui-react-core";
import { GridActionsBaseDirective } from "./GridActionsBaseDirective";
import { NotifyCollectionChangedAction } from "igniteui-react-core";
import { ActionStripResourceStrings } from "./ActionStripResourceStrings";
export class IgrActionStrip extends IgrDisplayDensityBaseElement {
    createImplementation() {
        let impl = new ActionStrip();
        let nat;
        if (typeof document !== 'undefined') {
            nat = document.createElement("igc-action-strip");
        }
        else {
            nat = {
                style: {}
            };
        }
        impl.setNativeElement(nat);
        return impl;
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
        super.onImplementationCreated();
        this._portalManager.getPortal(this._renderer.getWrapper(this._implementation.nativeElement), "ChildContent", (p) => { }, true);
    }
    _initializeAdapters() {
        if (!this._contentChildrenManager) {
            const resolveNested = ((props, propName, nestedPropName) => {
                var _a;
                const prop = props[propName];
                if (Array.isArray(prop)) {
                    return prop.map(x => {
                        var _a;
                        return (_a = x[nestedPropName]) !== null && _a !== void 0 ? _a : resolveNested(x.props, propName, nestedPropName);
                    }).join("_");
                }
                else if (prop) {
                    return (_a = prop.props[nestedPropName]) !== null && _a !== void 0 ? _a : resolveNested(prop.props, propName, nestedPropName);
                }
                else {
                    return props[nestedPropName];
                }
            });
            this._contentChildrenManager = new ContentChildrenManager((ch) => {
                const key = ch.key || ch.props.name;
                if (!key) {
                    const type = (ch.type);
                    const instance = new type;
                    const name = instance.i.$type.name;
                    switch (name) {
                        case "GridEditingActions": return "IgrGridEditingActions";
                        case "GridPinningActions": return "IgrGridPinningActions";
                        default: return undefined;
                    }
                }
                return key;
            }, (ch) => {
                const key = ch.key || ch.props.name;
                if (!key) {
                    const type = (ch.type);
                    const instance = new type;
                    const name = instance.i.$type.name;
                    switch (name) {
                        case "GridEditingActions": return "IgrGridEditingActions";
                        case "GridPinningActions": return "IgrGridPinningActions";
                        default: return undefined;
                    }
                }
                return key;
            }, () => {
                if (this._updateContentChildren) {
                    this._updateContentChildren();
                }
                else if (this._updateAdapters) {
                    this._updateAdapters();
                }
            });
        }
        this._actionButtonsAdapter = new CollectionAdapter(this.contentActionButtons, this.i.j, this.actualActionButtons, (c) => c.i, (i) => {
            if (this._initializeElement) {
                this._initializeElement(i);
            }
        }, (i) => {
            if (this._destroyElement) {
                this._destroyElement(i);
            }
        });
        if (super["_initializeAdapters"]) {
            super["_initializeAdapters"]();
        }
    }
    _updateAdapters() {
        if (super["_updateAdapters"]) {
            super["_updateAdapters"]();
        }
        let contentChildrenActual = this._contentChildrenManager.contentChildrenActual;
        this.contentActionButtons.length = 0;
        for (var i = 0; i < contentChildrenActual.length; i++) {
            if ((GridActionsBaseDirective.$type).isAssignableFrom(contentChildrenActual[i].i.$type)) {
                this.contentActionButtons.push(contentChildrenActual[i]);
            }
        }
        if (this._actionButtonsAdapter != null) {
            this._actionButtonsAdapter.notifyContentChanged();
        }
    }
    constructor(props) {
        super(props);
        this._actionButtons = null;
        this._getMainRef = this._getMainRef.bind(this);
    }
    componentDidMount() {
        this.mounted = true;
        super.componentDidMount();
    }
    render() {
        let children = this._contentChildrenManager.getChildren(this.props.children);
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("div", {
            ref: this._getMainRef,
            id: this.props.id,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    get actualActionButtons() {
        if (!this._actualActionButtons) {
            this._actualActionButtons = [];
        }
        return this._actualActionButtons;
    }
    get contentActionButtons() {
        if (!this._contentActionButtons) {
            this._contentActionButtons = [];
        }
        return this._contentActionButtons;
    }
    /**
     * ActionButton as ContentChildren inside the Action Strip
     * @hidden
     * @internal
    */
    get actionButtons() {
        if (this._actionButtons === null) {
            let coll = new IgrGridActionsBaseDirectiveCollection();
            let inner = coll._innerColl;
            this._actionButtons = coll;
            inner.addListener((sender, e) => {
                switch (e.action) {
                    case NotifyCollectionChangedAction.Add:
                        this._actionButtonsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                        break;
                    case NotifyCollectionChangedAction.Remove:
                        this._actionButtonsAdapter.removeManualItemAt(e.oldStartingIndex);
                        break;
                    case NotifyCollectionChangedAction.Replace:
                        this._actionButtonsAdapter.removeManualItemAt(e.oldStartingIndex);
                        this._actionButtonsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                        break;
                    case NotifyCollectionChangedAction.Reset:
                        this._actionButtonsAdapter.clearManualItems();
                        break;
                }
            });
            ;
        }
        return this._actionButtons;
    }
    get hidden() {
        return this.i.k;
    }
    set hidden(v) {
        this.i.k = ensureBool(v);
    }
    /**
     * Gets/Sets the resource strings.
     * @remarks
     * By default it uses EN resources.
    */
    get resourceStrings() {
        return this.i.i.nativeElement;
    }
    set resourceStrings(v) {
        this.i.i = interfaceToInternal(v, () => new ActionStripResourceStrings());
    }
    get name() {
        return this.i.l;
    }
    set name(v) {
        this.i.l = v;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.actionButtons != null && this.actionButtons.findByName && this.actionButtons.findByName(name)) {
            return this.actionButtons.findByName(name);
        }
        if (this.resourceStrings && this.resourceStrings.name && this.resourceStrings.name == name) {
            return this.resourceStrings;
        }
        return null;
    }
    /**
     * Showing the Action Strip and appending it the specified context element.
     * context
     * @example
     * ```typescript
     * this.actionStrip.show(row);
     * ```
    
    * @param   * context
    */
    show(context) {
        this.i.n(context);
    }
    /**
     * Hiding the Action Strip and removing it from its current context element.
     * @example
     * ```typescript
     * this.actionStrip.hide();
     * ```
    
    */
    hide() {
        this.i.m();
    }
}
