import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrBaseEventArgs } from "./igr-base-event-args";
import { IgrRowExportingEventArgs } from "./igr-row-exporting-event-args";
import { IgrColumnExportingEventArgs } from "./igr-column-exporting-event-args";
import { TypeRegistrar } from "igniteui-react-core";
export class IgrBaseExporter {
    createImplementation() {
        return null;
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    constructor() {
        this.mounted = false;
        this._exportEnded = null;
        this._exportEnded_wrapped = null;
        this._rowExporting = null;
        this._rowExporting_wrapped = null;
        this._columnExporting = null;
        this._columnExporting_wrapped = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
    exportGrid(grid, options) {
        this.i.l(grid, (options == null ? null : options.i));
    }
    exportData(data, options) {
        this.i.j(data, (options == null ? null : options.i));
    }
    addPivotGridColumns(grid) {
        this.i.h(grid);
    }
    get exportEnded() {
        return this._exportEnded;
    }
    set exportEnded(ev) {
        if (this._exportEnded_wrapped !== null) {
            this.i.exportEnded = delegateRemove(this.i.exportEnded, this._exportEnded_wrapped);
            this._exportEnded_wrapped = null;
            this._exportEnded = null;
        }
        this._exportEnded = ev;
        this._exportEnded_wrapped = (o, e) => {
            let outerArgs = new IgrBaseEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeExportEnded) {
                this.beforeExportEnded(this, outerArgs);
            }
            if (this._exportEnded) {
                this._exportEnded(this, outerArgs);
            }
        };
        this.i.exportEnded = delegateCombine(this.i.exportEnded, this._exportEnded_wrapped);
        ;
    }
    /**
     * This event is emitted when a row is exported.
     * ```typescript
     * this.exporterService.rowExporting.subscribe((args: IRowExportingEventArgs) => {
     * // put event handler code here
     * });
     * ```
     * @memberof IgxBaseExporter
    */
    get rowExporting() {
        return this._rowExporting;
    }
    set rowExporting(ev) {
        if (this._rowExporting_wrapped !== null) {
            this.i.rowExporting = delegateRemove(this.i.rowExporting, this._rowExporting_wrapped);
            this._rowExporting_wrapped = null;
            this._rowExporting = null;
        }
        this._rowExporting = ev;
        this._rowExporting_wrapped = (o, e) => {
            let outerArgs = new IgrRowExportingEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeRowExporting) {
                this.beforeRowExporting(this, outerArgs);
            }
            if (this._rowExporting) {
                this._rowExporting(this, outerArgs);
            }
        };
        this.i.rowExporting = delegateCombine(this.i.rowExporting, this._rowExporting_wrapped);
        ;
    }
    /**
     * This event is emitted when a column is exported.
     * ```typescript
     * this.exporterService.columnExporting.subscribe((args: IColumnExportingEventArgs) => {
     * // put event handler code here
     * });
     * ```
     * @memberof IgxBaseExporter
    */
    get columnExporting() {
        return this._columnExporting;
    }
    set columnExporting(ev) {
        if (this._columnExporting_wrapped !== null) {
            this.i.columnExporting = delegateRemove(this.i.columnExporting, this._columnExporting_wrapped);
            this._columnExporting_wrapped = null;
            this._columnExporting = null;
        }
        this._columnExporting = ev;
        this._columnExporting_wrapped = (o, e) => {
            let outerArgs = new IgrColumnExportingEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeColumnExporting) {
                this.beforeColumnExporting(this, outerArgs);
            }
            if (this._columnExporting) {
                this._columnExporting(this, outerArgs);
            }
        };
        this.i.columnExporting = delegateCombine(this.i.columnExporting, this._columnExporting_wrapped);
        ;
    }
}
