import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrToggleViewCancelableEventArgs } from "./igr-toggle-view-cancelable-event-args";
import { IgrToggleViewEventArgs } from "./igr-toggle-view-event-args";
import { IgrColumnToggledEventArgs } from "./igr-column-toggled-event-args";
import { IgrGridToolbarBaseAction } from "./igr-grid-toolbar-base-action";
import { interfaceToInternal } from "igniteui-react-core";
import { OverlaySettings } from "./OverlaySettings";
/**
 * Base class for the pinning/hiding column and exporter actions.
 * @hidden @internal
*/
export class IgrBaseToolbarDirective extends IgrGridToolbarBaseAction {
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._opening = null;
        this._opening_wrapped = null;
        this._opened = null;
        this._opened_wrapped = null;
        this._closing = null;
        this._closing_wrapped = null;
        this._closed = null;
        this._closed_wrapped = null;
        this._columnToggle = null;
        this._columnToggle_wrapped = null;
    }
    /**
     * Sets the height of the column list in the dropdown.
    */
    get columnListHeight() {
        return this.i.l;
    }
    set columnListHeight(v) {
        this.i.l = v;
    }
    /**
     * Title text for the column action component
    */
    get title() {
        return this.i.n;
    }
    set title(v) {
        this.i.n = v;
    }
    /**
     * The placeholder text for the search input.
    */
    get prompt() {
        return this.i.m;
    }
    set prompt(v) {
        this.i.m = v;
    }
    /**
     * Sets overlay settings
    */
    get overlaySettings() {
        return this.i.c.nativeElement;
    }
    set overlaySettings(v) {
        this.i.c = interfaceToInternal(v, () => new OverlaySettings());
    }
    get name() {
        return this.i.a;
    }
    set name(v) {
        this.i.a = v;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.overlaySettings && this.overlaySettings.name && this.overlaySettings.name == name) {
            return this.overlaySettings;
        }
        return null;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
    /**
     * Emits an event before the toggle container is opened.
    */
    get opening() {
        return this._opening;
    }
    set opening(ev) {
        if (this._opening_wrapped !== null) {
            this.i.opening = delegateRemove(this.i.opening, this._opening_wrapped);
            this._opening_wrapped = null;
            this._opening = null;
        }
        this._opening = ev;
        this._opening_wrapped = (o, e) => {
            let outerArgs = new IgrToggleViewCancelableEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeOpening) {
                this.beforeOpening(this, outerArgs);
            }
            if (this._opening) {
                this._opening(this, outerArgs);
            }
        };
        this.i.opening = delegateCombine(this.i.opening, this._opening_wrapped);
        if (this.i.openingChanged) {
            this.i.openingChanged();
        }
        ;
    }
    /**
     * Emits an event after the toggle container is opened.
    */
    get opened() {
        return this._opened;
    }
    set opened(ev) {
        if (this._opened_wrapped !== null) {
            this.i.opened = delegateRemove(this.i.opened, this._opened_wrapped);
            this._opened_wrapped = null;
            this._opened = null;
        }
        this._opened = ev;
        this._opened_wrapped = (o, e) => {
            let outerArgs = new IgrToggleViewEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeOpened) {
                this.beforeOpened(this, outerArgs);
            }
            if (this._opened) {
                this._opened(this, outerArgs);
            }
        };
        this.i.opened = delegateCombine(this.i.opened, this._opened_wrapped);
        if (this.i.openedChanged) {
            this.i.openedChanged();
        }
        ;
    }
    /**
     * Emits an event before the toggle container is closed.
    */
    get closing() {
        return this._closing;
    }
    set closing(ev) {
        if (this._closing_wrapped !== null) {
            this.i.closing = delegateRemove(this.i.closing, this._closing_wrapped);
            this._closing_wrapped = null;
            this._closing = null;
        }
        this._closing = ev;
        this._closing_wrapped = (o, e) => {
            let outerArgs = new IgrToggleViewEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeClosing) {
                this.beforeClosing(this, outerArgs);
            }
            if (this._closing) {
                this._closing(this, outerArgs);
            }
        };
        this.i.closing = delegateCombine(this.i.closing, this._closing_wrapped);
        if (this.i.closingChanged) {
            this.i.closingChanged();
        }
        ;
    }
    /**
     * Emits an event after the toggle container is closed.
    */
    get closed() {
        return this._closed;
    }
    set closed(ev) {
        if (this._closed_wrapped !== null) {
            this.i.closed = delegateRemove(this.i.closed, this._closed_wrapped);
            this._closed_wrapped = null;
            this._closed = null;
        }
        this._closed = ev;
        this._closed_wrapped = (o, e) => {
            let outerArgs = new IgrToggleViewEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeClosed) {
                this.beforeClosed(this, outerArgs);
            }
            if (this._closed) {
                this._closed(this, outerArgs);
            }
        };
        this.i.closed = delegateCombine(this.i.closed, this._closed_wrapped);
        if (this.i.closedChanged) {
            this.i.closedChanged();
        }
        ;
    }
    /**
     * Emits when after a column's checked state is changed
    */
    get columnToggle() {
        return this._columnToggle;
    }
    set columnToggle(ev) {
        if (this._columnToggle_wrapped !== null) {
            this.i.columnToggle = delegateRemove(this.i.columnToggle, this._columnToggle_wrapped);
            this._columnToggle_wrapped = null;
            this._columnToggle = null;
        }
        this._columnToggle = ev;
        this._columnToggle_wrapped = (o, e) => {
            let outerArgs = new IgrColumnToggledEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeColumnToggle) {
                this.beforeColumnToggle(this, outerArgs);
            }
            if (this._columnToggle) {
                this._columnToggle(this, outerArgs);
            }
        };
        this.i.columnToggle = delegateCombine(this.i.columnToggle, this._columnToggle_wrapped);
        if (this.i.columnToggleChanged) {
            this.i.columnToggleChanged();
        }
        ;
    }
}
