import { CellContentHorizontalAlignment, CellContentHorizontalAlignment_$type } from "./CellContentHorizontalAlignment";
import { CellContentVerticalAlignment_$type } from "./CellContentVerticalAlignment";
import { TextCellLineBreakMode_$type } from "./TextCellLineBreakMode";
import { ColumnSortDirection_$type } from "./ColumnSortDirection";
import { ensureBool, ensureEnum, brushToString, stringToBrush } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { delegateCombine, delegateRemove, runOn } from "igniteui-react-core";
import { PinnedPositions_$type } from './PinnedPositions';
/**
 * Represents info about the current cell.
*/
export class IgrCellInfo {
    createImplementation() {
        return null;
    }
    get i() {
        return this._implementation;
    }
    constructor() {
        this._onChanged = [];
        this._changed = false;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    onImplementationCreated() {
    }
    addOnChangedListener(listener) {
        if (this._onChanged.length == 0) {
            this.i.propertyChanged = delegateCombine(this.i.propertyChanged, runOn(this, this._implementation_propertyChanged));
            this.i.cellReconciling = delegateCombine(this.i.cellReconciling, runOn(this, this._implementation_cellReconciling));
        }
        this._onChanged.push(listener);
    }
    removeOnChangedListener(listener) {
        let ind = this._onChanged.indexOf(listener);
        if (ind < 0) {
            return;
        }
        this._onChanged.splice(ind, 1);
        if (this._onChanged.length == 0) {
            this.i.propertyChanged = delegateRemove(this.i.propertyChanged, runOn(this, this._implementation_propertyChanged));
            this.i.cellReconciling = delegateRemove(this.i.cellReconciling, runOn(this, this._implementation_cellReconciling));
        }
    }
    _implementation_propertyChanged(sender, args) {
        this._changed = true;
    }
    _implementation_cellReconciling(model) {
        if (this._changed && this._onChanged !== null && this._onChanged.length > 0) {
            this._changed = false;
            for (let i = 0; i < this._onChanged.length; i++) {
                this._onChanged[i]();
            }
        }
        this._changed = false;
    }
    get resolvedTextAlign() {
        switch (this.horizontalAlignment) {
            case CellContentHorizontalAlignment.Center:
                return "center";
            case CellContentHorizontalAlignment.Left:
                return "left";
            case CellContentHorizontalAlignment.Right:
                return "right";
            case CellContentHorizontalAlignment.Stretch:
                return "center";
        }
        return "left";
    }
    get resolvedContentOpacity() {
        let virtualPercent = Math.min(1.0, Math.max(0.0, this.virtualizationPercentage));
        let opacity = this.contentOpacity * (1.0 - virtualPercent);
        return opacity;
    }
    /**
 * Gets the style key of the current cell, used for recycling.
*/
    get styleKey() {
        return this.i.jm;
    }
    set styleKey(v) {
        this.i.jm = v;
    }
    /**
     * Gets the absolute data row for the current cell.
    */
    get dataRow() {
        return this.i.et;
    }
    set dataRow(v) {
        this.i.et = +v;
    }
    /**
     * Gets if the position of the cell is dirty.
    */
    get isPositionDirty() {
        return this.i.be;
    }
    set isPositionDirty(v) {
        this.i.be = ensureBool(v);
    }
    /**
     * Gets if the size of the cell is dirty.
    */
    get isSizeDirty() {
        return this.i.bj;
    }
    set isSizeDirty(v) {
        this.i.bj = ensureBool(v);
    }
    /**
     * Gets if the content of the cell is dirty.
    */
    get isContentDirty() {
        return this.i.ay;
    }
    set isContentDirty(v) {
        this.i.ay = ensureBool(v);
    }
    /**
     * Gets if the content of the cell is dirty.
    */
    get isBorderDirty() {
        return this.i.aw;
    }
    set isBorderDirty(v) {
        this.i.aw = ensureBool(v);
    }
    /**
     * Gets if the layer of the cell is dirty.
    */
    get isLayerDirty() {
        return this.i.bc;
    }
    set isLayerDirty(v) {
        this.i.bc = ensureBool(v);
    }
    /**
     * Gets if the layer of the cell is dirty.
    */
    get isStateDirty() {
        return this.i.bk;
    }
    set isStateDirty(v) {
        this.i.bk = ensureBool(v);
    }
    /**
     * Gets if the data of the cell is dirty.
    */
    get isDataDirty() {
        return this.i.a0;
    }
    set isDataDirty(v) {
        this.i.a0 = ensureBool(v);
    }
    /**
     * Gets if placeholder content is needed when virtualized.
    */
    get isPlaceholdContentNeeded() {
        return this.i.bd;
    }
    set isPlaceholdContentNeeded(v) {
        this.i.bd = ensureBool(v);
    }
    /**
     * Gets the action manager to propagate actions back to the grid.
    */
    get actionManager() {
        return this.i.c;
    }
    set actionManager(v) {
        this.i.c = v;
    }
    /**
     * Gets or sets whether the cell is hit test visible.
    */
    get isHitTestVisible() {
        return this.i.a8;
    }
    set isHitTestVisible(v) {
        this.i.a8 = ensureBool(v);
    }
    /**
     * Gets if this cell belongs to a row that has been marked as pinned.
    */
    get isRowPinned() {
        return this.i.bf;
    }
    set isRowPinned(v) {
        this.i.bf = ensureBool(v);
    }
    /**
     * Gets if this cell belongs to a row that will stick to the top of the grid.
    */
    get isRowSticky() {
        return this.i.bg;
    }
    set isRowSticky(v) {
        this.i.bg = ensureBool(v);
    }
    /**
     * Gets if this cell is the last row that can stick to the top of the grid.
    */
    get isLastStickyRow() {
        return this.i.bb;
    }
    set isLastStickyRow(v) {
        this.i.bb = ensureBool(v);
    }
    /**
     * Gets if this cell is in the filter row.
    */
    get isFilterRow() {
        return this.i.a6;
    }
    set isFilterRow(v) {
        this.i.a6 = ensureBool(v);
    }
    /**
     * Gets the indent level of the cell.
    */
    get indent() {
        return this.i.fi;
    }
    set indent(v) {
        this.i.fi = +v;
    }
    get rowItem() {
        return this.i.g4;
    }
    set rowItem(v) {
        this.i.g4 = v;
    }
    /**
     * Gets the X position of the cell within the content.
    */
    get x() {
        return this.i.cl;
    }
    set x(v) {
        this.i.cl = +v;
    }
    /**
     * Gets the Y position of the cell within the content.
    */
    get y() {
        return this.i.cm;
    }
    set y(v) {
        this.i.cm = +v;
    }
    /**
     * Gets the pixel snapped X position of the cell within the content.
    */
    get snappedX() {
        return this.i.gh;
    }
    set snappedX(v) {
        this.i.gh = +v;
    }
    /**
     * Gets the snapped Y position of the cell within the content.
    */
    get snappedY() {
        return this.i.gj;
    }
    set snappedY(v) {
        this.i.gj = +v;
    }
    /**
     * Gets or sets the opacity for cells that have unsaved edits.
    */
    get editOpacity() {
        return this.i.cb;
    }
    set editOpacity(v) {
        this.i.cb = +v;
    }
    /**
     * Gets or sets the opacity of the content of the cell.
    */
    get contentOpacity() {
        return this.i.ca;
    }
    set contentOpacity(v) {
        this.i.ca = +v;
    }
    /**
     * Gets the actual content opacity of the cell.
    */
    get actualContentOpacity() {
        return this.i.b8;
    }
    set actualContentOpacity(v) {
        this.i.b8 = +v;
    }
    /**
     * Gets or sets the opacity of the cell.
    */
    get opacity() {
        return this.i.cf;
    }
    set opacity(v) {
        this.i.cf = +v;
    }
    /**
     * Gets the actual opacity of the cell.
    */
    get actualOpacity() {
        return this.i.b9;
    }
    set actualOpacity(v) {
        this.i.b9 = +v;
    }
    /**
     * Gets the height of the cell.
    */
    get height() {
        return this.i.fc;
    }
    set height(v) {
        this.i.fc = +v;
    }
    /**
     * Gets the width of the cell.
    */
    get width() {
        return this.i.gu;
    }
    set width(v) {
        this.i.gu = +v;
    }
    /**
     * Gets if the cell is selected.
    */
    get isSelected() {
        return this.i.bi;
    }
    set isSelected(v) {
        this.i.bi = ensureBool(v);
    }
    /**
     * Gets the amount that the cell is selected. This is a value between 0 and 1.
    */
    get selectedStatus() {
        return this.i.ch;
    }
    set selectedStatus(v) {
        this.i.ch = +v;
    }
    /**
     * Gets the amount that the cell is activated. This is a value between 0 and 1.
    */
    get activationStatus() {
        return this.i.b7;
    }
    set activationStatus(v) {
        this.i.b7 = +v;
    }
    /**
     * Gets the amount that the cell is hovered. This is a value between 0 and 1.
    */
    get hoverStatus() {
        return this.i.cc;
    }
    set hoverStatus(v) {
        this.i.cc = +v;
    }
    /**
     * Gets whether the cell is hoverable or not.
    */
    get isHoverable() {
        return this.i.a9;
    }
    set isHoverable(v) {
        this.i.a9 = ensureBool(v);
    }
    /**
     * Gets or sets the horiztonal alignment of the cell content.
    */
    get horizontalAlignment() {
        return this.i.g;
    }
    set horizontalAlignment(v) {
        this.i.g = ensureEnum(CellContentHorizontalAlignment_$type, v);
    }
    /**
     * Gets or sets the vertical alignment of the cell content.
    */
    get verticalAlignment() {
        return this.i.i;
    }
    set verticalAlignment(v) {
        this.i.i = ensureEnum(CellContentVerticalAlignment_$type, v);
    }
    /**
     * Gets or sets the background color of the cell.
    */
    get background() {
        return brushToString(this.i.k3);
    }
    set background(v) {
        this.i.k3 = stringToBrush(v);
    }
    /**
     * Gets or sets the border color of the cell.
    */
    get border() {
        return brushToString(this.i.k4);
    }
    set border(v) {
        this.i.k4 = stringToBrush(v);
    }
    /**
     * Gets the actual background color of the cell
    */
    get actualBackground() {
        return brushToString(this.i.k0);
    }
    set actualBackground(v) {
        this.i.k0 = stringToBrush(v);
    }
    /**
     * Gets the actual background color of the cell
    */
    get actualBorder() {
        return brushToString(this.i.k1);
    }
    set actualBorder(v) {
        this.i.k1 = stringToBrush(v);
    }
    /**
     * Gets the actual background color of the cell
    */
    get activationBorder() {
        return brushToString(this.i.kz);
    }
    set activationBorder(v) {
        this.i.kz = stringToBrush(v);
    }
    /**
     * Gets or sets the error border color of the cell.
    */
    get errorBorder() {
        return brushToString(this.i.k6);
    }
    set errorBorder(v) {
        this.i.k6 = stringToBrush(v);
    }
    /**
     * Gets or sets the selected background color of the cell.
    */
    get selectedBackground() {
        return brushToString(this.i.ld);
    }
    set selectedBackground(v) {
        this.i.ld = stringToBrush(v);
    }
    /**
     * Gets or sets the hover background color of the cell.
    */
    get hoverBackground() {
        return brushToString(this.i.k9);
    }
    set hoverBackground(v) {
        this.i.k9 = stringToBrush(v);
    }
    /**
     * Gets or sets the hover text color of the cell.
    */
    get hoverTextColor() {
        return brushToString(this.i.la);
    }
    set hoverTextColor(v) {
        this.i.la = stringToBrush(v);
    }
    /**
     * Gets or sets the color for the sort indicator icon.
    */
    get sortIndicatorColor() {
        return brushToString(this.i.le);
    }
    set sortIndicatorColor(v) {
        this.i.le = stringToBrush(v);
    }
    /**
     * Gets or sets the background color for the cell when it is stuck to the top of the grid as a pinned row.
    */
    get stickyRowBackground() {
        return brushToString(this.i.lf);
    }
    set stickyRowBackground(v) {
        this.i.lf = stringToBrush(v);
    }
    /**
     * Gets or sets the background color for the cell that has been marked as pinned.
    */
    get pinnedRowBackground() {
        return brushToString(this.i.lc);
    }
    set pinnedRowBackground(v) {
        this.i.lc = stringToBrush(v);
    }
    /**
     * Gets or sets the color for the last row in the sticky row area.
    */
    get lastStickyRowBackground() {
        return brushToString(this.i.lb);
    }
    set lastStickyRowBackground(v) {
        this.i.lb = stringToBrush(v);
    }
    /**
     * Gets or sets the background color for filter row.
    */
    get filterRowBackground() {
        return brushToString(this.i.k7);
    }
    set filterRowBackground(v) {
        this.i.k7 = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for displaying text.
    */
    get pinnedRowOpacity() {
        return this.i.cg;
    }
    set pinnedRowOpacity(v) {
        this.i.cg = +v;
    }
    /**
     * Gets or sets the original value for the cell, before processing.
    */
    get originalValue() {
        return this.i.g3;
    }
    set originalValue(v) {
        this.i.g3 = v;
    }
    /**
     * Gets or sets the text value, if any, which was rendered by a text cell.
    */
    get renderValue() {
        return this.i.jb;
    }
    set renderValue(v) {
        this.i.jb = v;
    }
    /**
     * Gets or sets the color of the text for the cell, if any.
    */
    get textColor() {
        return brushToString(this.i.lg);
    }
    set textColor(v) {
        this.i.lg = stringToBrush(v);
    }
    /**
     * Gets the actual color of the text for the cell, if any.
    */
    get actualTextColor() {
        return brushToString(this.i.k2);
    }
    set actualTextColor(v) {
        this.i.k2 = stringToBrush(v);
    }
    /**
     * Gets or sets the text color for cells in deleted rows.
    */
    get deletedTextColor() {
        return brushToString(this.i.k5);
    }
    set deletedTextColor(v) {
        this.i.k5 = stringToBrush(v);
    }
    get font() {
        if (this.i.ag == null) {
            return null;
        }
        return this.i.ag.fontString;
    }
    set font(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.ag = fi;
    }
    get actualFont() {
        if (this.i.ae == null) {
            return null;
        }
        return this.i.ae.fontString;
    }
    set actualFont(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.ae = fi;
    }
    /**
     * Gets or sets the line break mode to use if text is present in the cell.
    */
    get lineBreakMode() {
        return this.i.aa;
    }
    set lineBreakMode(v) {
        this.i.aa = ensureEnum(TextCellLineBreakMode_$type, v);
    }
    /**
     * Gets or sets the virtualization percentage value. This is between 0 an 1, and indicates how virtual the content is at present.
    */
    get virtualizationPercentage() {
        return this.i.ck;
    }
    set virtualizationPercentage(v) {
        this.i.ck = +v;
    }
    /**
     * Gets or sets the left padding to use for the content.
    */
    get paddingLeft() {
        return this.i.f3;
    }
    set paddingLeft(v) {
        this.i.f3 = +v;
    }
    /**
     * Gets or sets the top padding to use for the content.
    */
    get paddingTop() {
        return this.i.f7;
    }
    set paddingTop(v) {
        this.i.f7 = +v;
    }
    /**
     * Gets or sets the right padding to use for the content.
    */
    get paddingRight() {
        return this.i.f5;
    }
    set paddingRight(v) {
        this.i.f5 = +v;
    }
    /**
     * Gets or sets the bottom padding to use for the content.
    */
    get paddingBottom() {
        return this.i.f1;
    }
    set paddingBottom(v) {
        this.i.f1 = +v;
    }
    /**
     * Gets or sets the left padding to use for the content.
    */
    get actualPaddingLeft() {
        return this.i.ea;
    }
    set actualPaddingLeft(v) {
        this.i.ea = +v;
    }
    /**
     * Gets or sets the top padding to use for the content.
    */
    get actualPaddingTop() {
        return this.i.ee;
    }
    set actualPaddingTop(v) {
        this.i.ee = +v;
    }
    /**
     * Gets or sets the right padding to use for the content.
    */
    get actualPaddingRight() {
        return this.i.ec;
    }
    set actualPaddingRight(v) {
        this.i.ec = +v;
    }
    /**
     * Gets or sets the bottom padding to use for the content.
    */
    get actualPaddingBottom() {
        return this.i.d8;
    }
    set actualPaddingBottom(v) {
        this.i.d8 = +v;
    }
    /**
     * Gets or sets the left border to use for the content.
    */
    get borderLeftWidth() {
        return this.i.ek;
    }
    set borderLeftWidth(v) {
        this.i.ek = +v;
    }
    /**
     * Gets or sets the top border to use for the content.
    */
    get borderTopWidth() {
        return this.i.ep;
    }
    set borderTopWidth(v) {
        this.i.ep = +v;
    }
    /**
     * Gets or sets the right border to use for the content.
    */
    get borderRightWidth() {
        return this.i.en;
    }
    set borderRightWidth(v) {
        this.i.en = +v;
    }
    /**
     * Gets or sets the bottom border to use for the content.
    */
    get borderBottomWidth() {
        return this.i.ei;
    }
    set borderBottomWidth(v) {
        this.i.ei = +v;
    }
    /**
     * Gets or sets the left activation border to use for the content.
    */
    get activationBorderLeftWidth() {
        return this.i.dm;
    }
    set activationBorderLeftWidth(v) {
        this.i.dm = +v;
    }
    /**
     * Gets or sets the top activation border to use for the content.
    */
    get activationBorderTopWidth() {
        return this.i.ds;
    }
    set activationBorderTopWidth(v) {
        this.i.ds = +v;
    }
    /**
     * Gets or sets the right activation border to use for the content.
    */
    get activationBorderRightWidth() {
        return this.i.dq;
    }
    set activationBorderRightWidth(v) {
        this.i.dq = +v;
    }
    /**
     * Gets or sets the bottom activation border to use for the content.
    */
    get activationBorderBottomWidth() {
        return this.i.dk;
    }
    set activationBorderBottomWidth(v) {
        this.i.dk = +v;
    }
    /**
     * Gets or sets the left error border to use for the content.
    */
    get errorBorderLeftWidth() {
        return this.i.e2;
    }
    set errorBorderLeftWidth(v) {
        this.i.e2 = +v;
    }
    /**
     * Gets or sets the top error border to use for the content.
    */
    get errorBorderTopWidth() {
        return this.i.e7;
    }
    set errorBorderTopWidth(v) {
        this.i.e7 = +v;
    }
    /**
     * Gets or sets the right error border to use for the content.
    */
    get errorBorderRightWidth() {
        return this.i.e5;
    }
    set errorBorderRightWidth(v) {
        this.i.e5 = +v;
    }
    /**
     * Gets or sets the bottom error border to use for the content.
    */
    get errorBorderBottomWidth() {
        return this.i.e0;
    }
    set errorBorderBottomWidth(v) {
        this.i.e0 = +v;
    }
    /**
     * Gets or sets the actual left border to use for the content.
    */
    get actualBorderLeftWidth() {
        return this.i.dy;
    }
    set actualBorderLeftWidth(v) {
        this.i.dy = +v;
    }
    /**
     * Gets or sets the actual top border to use for the content.
    */
    get actualBorderTopWidth() {
        return this.i.d3;
    }
    set actualBorderTopWidth(v) {
        this.i.d3 = +v;
    }
    /**
     * Gets or sets the actual right border to use for the content.
    */
    get actualBorderRightWidth() {
        return this.i.d1;
    }
    set actualBorderRightWidth(v) {
        this.i.d1 = +v;
    }
    /**
     * Gets or sets the actual bottom border to use for the content.
    */
    get actualBorderBottomWidth() {
        return this.i.dw;
    }
    set actualBorderBottomWidth(v) {
        this.i.dw = +v;
    }
    /**
     * Gets the current sort direction for the column containing the cell.
    */
    get sortDirection() {
        return this.i.n;
    }
    set sortDirection(v) {
        this.i.n = ensureEnum(ColumnSortDirection_$type, v);
    }
    /**
     * Gets the expansion state of the cell.
    */
    get isExpanded() {
        return this.i.a5;
    }
    set isExpanded(v) {
        this.i.a5 = ensureBool(v);
    }
    /**
     * Gets if the cell needs to display an expansion indicator.
    */
    get isCollapsable() {
        return this.i.ax;
    }
    set isCollapsable(v) {
        this.i.ax = ensureBool(v);
    }
    /**
     * Gets the fixed column position of this cell.
    */
    get pinned() {
        return this.i.y;
    }
    set pinned(v) {
        this.i.y = ensureEnum(PinnedPositions_$type, v);
    }
    get editFont() {
        if (this.i.af == null) {
            return null;
        }
        return this.i.af.fontString;
    }
    set editFont(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.af = fi;
    }
    /**
     * Gets whether the cell has been edited.
    */
    get isEdited() {
        return this.i.a4;
    }
    set isEdited(v) {
        this.i.a4 = ensureBool(v);
    }
    /**
     * Gets whether the cell is part of a deleted row.
    */
    get isDeleted() {
        return this.i.a1;
    }
    set isDeleted(v) {
        this.i.a1 = ensureBool(v);
    }
    /**
     * Gets or sets the error message for the cell.
    */
    get editError() {
        return this.i.h2;
    }
    set editError(v) {
        this.i.h2 = v;
    }
    /**
     * Gets whether the cell is in edit mode.
    */
    get isInEditMode() {
        return this.i.ba;
    }
    set isInEditMode(v) {
        this.i.ba = ensureBool(v);
    }
    get editID() {
        return this.i.ey;
    }
    set editID(v) {
        this.i.ey = +v;
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    }
    isCustomFieldDirty(propertyName) {
        let iv = this.i.az(propertyName);
        return (iv);
    }
    /**
     * Gets if a named property is dirty.
    
    * @param propertyId  * The property id to check.
    */
    isDirtyById(propertyId_) {
        let iv = this.i.a3(propertyId_);
        return (iv);
    }
    /**
     * Gets if a named property is dirty.
    
    * @param propertyName  * The property name to check.
    */
    isDirty(propertyName) {
        let iv = this.i.a2(propertyName);
        return (iv);
    }
    setNamedValue(valueName, value) {
        this.i.kg(valueName, value);
    }
    /**
     * Returns if there is a named value stored for the cell.
    
    * @param valueName  * The name of the value to check.
    */
    hasNamedValue(valueName) {
        let iv = this.i.av(valueName);
        return (iv);
    }
    /**
     * Removes a named value from the cell.
    
    * @param valueName  * The name of the value to remove.
    */
    removeNamedValue(valueName) {
        this.i.kc(valueName);
    }
    /**
     * Gets a named value from the cell.
    
    * @param valueName  * The name of the value to get.
    */
    getNamedValue(valueName) {
        let iv = this.i.g1(valueName);
        return (iv);
    }
}
