import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrGridColumnAnimationSettings } from "./igr-grid-column-animation-settings";
import { IgrColumnWidth } from "./igr-column-width";
import { IgrHeader } from "./igr-header";
import { ColumnSortDirection_$type } from "./ColumnSortDirection";
import { PinnedPositions_$type } from "./PinnedPositions";
import { ColumnOptionsIconAlignment_$type } from "./ColumnOptionsIconAlignment";
import { ColumnOptionsIconBehavior_$type } from "./ColumnOptionsIconBehavior";
import { MergedCellMode_$type } from "./MergedCellMode";
import { MergedCellEvaluationCriteria_$type } from "./MergedCellEvaluationCriteria";
import { CellContentVerticalAlignment_$type } from "./CellContentVerticalAlignment";
import { FilterComparisonType_$type } from "./FilterComparisonType";
import { IgrGridFilterOperandsCollection } from "./igr-grid-filter-operands-collection";
import { IgrDefinitionBase } from "./igr-definition-base";
import { brushToString, stringToBrush, ensureBool, ensureEnum } from "igniteui-react-core";
import { ColumnWidth as ColumnWidth_internal } from "./ColumnWidth";
import { FontInfo } from "igniteui-react-core";
import { GridFilterOperandsCollection as GridFilterOperandsCollection_internal } from "./GridFilterOperandsCollection";
import { FilterOperand } from "./FilterOperand";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
/**
 * A column in the data grid.
*/
export class IgrDataGridColumn extends IgrDefinitionBase {
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._filterOperands = null;
        this._actualHeaderTextChange = null;
        this._actualHeaderTextChange_wrapped = null;
    }
    /**
     * Gets or sets the amount of left padding to use for the cell content for this column.
    */
    get paddingLeft() {
        return this.i.h2;
    }
    set paddingLeft(v) {
        this.i.h2 = +v;
    }
    /**
     * Gets or sets the amount of top padding to use for the cell content for this column.
    */
    get paddingTop() {
        return this.i.h4;
    }
    set paddingTop(v) {
        this.i.h4 = +v;
    }
    /**
     * Gets or sets the amount of right padding to use for the cell content of this column.
    */
    get paddingRight() {
        return this.i.h3;
    }
    set paddingRight(v) {
        this.i.h3 = +v;
    }
    /**
     * Gets or sets the amount of bottom padding to use for the cell content of this column.
    */
    get paddingBottom() {
        return this.i.h1;
    }
    set paddingBottom(v) {
        this.i.h1 = +v;
    }
    /**
     * Gets or sets an unique name of the Column
    */
    get name() {
        return this.i.jz;
    }
    set name(v) {
        this.i.jz = v;
    }
    /**
     * Gets or sets the key used for the column binding
    */
    get field() {
        return this.i.i8;
    }
    set field(v) {
        this.i.i8 = v;
    }
    /**
     * Gets or sets the text displayed in the header of the column
    */
    get headerText() {
        return this.i.jf;
    }
    set headerText(v) {
        this.i.jf = v;
    }
    /**
     * Gets the actual text displayed in the header of the column
    */
    get actualHeaderText() {
        return this.i.im;
    }
    set actualHeaderText(v) {
        this.i.im = v;
    }
    /**
     * Gets or sets the background color to use for the cells when they are selected
    */
    get selectedBackground() {
        return brushToString(this.i.lk);
    }
    set selectedBackground(v) {
        this.i.lk = stringToBrush(v);
    }
    /**
     * Gets the actual background color that is used for the cells when they are selected
    */
    get actualSelectedBackground() {
        return brushToString(this.i.ld);
    }
    set actualSelectedBackground(v) {
        this.i.ld = stringToBrush(v);
    }
    /**
     * Gets or sets the background color to use for the cells when the row is hovered.
    */
    get rowHoverBackground() {
        return brushToString(this.i.li);
    }
    set rowHoverBackground(v) {
        this.i.li = stringToBrush(v);
    }
    /**
     * Gets the actual background color that is used for the cells when they are hovered.
    */
    get actualHoverBackground() {
        return brushToString(this.i.lb);
    }
    set actualHoverBackground(v) {
        this.i.lb = stringToBrush(v);
    }
    /**
     * Gets or sets the text color to use for the cells when the row is hovered.
    */
    get rowHoverTextColor() {
        return brushToString(this.i.lj);
    }
    set rowHoverTextColor(v) {
        this.i.lj = stringToBrush(v);
    }
    /**
     * Gets the actual text color that is used for the cells when they are hovered.
    */
    get actualRowHoverTextColor() {
        return brushToString(this.i.lc);
    }
    set actualRowHoverTextColor(v) {
        this.i.lc = stringToBrush(v);
    }
    /**
     * Gets or sets the animation settings to use for this column.
    */
    get animationSettings() {
        const r = this.i.fs;
        if (r == null) {
            return null;
        }
        if (!r.externalObject) {
            let e = new IgrGridColumnAnimationSettings();
            if (r.$type) {
                e._implementation = r;
            }
            else {
                if (e.i.setNativeElement) {
                    e.i.setNativeElement(r);
                }
            }
            r.externalObject = e;
        }
        return r.externalObject;
    }
    set animationSettings(v) {
        v == null ? this.i.fs = null : this.i.fs = v.i;
    }
    /**
     * Gets or sets the width to use for this column.
    */
    get width() {
        const r = this.i.width;
        if (r == null) {
            return null;
        }
        if (!r.externalObject) {
            let e = new IgrColumnWidth();
            if (r.$type) {
                e._implementation = r;
            }
            else {
                if (e.i.setNativeElement) {
                    e.i.setNativeElement(r);
                }
            }
            r.externalObject = e;
        }
        return r.externalObject;
    }
    set width(v) {
        if (typeof v == "string") {
            let int = ColumnWidth_internal.parse(v);
            let ext = new IgrColumnWidth();
            ext._implementation = int;
            v = ext;
        }
        v == null ? this.i.width = null : this.i.width = v.i;
    }
    /**
     * Gets or sets the minimum width to use for this column. Overrides the DefaultColumnMinWidth from the grid, if set.
    */
    get minWidth() {
        return this.i.hi;
    }
    set minWidth(v) {
        this.i.hi = +v;
    }
    /**
     * Gets whether this column was projected from markup/templates and is constrained.
    */
    get isFromMarkup() {
        return this.i.g6;
    }
    set isFromMarkup(v) {
        this.i.g6 = ensureBool(v);
    }
    /**
     * Gets whether this column was auto generated.
    */
    get isAutoGenerated() {
        return this.i.g0;
    }
    set isAutoGenerated(v) {
        this.i.g0 = ensureBool(v);
    }
    /**
     * Gets or sets a filter to apply on the values of this column
    */
    get filter() {
        return this.i.ep;
    }
    set filter(v) {
        this.i.ep = v;
    }
    /**
     * Gets or sets a filter to apply to the values of this column.
    */
    get filterExpression() {
        return this.i.er;
    }
    set filterExpression(v) {
        this.i.er = v;
    }
    /**
     * Gets or sets the header definition for this column.
    */
    get header() {
        const r = this.i.header;
        if (r == null) {
            return null;
        }
        if (!r.externalObject) {
            let e = IgrHeader._createFromInternal(r);
            if (e) {
                e._implementation = r;
            }
            r.externalObject = e;
        }
        return r.externalObject;
    }
    set header(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.header = null : this.i.header = v.i;
    }
    /**
     * Gets or sets whether filtering is enabled for this column.
    */
    get isFilteringEnabled() {
        return this.i.g5;
    }
    set isFilteringEnabled(v) {
        this.i.g5 = ensureBool(v);
    }
    /**
     * Gets or sets whether resizing is enabled for this column.
    */
    get isResizingEnabled() {
        return this.i.g8;
    }
    set isResizingEnabled(v) {
        this.i.g8 = ensureBool(v);
    }
    /**
     * Gets or sets whether or not a column is hidden from the grid
    */
    get isHidden() {
        return this.i.g7;
    }
    set isHidden(v) {
        this.i.g7 = ensureBool(v);
    }
    /**
     * Gets or sets if a column should be removed from the grid when it is fully hidden
    */
    get shouldRemoveWhenHidden() {
        return this.i.hb;
    }
    set shouldRemoveWhenHidden(v) {
        this.i.hb = ensureBool(v);
    }
    /**
     * Gets the current sort direction (None, Ascending, Descending) for this column.
    */
    get sortDirection() {
        return this.i.ff;
    }
    set sortDirection(v) {
        this.i.ff = ensureEnum(ColumnSortDirection_$type, v);
    }
    /**
     * Gets or sets the current fixed position for this column.
    */
    get pinned() {
        return this.i.f6;
    }
    set pinned(v) {
        this.i.f6 = ensureEnum(PinnedPositions_$type, v);
    }
    /**
     * Gets the actual column options icon alignment for this column.
    */
    get actualColumnOptionsIconAlignment() {
        return this.i.e6;
    }
    set actualColumnOptionsIconAlignment(v) {
        this.i.e6 = ensureEnum(ColumnOptionsIconAlignment_$type, v);
    }
    /**
     * Gets or sets whether the column options icon is aligned opposite the header text or not.
    */
    get columnOptionsIconAlignment() {
        return this.i.e7;
    }
    set columnOptionsIconAlignment(v) {
        this.i.e7 = ensureEnum(ColumnOptionsIconAlignment_$type, v);
    }
    /**
     * Gets the actual column options icon color for this column.
    */
    get actualColumnOptionsIconColor() {
        return brushToString(this.i.k9);
    }
    set actualColumnOptionsIconColor(v) {
        this.i.k9 = stringToBrush(v);
    }
    /**
     * Gets or sets the column options icon color for this column.
    */
    get columnOptionsIconColor() {
        return brushToString(this.i.le);
    }
    set columnOptionsIconColor(v) {
        this.i.le = stringToBrush(v);
    }
    /**
     * Gets or sets how the column option icon will behave in the column header.
    */
    get columnOptionsIconBehavior() {
        return this.i.fb;
    }
    set columnOptionsIconBehavior(v) {
        this.i.fb = ensureEnum(ColumnOptionsIconBehavior_$type, v);
    }
    /**
     * Gets or sets how the column option icon will behave in the column header.
    */
    get actualColumnOptionsIconBehavior() {
        return this.i.fa;
    }
    set actualColumnOptionsIconBehavior(v) {
        this.i.fa = ensureEnum(ColumnOptionsIconBehavior_$type, v);
    }
    /**
     * Gets the actual state of the column options for this column.
    */
    get actualIsColumnOptionsEnabled() {
        return this.i.gt;
    }
    set actualIsColumnOptionsEnabled(v) {
        this.i.gt = ensureBool(v);
    }
    /**
     * Gets or sets the preferred state of the column options for this column. If the feature is disabled at the grid level
     * then it will be disabled for the column regardless of what this is set to.
    */
    get isColumnOptionsEnabled() {
        return this.i.g1;
    }
    set isColumnOptionsEnabled(v) {
        this.i.g1 = ensureBool(v);
    }
    /**
     * Gets the actual state of summaries menu in the column options for this column.
    */
    get actualIsColumnOptionsSummariesEnabled() {
        return this.i.gv;
    }
    set actualIsColumnOptionsSummariesEnabled(v) {
        this.i.gv = ensureBool(v);
    }
    /**
     * Gets or sets whether to show the summaries option in the column options menu for this column.
    */
    get isColumnOptionsSummariesEnabled() {
        return this.i.g3;
    }
    set isColumnOptionsSummariesEnabled(v) {
        this.i.g3 = ensureBool(v);
    }
    /**
     * Gets the actual state of grouping menu in the column options for this column.
    */
    get actualIsColumnOptionsGroupingEnabled() {
        return this.i.gu;
    }
    set actualIsColumnOptionsGroupingEnabled(v) {
        this.i.gu = ensureBool(v);
    }
    /**
     * Gets or sets whether to show the grouping option in the column options menu for this column.
    */
    get isColumnOptionsGroupingEnabled() {
        return this.i.g2;
    }
    set isColumnOptionsGroupingEnabled(v) {
        this.i.g2 = ensureBool(v);
    }
    /**
     * Gets or sets if the column is editable.
    */
    get isEditable() {
        return this.i.g4;
    }
    set isEditable(v) {
        this.i.g4 = ensureBool(v);
    }
    /**
     * Gets or sets the text color used for deleted rows.
    */
    get deletedTextColor() {
        return brushToString(this.i.lf);
    }
    set deletedTextColor(v) {
        this.i.lf = stringToBrush(v);
    }
    /**
     * Gets the actual text color used for deleted rows.
    */
    get actualDeletedTextColor() {
        return brushToString(this.i.la);
    }
    set actualDeletedTextColor(v) {
        this.i.la = stringToBrush(v);
    }
    /**
     * Gets or sets the opacity to use for unsaved edited cell values.
    */
    get editOpacity() {
        return this.i.hh;
    }
    set editOpacity(v) {
        this.i.hh = +v;
    }
    /**
     * Gets the actual opacity for unsaved edited cell values.
    */
    get actualEditOpacity() {
        return this.i.hg;
    }
    set actualEditOpacity(v) {
        this.i.hg = +v;
    }
    /**
     * Gets or sets the font style to use for unsaved cell edits.
    */
    get textEditStyle() {
        if (this.i.textEditStyle == null) {
            return null;
        }
        return this.i.textEditStyle.fontString;
    }
    set textEditStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.textEditStyle = fi;
    }
    /**
     * Gets the actual font style used for unsaved cell edits.
    */
    get actualEditFontInfo() {
        if (this.i.gb == null) {
            return null;
        }
        return this.i.gb.fontString;
    }
    set actualEditFontInfo(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.gb = fi;
    }
    /**
     * Gets or sets if and how cell merging is performed for this field.
    */
    get mergedCellMode() {
        return this.i.f2;
    }
    set mergedCellMode(v) {
        this.i.f2 = ensureEnum(MergedCellMode_$type, v);
    }
    /**
     * Gets or sets how cells are evaluated for merging.
    */
    get mergedCellEvaluationCriteria() {
        return this.i.fz;
    }
    set mergedCellEvaluationCriteria(v) {
        this.i.fz = ensureEnum(MergedCellEvaluationCriteria_$type, v);
    }
    /**
     * Gets or sets the vertical alignment to use for the merged cell content.
    */
    get mergedCellVerticalAlignment() {
        return this.i.ey;
    }
    set mergedCellVerticalAlignment(v) {
        this.i.ey = ensureEnum(CellContentVerticalAlignment_$type, v);
    }
    /**
     * Gets or sets the amount of left padding to use for the cell content for this column.
    */
    get mergedCellPaddingLeft() {
        return this.i.hv;
    }
    set mergedCellPaddingLeft(v) {
        this.i.hv = +v;
    }
    /**
     * Gets or sets the amount of top padding to use for the cell content for this column.
    */
    get mergedCellPaddingTop() {
        return this.i.hx;
    }
    set mergedCellPaddingTop(v) {
        this.i.hx = +v;
    }
    /**
     * Gets or sets the amount of right padding to use for the cell content of this column.
    */
    get mergedCellPaddingRight() {
        return this.i.hw;
    }
    set mergedCellPaddingRight(v) {
        this.i.hw = +v;
    }
    /**
     * Gets or sets the amount of bottom padding to use for the cell content of this column.
    */
    get mergedCellPaddingBottom() {
        return this.i.hu;
    }
    set mergedCellPaddingBottom(v) {
        this.i.hu = +v;
    }
    /**
     * Gets or sets whether UI filters are case sensitive or not.
    */
    get filterComparisonType() {
        return this.i.fn;
    }
    set filterComparisonType(v) {
        this.i.fn = ensureEnum(FilterComparisonType_$type, v);
    }
    /**
     * Gets a list of the current custom filters for this column.
    */
    get filterOperands() {
        if (this._filterOperands === null) {
            let coll = new IgrGridFilterOperandsCollection();
            let innerColl = this.i.fu;
            if (!innerColl) {
                innerColl = new GridFilterOperandsCollection_internal();
            }
            this._filterOperands = coll._fromInner(innerColl);
        }
        return this._filterOperands;
    }
    set filterOperands(v) {
        if (this._filterOperands !== null) {
            this._filterOperands._setSyncTarget(null);
            this._filterOperands = null;
        }
        let coll = new IgrGridFilterOperandsCollection();
        this._filterOperands = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(FilterOperand.$type);
        let innerColl = this.i.fu;
        if (!innerColl) {
            innerColl = new GridFilterOperandsCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._filterOperands._setSyncTarget(syncColl);
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.animationSettings && this.animationSettings.name && this.animationSettings.name == name) {
            return this.animationSettings;
        }
        if (this.width && this.width.name && this.width.name == name) {
            return this.width;
        }
        if (this.header && this.header.name && this.header.name == name) {
            return this.header;
        }
        if (this.filterOperands != null && this.filterOperands.findByName && this.filterOperands.findByName(name)) {
            return this.filterOperands.findByName(name);
        }
        return null;
    }
    _styling(container, component, parent) {
        super._styling(container, component, parent);
        this._inStyling = true;
        if (this.header && this.header._styling) {
            this.header._styling(container, component, this);
        }
        this._inStyling = false;
    }
    /**
     * Get the unique key used to identify this column.
    
    */
    getUniqueKey() {
        let iv = this.i.jd();
        return (iv);
    }
    setNamedHeaderValue(valueName, animationType, value) {
        this.i.kk(valueName, (animationType == null ? null : animationType), value);
    }
    /**
     * Returns if the column has named header values.
    
    */
    hasNamedHeaderValues() {
        let iv = this.i.gy();
        return (iv);
    }
    /**
     * Returns if there is a named header value with a given name.
    
    * @param valueName  * The named value to check for.
    */
    hasNamedHeaderValue(valueName) {
        let iv = this.i.gx(valueName);
        return (iv);
    }
    /**
     * Removes a named header value with the given name from the named header values for this column.
    
    * @param valueName  * The named header value to remove.
    */
    removeNamedHeaderValue(valueName) {
        this.i.kj(valueName);
    }
    /**
     * Gets the value of a named header value for this column by name.
    
    * @param valueName  * Name of the named header value to retrieve.
    */
    getNamedHeaderValue(valueName) {
        let iv = this.i.h9(valueName);
        return (iv);
    }
    applyCustomFilter(filterID, index, value) {
        this.i.ke(filterID, index, value);
    }
    get actualHeaderTextChange() {
        return this._actualHeaderTextChange;
    }
    set actualHeaderTextChange(ev) {
        if (this._actualHeaderTextChange_wrapped !== null) {
            this.i.propertyChanged = delegateRemove(this.i.propertyChanged, this._actualHeaderTextChange_wrapped);
            this._actualHeaderTextChange_wrapped = null;
            this._actualHeaderTextChange = null;
        }
        this._actualHeaderTextChange = ev;
        this._actualHeaderTextChange_wrapped = (o, e) => {
            let ext = this.actualHeaderText;
            if (this.beforeActualHeaderTextChange) {
                this.beforeActualHeaderTextChange(this, ext);
            }
            if (this._actualHeaderTextChange) {
                this._actualHeaderTextChange(this, ext);
            }
        };
        this.i.propertyChanged = delegateCombine(this.i.propertyChanged, this._actualHeaderTextChange_wrapped);
    }
}
