import { DateTimeFormats_$type } from "./DateTimeFormats";
import { IgrCellInfo } from "./igr-cell-info";
import { DateTimeCellModel as DateTimeCellModel_internal } from "./DateTimeCellModel";
import { ensureEnum, ensureBool, arrayFindByName } from "igniteui-react-core";
/**
 * Backing information about a date time cell for the grid.
*/
export class IgrDateTimeCellInfo extends IgrCellInfo {
    createImplementation() {
        return new DateTimeCellModel_internal();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
    /**
     * Sets or gets the DateTime value for the cell.
    */
    get dateTimeValue() {
        return this.i.lt;
    }
    set dateTimeValue(v) {
        this.i.lt = v;
    }
    /**
     * The format string to apply to the value
    */
    get formatStringOverride() {
        return this.i.ma;
    }
    set formatStringOverride(v) {
        this.i.ma = v;
    }
    get formatSpecifiers() {
        return this.i.lk;
    }
    set formatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.lk = v;
    }
    /**
     * The format options to apply to the value
    */
    get formatOverride() {
        return this.i.l3;
    }
    set formatOverride(v) {
        this.i.l3 = v;
    }
    /**
     * Sets or gets the simple DateTimeFormat to use for the cell.
    */
    get dateTimeFormat() {
        return this.i.lp;
    }
    set dateTimeFormat(v) {
        this.i.lp = ensureEnum(DateTimeFormats_$type, v);
    }
    /**
     * Sets or gets whether the value to use is a DateTimeOffset value.
    */
    get isOffsetValue() {
        return this.i.lr;
    }
    set isOffsetValue(v) {
        this.i.lr = ensureBool(v);
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.formatSpecifiers != null && arrayFindByName(this.formatSpecifiers, name)) {
            return arrayFindByName(this.formatSpecifiers, name);
        }
        return null;
    }
}
