import { DateTimeFormats_$type } from "./DateTimeFormats";
import { EditorType_$type } from "./EditorType";
import { IgrDataGridColumn } from "./igr-data-grid-column";
import { DateTimeColumn } from "./DateTimeColumn";
import { ensureEnum, ensureBool, arrayFindByName } from "igniteui-react-core";
/**
 * A column for displaying date/time values.
*/
export class IgrDateTimeColumn extends IgrDataGridColumn {
    createImplementation() {
        return new DateTimeColumn();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets the date time format to use for this column. If FormatString is specificied this value is ignored.
    */
    get dateTimeFormat() {
        return this.i.lq;
    }
    set dateTimeFormat(v) {
        this.i.lq = ensureEnum(DateTimeFormats_$type, v);
    }
    /**
     * Gets or sets the format string to apply to the value. If set, the other value formatting properties on this column are ignored.
    */
    get formatString() {
        return this.i.l8;
    }
    set formatString(v) {
        this.i.l8 = v;
    }
    /**
     * Gets or sets the format string to use when editing dates.
    */
    get editorFormatString() {
        return this.i.l1;
    }
    set editorFormatString(v) {
        this.i.l1 = v;
    }
    get formatSpecifiers() {
        return this.i.lm;
    }
    set formatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.lm = v;
    }
    /**
     * Gets or sets the INTL DateTimeFormat object to use for formatting the date values.
    */
    get formatOverride() {
        return this.i.lx;
    }
    set formatOverride(v) {
        this.i.lx = v;
    }
    /**
     * Gets or sets the ShowTodayButton property to detirmine if the today button is shown
    */
    get showTodayButton() {
        return this.i.lt;
    }
    set showTodayButton(v) {
        this.i.lt = ensureBool(v);
    }
    /**
     * Gets or sets the editor type used for editing cells in this column.
    */
    get editorType() {
        return this.i.lr;
    }
    set editorType(v) {
        this.i.lr = ensureEnum(EditorType_$type, v);
    }
    /**
     * Gets or sets the ComboBox data source.
    */
    get editorDataSource() {
        return this.i.lw;
    }
    set editorDataSource(v) {
        this.i.lw = v;
    }
    /**
     * Gets or sets the ComboBox text field.
    */
    get editorTextField() {
        return this.i.l3;
    }
    set editorTextField(v) {
        this.i.l3 = v;
    }
    /**
     * Gets or sets the ComboBox value field.
    */
    get editorValueField() {
        return this.i.l4;
    }
    set editorValueField(v) {
        this.i.l4 = v;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.formatSpecifiers != null && arrayFindByName(this.formatSpecifiers, name)) {
            return arrayFindByName(this.formatSpecifiers, name);
        }
        return null;
    }
}
