import { IgrCellInfo } from "./igr-cell-info";
import { DataSourceSchemaPropertyType_$type } from "igniteui-react-core";
import { EditorType_$type } from "./EditorType";
import { EditorCellModel as EditorCellModel_internal } from "./EditorCellModel";
import { ensureBool, ensureEnum } from "igniteui-react-core";
/**
 * Represents info about the current cell.
*/
export class IgrEditorCellInfo extends IgrCellInfo {
    createImplementation() {
        return new EditorCellModel_internal();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
    /**
     * Gets whether the editor cell is hidden or not.
    */
    get isHidden() {
        return this.i.lv;
    }
    /**
     * Gets or sets the edit target for this cell.
    */
    get editTarget() {
        const r = this.i.lo;
        if (r == null) {
            return null;
        }
        return r.externalObject;
    }
    set editTarget(v) {
        v == null ? this.i.lo = null : this.i.lo = v.i;
    }
    /**
     * Gets or sets the data type associated with the cell being edited.
    */
    get dataType() {
        return this.i.lm;
    }
    set dataType(v) {
        this.i.lm = ensureEnum(DataSourceSchemaPropertyType_$type, v);
    }
    /**
     * Gets or sets the error message to display in the editor cell.
    */
    get errorMessage() {
        return this.i.mr;
    }
    set errorMessage(v) {
        this.i.mr = v;
    }
    /**
     * Gets or sets the user selected value.
    */
    get editValue() {
        return this.i.me;
    }
    set editValue(v) {
        this.i.me = v;
    }
    /**
     * Gets or sets the type of editor to use while cell editing.
    */
    get editorType() {
        return this.i.lq;
    }
    set editorType(v) {
        this.i.lq = ensureEnum(EditorType_$type, v);
    }
    /**
     * Gets or sets the data source to use for the editor where it makes sense.
    */
    get editorDataSource() {
        return this.i.md;
    }
    set editorDataSource(v) {
        this.i.md = v;
    }
    /**
     * Gets or sets the editors display member.
    */
    get editorTextField() {
        return this.i.mm;
    }
    set editorTextField(v) {
        this.i.mm = v;
    }
    /**
     * Gets or sets the editors value member.
    */
    get editorValueField() {
        return this.i.lk;
    }
    set editorValueField(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.lk = v;
    }
    get dateFormatString() {
        return this.i.mj;
    }
    set dateFormatString(v) {
        this.i.mj = v;
    }
    get showTodayButton() {
        return this.i.lw;
    }
    set showTodayButton(v) {
        this.i.lw = ensureBool(v);
    }
    /**
     * Gets the row index that the editor cell is targeting for edit.
    */
    get targetRow() {
        return this.i.mb;
    }
    /**
     * Gets the column index that the editor cell is targeting for edit.
    */
    get targetColumn() {
        return this.i.ma;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.editTarget && this.editTarget.name && this.editTarget.name == name) {
            return this.editTarget;
        }
        return null;
    }
}
