import { DataSourceSchemaPropertyType_$type } from "igniteui-react-core";
import { IgrGridFilterOperandsCollection } from "./igr-grid-filter-operands-collection";
import { IgrCellInfo } from "./igr-cell-info";
import { FilterCellModel as FilterCellModel_internal } from "./FilterCellModel";
import { ensureEnum } from "igniteui-react-core";
import { GridFilterOperandsCollection as GridFilterOperandsCollection_internal } from "./GridFilterOperandsCollection";
import { FilterOperand } from "./FilterOperand";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
/**
 * Represents info about the current cell.
*/
export class IgrFilterCellInfo extends IgrCellInfo {
    createImplementation() {
        return new FilterCellModel_internal();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
        this._filterOperands = null;
    }
    /**
     * Gets or sets whether the cell is hit test visible.
    */
    get dataType() {
        return this.i.lo;
    }
    set dataType(v) {
        this.i.lo = ensureEnum(DataSourceSchemaPropertyType_$type, v);
    }
    /**
     * Gets or sets the current filter to display in the cell.
    */
    get filter() {
        return this.i.lm;
    }
    set filter(v) {
        this.i.lm = v;
    }
    /**
     * Gets or sets the current filter expression applied to the column.
    */
    get filterExpression() {
        return this.i.lq;
    }
    set filterExpression(v) {
        this.i.lq = v;
    }
    get filterOperands() {
        if (this._filterOperands === null) {
            let coll = new IgrGridFilterOperandsCollection();
            let innerColl = this.i.ls;
            if (!innerColl) {
                innerColl = new GridFilterOperandsCollection_internal();
            }
            this._filterOperands = coll._fromInner(innerColl);
            this.i.ls = innerColl;
        }
        return this._filterOperands;
    }
    set filterOperands(v) {
        if (this._filterOperands !== null) {
            this._filterOperands._setSyncTarget(null);
            this._filterOperands = null;
        }
        let coll = new IgrGridFilterOperandsCollection();
        this._filterOperands = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(FilterOperand.$type);
        let innerColl = this.i.ls;
        if (!innerColl) {
            innerColl = new GridFilterOperandsCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._filterOperands._setSyncTarget(syncColl);
        this.i.ls = innerColl;
    }
    get operatorType() {
        return this.i.lk;
    }
    set operatorType(v) {
        this.i.lk = v;
    }
    get filterValue() {
        return this.i.l6;
    }
    set filterValue(v) {
        this.i.l6 = v;
    }
    get selectorTop() {
        return this.i.l0;
    }
    set selectorTop(v) {
        this.i.l0 = +v;
    }
    get selectorLeft() {
        return this.i.lz;
    }
    set selectorLeft(v) {
        this.i.lz = +v;
    }
    get editorTop() {
        return this.i.ly;
    }
    set editorTop(v) {
        this.i.ly = +v;
    }
    get editorLeft() {
        return this.i.lx;
    }
    set editorLeft(v) {
        this.i.lx = +v;
    }
    get clearIconTop() {
        return this.i.lw;
    }
    set clearIconTop(v) {
        this.i.lw = +v;
    }
    get clearIconLeft() {
        return this.i.lv;
    }
    set clearIconLeft(v) {
        this.i.lv = +v;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.filterOperands != null && this.filterOperands.findByName && this.filterOperands.findByName(name)) {
            return this.filterOperands.findByName(name);
        }
        return null;
    }
}
