import { FilteringLogic_$type } from "./FilteringLogic";
import { FilteringExpressionsTreeType_$type } from "./FilteringExpressionsTreeType";
import { IgrFilteringExpressionsTreeOrFilteringExpression } from "./igr-filtering-expressions-tree-or-filtering-expression";
import { FilteringExpressionsTree as FilteringExpressionsTree_internal } from "./FilteringExpressionsTree";
import { ensureEnum } from "igniteui-react-core";
export class IgrFilteringExpressionsTree {
    createImplementation() {
        let impl = new FilteringExpressionsTree_internal();
        if (impl.setNativeElement) {
            impl.setNativeElement({});
        }
        return impl;
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this.mounted = false;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    /**
     * Sets/gets the filtering operands.
     * ```typescript
     * const gridExpressionsTree = new FilteringExpressionsTree(FilteringLogic.And);
     * const expression = [
     * {
     * condition: IgxStringFilteringOperand.instance().condition('contains'),
     * fieldName: 'Column Field',
     * searchVal: 'Value',
     * ignoreCase: false
     * }];
     * gridExpressionsTree.filteringOperands.push(expression);
     * this.grid.filteringExpressionsTree = gridExpressionsTree;
     * ```
     * ```typescript
     * let filteringOperands = gridExpressionsTree.filteringOperands;
     * ```
     * @memberof FilteringExpressionsTree
    */
    get filteringOperands() {
        if (!this.i.a) {
            return undefined;
        }
        let ret = [];
        for (let i = 0; i < this.i.a.length; i++) {
            let impl = this.i.a[i];
            if (!impl.externalObject) {
                if (impl instanceof IgrFilteringExpressionsTreeOrFilteringExpression) {
                    ret.push(impl);
                    continue;
                }
                let e = new IgrFilteringExpressionsTreeOrFilteringExpression();
                e._implementation = impl;
                impl.externalObject = e;
            }
            ret.push(impl.externalObject);
        }
        return ret;
    }
    set filteringOperands(v) {
        let arr = [];
        for (let i = 0; i < v.length; i++) {
            arr.push(v[i].i);
        }
        this.i.a = arr;
    }
    /**
     * Sets/gets the operator.
     * ```typescript
     * gridExpressionsTree.operator = FilteringLogic.And;
     * ```
     * ```typescript
     * let operator = gridExpressionsTree.operator;
     * ```
     * @memberof FilteringExpressionsTree
    */
    get operator() {
        return this.i.d;
    }
    set operator(v) {
        this.i.d = ensureEnum(FilteringLogic_$type, v);
    }
    /**
     * Sets/gets the field name of the column where the filtering expression is placed.
     * ```typescript
     * gridExpressionTree.fieldName = 'Column Field';
     * ```
     * ```typescript
     * let columnField = expressionTree.fieldName;
     * ```
     * @memberof FilteringExpressionsTree
    */
    get fieldName() {
        return this.i.k;
    }
    set fieldName(v) {
        this.i.k = v;
    }
    /**
     * Sets/gets the type of the filtering expressions tree.
     * ```typescript
     * gridExpressionTree.type = FilteringExpressionsTree.Advanced;
     * ```
     * ```typescript
     * let type = expressionTree.type;
     * ```
     * @memberof FilteringExpressionsTree
    */
    get type() {
        return this.i.c;
    }
    set type(v) {
        this.i.c = ensureEnum(FilteringExpressionsTreeType_$type, v);
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
    /**
     * Checks if filtering expressions tree is empty.
     * expressionTree filtering expressions tree.
    
    * @param expressionTree  * filtering expressions tree.
    */
    empty(expressionTree) {
        let iv = this.i.g((expressionTree == null ? null : expressionTree.i));
        return (iv);
    }
    /**
     * Returns the filtering expression for a column with the provided fieldName.
     * ```typescript
     * let filteringExpression = gridExpressionTree.find('Column Field');
     * ```
     * @memberof FilteringExpressionsTree
    
    */
    find(fieldName) {
        let iv = this.i.b(fieldName);
        let ret = null;
        if (iv && iv.externalObject) {
            ret = iv.externalObject;
        }
        else {
            if (iv) {
                let e = new IgrFilteringExpressionsTreeOrFilteringExpression();
                e._implementation = iv;
                iv.externalObject = e;
                ret = e;
            }
        }
        return ret;
    }
    /**
     * Returns the index of the filtering expression for a column with the provided fieldName.
     * ```typescript
     * let filteringExpressionIndex = gridExpressionTree.findIndex('Column Field');
     * ```
     * @memberof FilteringExpressionsTree
    
    */
    findIndex(fieldName) {
        let iv = this.i.h(fieldName);
        return (iv);
    }
}
