import * as React from 'react';
import { IgrGridActionsBaseDirective } from "./igr-grid-actions-base-directive";
import { GridEditingActions } from "./GridEditingActions";
import { ensureBool } from "igniteui-react-core";
/**
 * Grid Editing Actions for the Action Strip
 * @igxParent IgxActionStripComponent
*/
export class IgrGridEditingActions extends IgrGridActionsBaseDirective {
    createImplementation() {
        let impl = new GridEditingActions();
        let nat;
        if (typeof document !== 'undefined') {
            nat = document.createElement("igc-grid-editing-actions");
        }
        else {
            nat = {
                style: {}
            };
        }
        impl.setNativeElement(nat);
        return impl;
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._getMainRef = this._getMainRef.bind(this);
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("div", {
            ref: this._getMainRef,
            id: this.props.id,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * An input to enable/disable action strip row adding button
    */
    get addRow() {
        return this.i.i;
    }
    set addRow(v) {
        this.i.i = ensureBool(v);
    }
    /**
     * An input to enable/disable action strip row editing button
    */
    get editRow() {
        return this.i.k;
    }
    set editRow(v) {
        this.i.k = ensureBool(v);
    }
    /**
     * An input to enable/disable action strip row deleting button
    */
    get deleteRow() {
        return this.i.j;
    }
    set deleteRow(v) {
        this.i.j = ensureBool(v);
    }
    /**
     * An input to enable/disable action strip child row adding button
    */
    get addChild() {
        return this.i.h;
    }
    set addChild(v) {
        this.i.h = ensureBool(v);
    }
    /**
     * Enter row or cell edit mode depending the grid rowEditable option
     * @example
     * ```typescript
     * this.gridEditingActions.startEdit();
     * ```
    
    */
    startEdit(evt) {
        this.i.l(evt);
    }
}
