import * as React from 'react';
import { IgrGridToolbarBaseActionCollection } from "./igr-grid-toolbar-base-action-collection";
import { IgrGridToolbarContent } from "./igr-grid-toolbar-content";
import { GridToolbarActions } from "./GridToolbarActions";
import { ContentChildrenManager } from "igniteui-react-core";
import { CollectionAdapter } from "igniteui-react-core";
import { GridToolbarBaseAction } from "./GridToolbarBaseAction";
import { NotifyCollectionChangedAction } from "igniteui-react-core";
/**
 * Provides a way to template the action portion of the toolbar in the grid.
 * @igxModule IgxGridToolbarModule
 * @igxParent IgxGridToolbarComponent
 * @example
 * ```html
 * ```
*/
export class IgrGridToolbarActions extends IgrGridToolbarContent {
    createImplementation() {
        let impl = new GridToolbarActions();
        let nat;
        if (typeof document !== 'undefined') {
            nat = document.createElement("igc-grid-toolbar-actions");
        }
        else {
            nat = {
                style: {}
            };
        }
        impl.setNativeElement(nat);
        return impl;
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    _initializeAdapters() {
        if (!this._contentChildrenManager) {
            const resolveNested = ((props, propName, nestedPropName) => {
                var _a;
                const prop = props[propName];
                if (Array.isArray(prop)) {
                    return prop.map(x => {
                        var _a;
                        return (_a = x[nestedPropName]) !== null && _a !== void 0 ? _a : resolveNested(x.props, propName, nestedPropName);
                    }).join("_");
                }
                else if (prop) {
                    return (_a = prop.props[nestedPropName]) !== null && _a !== void 0 ? _a : resolveNested(prop.props, propName, nestedPropName);
                }
                else {
                    return props[nestedPropName];
                }
            });
            this._contentChildrenManager = new ContentChildrenManager((ch) => {
                const key = ch.key || ch.props.name;
                if (!key) {
                    const type = (ch.type);
                    const instance = new type;
                    const name = instance.i.$type.name;
                    switch (name) {
                        case "GridToolbarHiding": return "IgrGridToolbarHiding";
                        case "GridToolbarPinning": return "IgrGridToolbarPinning";
                        case "GridToolbarExporter": return "IgrGridToolbarExporter";
                        case "GridToolbarAdvancedFiltering": return "IgrGridToolbarAdvancedFiltering";
                        default: return undefined;
                    }
                }
                return key;
            }, (ch) => {
                const key = ch.key || ch.props.name;
                if (!key) {
                    const type = (ch.type);
                    const instance = new type;
                    const name = instance.i.$type.name;
                    switch (name) {
                        case "GridToolbarHiding": return "IgrGridToolbarHiding";
                        case "GridToolbarPinning": return "IgrGridToolbarPinning";
                        case "GridToolbarExporter": return "IgrGridToolbarExporter";
                        case "GridToolbarAdvancedFiltering": return "IgrGridToolbarAdvancedFiltering";
                        default: return undefined;
                    }
                }
                return key;
            }, () => {
                if (this._updateContentChildren) {
                    this._updateContentChildren();
                }
                else if (this._updateAdapters) {
                    this._updateAdapters();
                }
            });
        }
        this._actionsAdapter = new CollectionAdapter(this.contentActions, this.i.c, this.actualActions, (c) => c.i, (i) => {
            if (this._initializeElement) {
                this._initializeElement(i);
            }
        }, (i) => {
            if (this._destroyElement) {
                this._destroyElement(i);
            }
        });
        if (super["_initializeAdapters"]) {
            super["_initializeAdapters"]();
        }
    }
    _updateAdapters() {
        if (super["_updateAdapters"]) {
            super["_updateAdapters"]();
        }
        let contentChildrenActual = this._contentChildrenManager.contentChildrenActual;
        this.contentActions.length = 0;
        for (var i = 0; i < contentChildrenActual.length; i++) {
            if ((GridToolbarBaseAction.$type).isAssignableFrom(contentChildrenActual[i].i.$type)) {
                this.contentActions.push(contentChildrenActual[i]);
            }
        }
        if (this._actionsAdapter != null) {
            this._actionsAdapter.notifyContentChanged();
        }
    }
    constructor(props) {
        super(props);
        this._actions = null;
        this._getMainRef = this._getMainRef.bind(this);
    }
    componentDidMount() {
        this.mounted = true;
        super.componentDidMount();
    }
    render() {
        let children = this._contentChildrenManager.getChildren(this.props.children);
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("div", {
            ref: this._getMainRef,
            id: this.props.id,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    get actualActions() {
        if (!this._actualActions) {
            this._actualActions = [];
        }
        return this._actualActions;
    }
    get contentActions() {
        if (!this._contentActions) {
            this._contentActions = [];
        }
        return this._contentActions;
    }
    get actions() {
        if (this._actions === null) {
            let coll = new IgrGridToolbarBaseActionCollection();
            let inner = coll._innerColl;
            this._actions = coll;
            inner.addListener((sender, e) => {
                switch (e.action) {
                    case NotifyCollectionChangedAction.Add:
                        this._actionsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                        break;
                    case NotifyCollectionChangedAction.Remove:
                        this._actionsAdapter.removeManualItemAt(e.oldStartingIndex);
                        break;
                    case NotifyCollectionChangedAction.Replace:
                        this._actionsAdapter.removeManualItemAt(e.oldStartingIndex);
                        this._actionsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                        break;
                    case NotifyCollectionChangedAction.Reset:
                        this._actionsAdapter.clearManualItems();
                        break;
                }
            });
            ;
        }
        return this._actions;
    }
    get name() {
        return this.i.a;
    }
    set name(v) {
        this.i.a = v;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.actions != null && this.actions.findByName && this.actions.findByName(name)) {
            return this.actions.findByName(name);
        }
        return null;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
}
