import * as React from 'react';
import { IgrGridToolbarBaseAction } from "./igr-grid-toolbar-base-action";
import { GridToolbarAdvancedFiltering } from "./GridToolbarAdvancedFiltering";
import { interfaceToInternal } from "igniteui-react-core";
import { OverlaySettings } from "./OverlaySettings";
/**
 * Provides a pre-configured button to open the advanced filtering dialog of the grid.
 * @igxModule IgxGridToolbarModule
 * @igxParent IgxGridToolbarComponent
 * @example
 * ```html
 * Custom text
 * ```
*/
export class IgrGridToolbarAdvancedFiltering extends IgrGridToolbarBaseAction {
    createImplementation() {
        let impl = new GridToolbarAdvancedFiltering();
        let nat;
        if (typeof document !== 'undefined') {
            nat = document.createElement("igc-grid-toolbar-advanced-filtering");
        }
        else {
            nat = {
                style: {}
            };
        }
        impl.setNativeElement(nat);
        return impl;
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
        super.onImplementationCreated();
        this._portalManager.getPortal(this._renderer.getWrapper(this._implementation.nativeElement), "ChildContent", (p) => { }, true);
    }
    constructor(props) {
        super(props);
        this._getMainRef = this._getMainRef.bind(this);
    }
    componentDidMount() {
        this.mounted = true;
        super.componentDidMount();
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("div", {
            ref: this._getMainRef,
            id: this.props.id,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    get overlaySettings() {
        return this.i.b.nativeElement;
    }
    set overlaySettings(v) {
        this.i.b = interfaceToInternal(v, () => new OverlaySettings());
    }
    get name() {
        return this.i.a;
    }
    set name(v) {
        this.i.a = v;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.overlaySettings && this.overlaySettings.name && this.overlaySettings.name == name) {
            return this.overlaySettings;
        }
        return null;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
}
