import * as React from 'react';
import { IgrGridToolbarContent } from "./igr-grid-toolbar-content";
import { GridToolbarTitle } from "./GridToolbarTitle";
/**
 * Provides a way to template the title portion of the toolbar in the grid.
 * @igxModule IgxGridToolbarModule
 * @igxParent IgxGridToolbarComponent
 * @example
 * ```html
 * My custom title
 * ```
*/
export class IgrGridToolbarTitle extends IgrGridToolbarContent {
    createImplementation() {
        let impl = new GridToolbarTitle();
        let nat;
        if (typeof document !== 'undefined') {
            nat = document.createElement("igc-grid-toolbar-title");
        }
        else {
            nat = {
                style: {}
            };
        }
        impl.setNativeElement(nat);
        return impl;
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
        super.onImplementationCreated();
        this._portalManager.getPortal(this._renderer.getWrapper(this._implementation.nativeElement), "ChildContent", (p) => { }, true);
    }
    constructor(props) {
        super(props);
        this._getMainRef = this._getMainRef.bind(this);
    }
    componentDidMount() {
        this.mounted = true;
        super.componentDidMount();
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("div", {
            ref: this._getMainRef,
            id: this.props.id,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    get name() {
        return this.i.a;
    }
    set name(v) {
        this.i.a = v;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
}
