import * as React from 'react';
import { IgrGridToolbarContentCollection } from "./igr-grid-toolbar-content-collection";
import { IgrDisplayDensityBaseElement } from "./igr-display-density-base-element";
import { GridToolbar } from "./GridToolbar";
import { ContentChildrenManager } from "igniteui-react-core";
import { CollectionAdapter, ensureBool } from "igniteui-react-core";
import { GridToolbarContent } from "./GridToolbarContent";
import { NotifyCollectionChangedAction } from "igniteui-react-core";
/**
 * Provides a context-aware container component for UI operations for the grid components.
 * @igxModule IgxGridToolbarModule
 * @igxParent IgxGridComponent, IgxTreeGridComponent, IgxHierarchicalGridComponent, IgxPivotGridComponent
*/
export class IgrGridToolbar extends IgrDisplayDensityBaseElement {
    createImplementation() {
        let impl = new GridToolbar();
        let nat;
        if (typeof document !== 'undefined') {
            nat = document.createElement("igc-grid-toolbar");
        }
        else {
            nat = {
                style: {}
            };
        }
        impl.setNativeElement(nat);
        return impl;
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
        super.onImplementationCreated();
        this._portalManager.getPortal(this._renderer.getWrapper(this._implementation.nativeElement), "ChildContent", (p) => { }, true);
    }
    _initializeAdapters() {
        if (!this._contentChildrenManager) {
            const resolveNested = ((props, propName, nestedPropName) => {
                var _a;
                const prop = props[propName];
                if (Array.isArray(prop)) {
                    return prop.map(x => {
                        var _a;
                        return (_a = x[nestedPropName]) !== null && _a !== void 0 ? _a : resolveNested(x.props, propName, nestedPropName);
                    }).join("_");
                }
                else if (prop) {
                    return (_a = prop.props[nestedPropName]) !== null && _a !== void 0 ? _a : resolveNested(prop.props, propName, nestedPropName);
                }
                else {
                    return props[nestedPropName];
                }
            });
            this._contentChildrenManager = new ContentChildrenManager((ch) => {
                const key = ch.key || ch.props.name;
                if (!key) {
                    const type = (ch.type);
                    const instance = new type;
                    const name = instance.i.$type.name;
                    switch (name) {
                        case "GridToolbarActions": return "IgrGridToolbarActions";
                        case "GridToolbarTitle": return "IgrGridToolbarTitle";
                        default: return undefined;
                    }
                }
                return key;
            }, (ch) => {
                const key = ch.key || ch.props.name;
                if (!key) {
                    const type = (ch.type);
                    const instance = new type;
                    const name = instance.i.$type.name;
                    switch (name) {
                        case "GridToolbarActions": return "IgrGridToolbarActions";
                        case "GridToolbarTitle": return "IgrGridToolbarTitle";
                        default: return undefined;
                    }
                }
                return key;
            }, () => {
                if (this._updateContentChildren) {
                    this._updateContentChildren();
                }
                else if (this._updateAdapters) {
                    this._updateAdapters();
                }
            });
        }
        this._toolsAdapter = new CollectionAdapter(this.contentTools, this.i.k, this.actualTools, (c) => c.i, (i) => {
            if (this._initializeElement) {
                this._initializeElement(i);
            }
        }, (i) => {
            if (this._destroyElement) {
                this._destroyElement(i);
            }
        });
        if (super["_initializeAdapters"]) {
            super["_initializeAdapters"]();
        }
    }
    _updateAdapters() {
        if (super["_updateAdapters"]) {
            super["_updateAdapters"]();
        }
        let contentChildrenActual = this._contentChildrenManager.contentChildrenActual;
        this.contentTools.length = 0;
        for (var i = 0; i < contentChildrenActual.length; i++) {
            if ((GridToolbarContent.$type).isAssignableFrom(contentChildrenActual[i].i.$type)) {
                this.contentTools.push(contentChildrenActual[i]);
            }
        }
        if (this._toolsAdapter != null) {
            this._toolsAdapter.notifyContentChanged();
        }
    }
    constructor(props) {
        super(props);
        this._tools = null;
        this._getMainRef = this._getMainRef.bind(this);
    }
    componentDidMount() {
        this.mounted = true;
        super.componentDidMount();
    }
    render() {
        let children = this._contentChildrenManager.getChildren(this.props.children);
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("div", {
            ref: this._getMainRef,
            id: this.props.id,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * When enabled, shows the indeterminate progress bar.
     * @remarks
     * By default this will be toggled, when the default exporter component is present
     * and an exporting is in progress.
    */
    get showProgress() {
        return this.i.l;
    }
    set showProgress(v) {
        this.i.l = ensureBool(v);
    }
    /**
     * Gets/sets the grid component for the toolbar component.
     * @remarks
     * Usually you should not set this property in the context of the default grid/tree grid.
     * The only grids that demands this to be set are the hierarchical child grids. For additional
     * information check the toolbar topic.
    */
    get grid() {
        const r = this.i.i;
        if (r == null) {
            return null;
        }
        return r.externalObject;
    }
    set grid(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.i = null : this.i.i = v.i;
    }
    get name() {
        return this.i.m;
    }
    set name(v) {
        this.i.m = v;
    }
    get actualTools() {
        if (!this._actualTools) {
            this._actualTools = [];
        }
        return this._actualTools;
    }
    get contentTools() {
        if (!this._contentTools) {
            this._contentTools = [];
        }
        return this._contentTools;
    }
    get tools() {
        if (this._tools === null) {
            let coll = new IgrGridToolbarContentCollection();
            let inner = coll._innerColl;
            this._tools = coll;
            inner.addListener((sender, e) => {
                switch (e.action) {
                    case NotifyCollectionChangedAction.Add:
                        this._toolsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                        break;
                    case NotifyCollectionChangedAction.Remove:
                        this._toolsAdapter.removeManualItemAt(e.oldStartingIndex);
                        break;
                    case NotifyCollectionChangedAction.Replace:
                        this._toolsAdapter.removeManualItemAt(e.oldStartingIndex);
                        this._toolsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                        break;
                    case NotifyCollectionChangedAction.Reset:
                        this._toolsAdapter.clearManualItems();
                        break;
                }
            });
            ;
        }
        return this._tools;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.grid && this.grid.name && this.grid.name == name) {
            return this.grid;
        }
        if (this.tools != null && this.tools.findByName && this.tools.findByName(name)) {
            return this.tools.findByName(name);
        }
        return null;
    }
    _styling(container, component, parent) {
        super._styling(container, component, parent);
        this._inStyling = true;
        if (this.grid && this.grid._styling) {
            this.grid._styling(container, component, this);
        }
        this._inStyling = false;
    }
}
