import { SortIndicatorStyle_$type } from "./SortIndicatorStyle";
import { IgrDefinitionBase } from "./igr-definition-base";
import { brushToString, stringToBrush, ensureEnum } from "igniteui-react-core";
/**
 * Represents a base class used to configure the appearance of the column header cells.
*/
export class IgrHeader extends IgrDefinitionBase {
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets the color to use for the sort indicator icon
    */
    get sortIndicatorColor() {
        return brushToString(this.i.fc);
    }
    set sortIndicatorColor(v) {
        this.i.fc = stringToBrush(v);
    }
    /**
     * Gets the actual background color that is used for the cells when they are selected
    */
    get actualSortIndicatorColor() {
        return brushToString(this.i.fa);
    }
    set actualSortIndicatorColor(v) {
        this.i.fa = stringToBrush(v);
    }
    get sortIndicatorStyle() {
        return this.i.ep;
    }
    set sortIndicatorStyle(v) {
        this.i.ep = ensureEnum(SortIndicatorStyle_$type, v);
    }
    get actualSortIndicatorStyle() {
        return this.i.eo;
    }
    set actualSortIndicatorStyle(v) {
        this.i.eo = ensureEnum(SortIndicatorStyle_$type, v);
    }
    /**
     * Gets or sets the amount of left padding to use for the cell content.
    */
    get paddingLeft() {
        return this.i.ev;
    }
    set paddingLeft(v) {
        this.i.ev = +v;
    }
    /**
     * Gets or sets the amount of top padding to use for the cell content.
    */
    get paddingTop() {
        return this.i.ex;
    }
    set paddingTop(v) {
        this.i.ex = +v;
    }
    /**
     * Gets or sets the amount of right padding to use for the cell content.
    */
    get paddingRight() {
        return this.i.ew;
    }
    set paddingRight(v) {
        this.i.ew = +v;
    }
    /**
     * Gets or sets the amount of bottom padding to use for the cell content.
    */
    get paddingBottom() {
        return this.i.eu;
    }
    set paddingBottom(v) {
        this.i.eu = +v;
    }
}
