import { IgrCellInfo } from "./igr-cell-info";
import { NumericCellModel as NumericCellModel_internal } from "./NumericCellModel";
import { ensureBool, arrayFindByName } from "igniteui-react-core";
/**
 * Backing information for a numeric cell in the grid.
*/
export class IgrNumericCellInfo extends IgrCellInfo {
    createImplementation() {
        return new NumericCellModel_internal();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
    /**
     * Sets or gets the numeric value to use for the cell.
    */
    get numericValue() {
        return this.i.ls;
    }
    set numericValue(v) {
        this.i.ls = +v;
    }
    /**
     * Sets or gets whether there is a decimal numeric value to use for the cell.
    */
    get hasDecimalValue() {
        return this.i.lo;
    }
    set hasDecimalValue(v) {
        this.i.lo = ensureBool(v);
    }
    /**
     * The format string to apply to the value
    */
    get formatStringOverride() {
        return this.i.mm;
    }
    set formatStringOverride(v) {
        this.i.mm = v;
    }
    get formatSpecifiers() {
        return this.i.lk;
    }
    set formatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.lk = v;
    }
    /**
     * The format options to apply to the value
    */
    get formatOverride() {
        return this.i.me;
    }
    set formatOverride(v) {
        this.i.me = v;
    }
    /**
     * Sets or gets the text prepended to a negative numeric value
    */
    get negativePrefix() {
        return this.i.ms;
    }
    set negativePrefix(v) {
        this.i.ms = v;
    }
    /**
     * Sets or gets the text prepended to a positive numeric value
    */
    get positivePrefix() {
        return this.i.mx;
    }
    set positivePrefix(v) {
        this.i.mx = v;
    }
    /**
     * Sets or gets the text appended to a negative numeric value
    */
    get negativeSuffix() {
        return this.i.mu;
    }
    set negativeSuffix(v) {
        this.i.mu = v;
    }
    /**
     * Sets or gets the text appended to a positive numeric value
    */
    get positiveSuffix() {
        return this.i.mz;
    }
    set positiveSuffix(v) {
        this.i.mz = v;
    }
    /**
     * The maximum number of decimal places to display when formatting
    */
    get maxFractionDigits() {
        return this.i.l0;
    }
    set maxFractionDigits(v) {
        this.i.l0 = +v;
    }
    /**
     * The minimum number of decimal places to display when formatting
    */
    get minFractionDigits() {
        return this.i.l2;
    }
    set minFractionDigits(v) {
        this.i.l2 = +v;
    }
    /**
     * The minimum number of integer digits to display when formatting
    */
    get minIntegerDigits() {
        return this.i.l4;
    }
    set minIntegerDigits(v) {
        this.i.l4 = +v;
    }
    /**
     * Sets or gets if the grouping separator is shown
    */
    get showGroupingSeparator() {
        return this.i.lq;
    }
    set showGroupingSeparator(v) {
        this.i.lq = ensureBool(v);
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.formatSpecifiers != null && arrayFindByName(this.formatSpecifiers, name)) {
            return arrayFindByName(this.formatSpecifiers, name);
        }
        return null;
    }
}
