import { EditorType_$type } from "./EditorType";
import { IgrDataGridColumn } from "./igr-data-grid-column";
import { NumericColumn } from "./NumericColumn";
import { ensureBool, ensureEnum, arrayFindByName } from "igniteui-react-core";
/**
 * Represents a Numeric grid column, used to allow the developer to display a formatted number in a cell.
*/
export class IgrNumericColumn extends IgrDataGridColumn {
    createImplementation() {
        return new NumericColumn();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets the string to prefix a negative value. If FormatString is specificied this value is ignored.
    */
    get negativePrefix() {
        return this.i.mg;
    }
    set negativePrefix(v) {
        this.i.mg = v;
    }
    /**
     * Gets or sets the string to prefix a positive value. If FormatString is specificied this value is ignored.
    */
    get positivePrefix() {
        return this.i.mk;
    }
    set positivePrefix(v) {
        this.i.mk = v;
    }
    /**
     * Gets or sets the string to suffix a negative value. If FormatString is specificied this value is ignored.
    */
    get negativeSuffix() {
        return this.i.mi;
    }
    set negativeSuffix(v) {
        this.i.mi = v;
    }
    /**
     * Gets or sets the string to suffix a positive value. If FormatString is specificied this value is ignored.
    */
    get positiveSuffix() {
        return this.i.mm;
    }
    set positiveSuffix(v) {
        this.i.mm = v;
    }
    /**
     * Gets or sets the maximum fraction digits. If FormatString is specificied this value is ignored.
    */
    get maxFractionDigits() {
        return this.i.lv;
    }
    set maxFractionDigits(v) {
        this.i.lv = +v;
    }
    /**
     * Gets or sets the minimum fraction digits. If FormatString is specificied this value is ignored.
    */
    get minFractionDigits() {
        return this.i.lw;
    }
    set minFractionDigits(v) {
        this.i.lw = +v;
    }
    /**
     * Gets or sets the minimum integer digits. If FormatString is specificied this value is ignored.
    */
    get minIntegerDigits() {
        return this.i.lx;
    }
    set minIntegerDigits(v) {
        this.i.lx = +v;
    }
    /**
     * Gets or sets whether to show a grouping separator. If FormatString is specificied this value is ignored.
    */
    get showGroupingSeparator() {
        return this.i.lq;
    }
    set showGroupingSeparator(v) {
        this.i.lq = ensureBool(v);
    }
    /**
     * Gets or sets the format string to apply to the value. If set, the other value formatting properties on this column are ignored.
    */
    get formatString() {
        return this.i.mb;
    }
    set formatString(v) {
        this.i.mb = v;
    }
    get formatSpecifiers() {
        return this.i.lm;
    }
    set formatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.lm = v;
    }
    /**
     * Gets or sets the INTL NumericFormat object to use for formatting the date values.
    */
    get formatOverride() {
        return this.i.l0;
    }
    set formatOverride(v) {
        this.i.l0 = v;
    }
    /**
     * Gets or sets the editor type used for editing cells in this column.
    */
    get editorType() {
        return this.i.lo;
    }
    set editorType(v) {
        this.i.lo = ensureEnum(EditorType_$type, v);
    }
    /**
     * Gets or sets the ComboBox data source.
    */
    get editorDataSource() {
        return this.i.lz;
    }
    set editorDataSource(v) {
        this.i.lz = v;
    }
    /**
     * Gets or sets the ComboBox text field.
    */
    get editorTextField() {
        return this.i.l6;
    }
    set editorTextField(v) {
        this.i.l6 = v;
    }
    /**
     * Gets or sets the ComboBox value field.
    */
    get editorValueField() {
        return this.i.l7;
    }
    set editorValueField(v) {
        this.i.l7 = v;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.formatSpecifiers != null && arrayFindByName(this.formatSpecifiers, name)) {
            return arrayFindByName(this.formatSpecifiers, name);
        }
        return null;
    }
}
