import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrNumberEventArgs } from "igniteui-react";
import { IgrPageCancellableEventArgs } from "./igr-page-cancellable-event-args";
import { IgrPageEventArgs } from "./igr-page-event-args";
import { IgrDisplayDensityBaseElement } from "./igr-display-density-base-element";
import { Paginator } from "./Paginator";
import { interfaceToInternal } from "igniteui-react-core";
import { OverlaySettings } from "./OverlaySettings";
import { PaginatorResourceStrings } from "./PaginatorResourceStrings";
/**
 * Paginator component description
 * @igxParent IgxGridComponent, IgxTreeGridComponent, IgxHierarchicalGridComponent, IgxPivotGridComponent, *
*/
export class IgrPaginator extends IgrDisplayDensityBaseElement {
    createImplementation() {
        let impl = new Paginator();
        let nat;
        if (typeof document !== 'undefined') {
            nat = document.createElement("igc-paginator");
        }
        else {
            nat = {
                style: {}
            };
        }
        impl.setNativeElement(nat);
        return impl;
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._perPageChange = null;
        this._perPageChange_wrapped = null;
        this._pageChange = null;
        this._pageChange_wrapped = null;
        this._paging = null;
        this._paging_wrapped = null;
        this._pagingDone = null;
        this._pagingDone_wrapped = null;
        this._getMainRef = this._getMainRef.bind(this);
    }
    componentDidMount() {
        this.mounted = true;
        super.componentDidMount();
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("div", {
            ref: this._getMainRef,
            id: this.props.id,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * Total pages calculated from totalRecords and perPage
    */
    get totalPages() {
        return this.i.r;
    }
    set totalPages(v) {
        this.i.r = +v;
    }
    /**
     * An @Input property, sets current page of the `IgxPaginatorComponent`.
     * The default is 0.
     * ```typescript
     * let page = this.paginator.page;
     * ```
     * @memberof IgxPaginatorComponent
    */
    get page() {
        return this.i.p;
    }
    set page(v) {
        this.i.p = +v;
    }
    /**
     * An @Input property, sets number of visible items per page in the `IgxPaginatorComponent`.
     * The default is 15.
     * ```typescript
     * let itemsPerPage = this.paginator.perPage;
     * ```
     * @memberof IgxPaginatorComponent
    */
    get perPage() {
        return this.i.q;
    }
    set perPage(v) {
        this.i.q = +v;
    }
    /**
     * An @Input property that sets the total records.
     * ```typescript
     * let totalRecords = this.paginator.totalRecords;
     * ```
     * @memberof IgxPaginatorComponent
    */
    get totalRecords() {
        return this.i.s;
    }
    set totalRecords(v) {
        this.i.s = +v;
    }
    /**
     * An @Input property that sets custom options in the select of the paginator
     * ```typescript
     * let options = this.paginator.selectOptions;
     * ```
     * @memberof IgxPaginatorComponent
    */
    get selectOptions() {
        return this.i.i;
    }
    set selectOptions(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.i = v;
    }
    get overlaySettings() {
        return this.i.l.nativeElement;
    }
    set overlaySettings(v) {
        this.i.l = interfaceToInternal(v, () => new OverlaySettings());
    }
    /**
     * An accessor that sets the resource strings.
     * By default it uses EN resources.
    */
    get resourceStrings() {
        return this.i.o.nativeElement;
    }
    set resourceStrings(v) {
        this.i.o = interfaceToInternal(v, () => new PaginatorResourceStrings());
    }
    get name() {
        return this.i.t;
    }
    set name(v) {
        this.i.t = v;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.overlaySettings && this.overlaySettings.name && this.overlaySettings.name == name) {
            return this.overlaySettings;
        }
        if (this.resourceStrings && this.resourceStrings.name && this.resourceStrings.name == name) {
            return this.resourceStrings;
        }
        return null;
    }
    /**
     * Goes to the next page of the `IgxPaginatorComponent`, if the paginator is not already at the last page.
     * ```typescript
     * this.paginator.nextPage();
     * ```
     * @memberof IgxPaginatorComponent
    
    */
    nextPage() {
        this.i.u();
    }
    /**
     * Goes to the previous page of the `IgxPaginatorComponent`, if the paginator is not already at the first page.
     * ```typescript
     * this.paginator.previousPage();
     * ```
     * @memberof IgxPaginatorComponent
    
    */
    previousPage() {
        this.i.aa();
    }
    /**
     * Goes to the desired page index.
     * ```typescript
     * this.paginator.paginate(1);
     * ```
     * val
     * @memberof IgxPaginatorComponent
    
    * @param   * val
    */
    paginate(val) {
        this.i.w(val);
    }
    get perPageChange() {
        return this._perPageChange;
    }
    set perPageChange(ev) {
        if (this._perPageChange_wrapped !== null) {
            this.i.perPageChange = delegateRemove(this.i.perPageChange, this._perPageChange_wrapped);
            this._perPageChange_wrapped = null;
            this._perPageChange = null;
        }
        this._perPageChange = ev;
        this._perPageChange_wrapped = (o, e) => {
            let outerArgs = new IgrNumberEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforePerPageChange) {
                this.beforePerPageChange(this, outerArgs);
            }
            if (this._perPageChange) {
                this._perPageChange(this, outerArgs);
            }
        };
        this.i.perPageChange = delegateCombine(this.i.perPageChange, this._perPageChange_wrapped);
        if (this.i.perPageChangeChanged) {
            this.i.perPageChangeChanged();
        }
        ;
    }
    get pageChange() {
        return this._pageChange;
    }
    set pageChange(ev) {
        if (this._pageChange_wrapped !== null) {
            this.i.pageChange = delegateRemove(this.i.pageChange, this._pageChange_wrapped);
            this._pageChange_wrapped = null;
            this._pageChange = null;
        }
        this._pageChange = ev;
        this._pageChange_wrapped = (o, e) => {
            let outerArgs = new IgrNumberEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforePageChange) {
                this.beforePageChange(this, outerArgs);
            }
            if (this._pageChange) {
                this._pageChange(this, outerArgs);
            }
        };
        this.i.pageChange = delegateCombine(this.i.pageChange, this._pageChange_wrapped);
        if (this.i.pageChangeChanged) {
            this.i.pageChangeChanged();
        }
        ;
    }
    get paging() {
        return this._paging;
    }
    set paging(ev) {
        if (this._paging_wrapped !== null) {
            this.i.paging = delegateRemove(this.i.paging, this._paging_wrapped);
            this._paging_wrapped = null;
            this._paging = null;
        }
        this._paging = ev;
        this._paging_wrapped = (o, e) => {
            let outerArgs = new IgrPageCancellableEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforePaging) {
                this.beforePaging(this, outerArgs);
            }
            if (this._paging) {
                this._paging(this, outerArgs);
            }
        };
        this.i.paging = delegateCombine(this.i.paging, this._paging_wrapped);
        if (this.i.pagingChanged) {
            this.i.pagingChanged();
        }
        ;
    }
    get pagingDone() {
        return this._pagingDone;
    }
    set pagingDone(ev) {
        if (this._pagingDone_wrapped !== null) {
            this.i.pagingDone = delegateRemove(this.i.pagingDone, this._pagingDone_wrapped);
            this._pagingDone_wrapped = null;
            this._pagingDone = null;
        }
        this._pagingDone = ev;
        this._pagingDone_wrapped = (o, e) => {
            let outerArgs = new IgrPageEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforePagingDone) {
                this.beforePagingDone(this, outerArgs);
            }
            if (this._pagingDone) {
                this._pagingDone(this, outerArgs);
            }
        };
        this.i.pagingDone = delegateCombine(this.i.pagingDone, this._pagingDone_wrapped);
        if (this.i.pagingDoneChanged) {
            this.i.pagingDoneChanged();
        }
        ;
    }
}
