import { IgrPivotDimensionCollection } from "./igr-pivot-dimension-collection";
import { IgrPivotValueCollection } from "./igr-pivot-value-collection";
import { IgrPivotKeys } from "./igr-pivot-keys";
import { PivotConfiguration as PivotConfiguration_internal } from "./PivotConfiguration";
import { interfaceToInternal } from "igniteui-react-core";
import { PivotDimensionStrategy } from "./PivotDimensionStrategy";
import { PivotDimensionCollection as PivotDimensionCollection_internal } from "./PivotDimensionCollection";
import { PivotDimension } from "./PivotDimension";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
import { PivotValueCollection as PivotValueCollection_internal } from "./PivotValueCollection";
import { PivotValue } from "./PivotValue";
/**
 * Configuration of the pivot grid.
*/
export class IgrPivotConfiguration {
    createImplementation() {
        let impl = new PivotConfiguration_internal();
        if (impl.setNativeElement) {
            impl.setNativeElement({});
        }
        return impl;
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this.mounted = false;
        this._rows = null;
        this._columns = null;
        this._values = null;
        this._filters = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    /**
     * A strategy to transform the rows.
    */
    get rowStrategy() {
        return this.i.e.nativeElement;
    }
    set rowStrategy(v) {
        this.i.e = interfaceToInternal(v, () => new PivotDimensionStrategy());
    }
    /**
     * A strategy to transform the columns.
    */
    get columnStrategy() {
        return this.i.d.nativeElement;
    }
    set columnStrategy(v) {
        this.i.d = interfaceToInternal(v, () => new PivotDimensionStrategy());
    }
    /**
     * A list of the rows.
    */
    get rows() {
        if (this._rows === null) {
            let coll = new IgrPivotDimensionCollection();
            let innerColl = this.i.c;
            if (!innerColl) {
                innerColl = new PivotDimensionCollection_internal();
            }
            this._rows = coll._fromInner(innerColl);
        }
        return this._rows;
    }
    set rows(v) {
        if (this._rows !== null) {
            this._rows._setSyncTarget(null);
            this._rows = null;
        }
        let coll = new IgrPivotDimensionCollection();
        this._rows = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(PivotDimension.$type);
        let innerColl = this.i.c;
        if (!innerColl) {
            innerColl = new PivotDimensionCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._rows._setSyncTarget(syncColl);
    }
    /**
     * A list of the columns.
    */
    get columns() {
        if (this._columns === null) {
            let coll = new IgrPivotDimensionCollection();
            let innerColl = this.i.a;
            if (!innerColl) {
                innerColl = new PivotDimensionCollection_internal();
            }
            this._columns = coll._fromInner(innerColl);
        }
        return this._columns;
    }
    set columns(v) {
        if (this._columns !== null) {
            this._columns._setSyncTarget(null);
            this._columns = null;
        }
        let coll = new IgrPivotDimensionCollection();
        this._columns = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(PivotDimension.$type);
        let innerColl = this.i.a;
        if (!innerColl) {
            innerColl = new PivotDimensionCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._columns._setSyncTarget(syncColl);
    }
    /**
     * A list of the values.
    */
    get values() {
        if (this._values === null) {
            let coll = new IgrPivotValueCollection();
            let innerColl = this.i.g;
            if (!innerColl) {
                innerColl = new PivotValueCollection_internal();
            }
            this._values = coll._fromInner(innerColl);
        }
        return this._values;
    }
    set values(v) {
        if (this._values !== null) {
            this._values._setSyncTarget(null);
            this._values = null;
        }
        let coll = new IgrPivotValueCollection();
        this._values = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(PivotValue.$type);
        let innerColl = this.i.g;
        if (!innerColl) {
            innerColl = new PivotValueCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._values._setSyncTarget(syncColl);
    }
    /**
     * Dimensions to be displayed in the filter area.
    */
    get filters() {
        if (this._filters === null) {
            let coll = new IgrPivotDimensionCollection();
            let innerColl = this.i.b;
            if (!innerColl) {
                innerColl = new PivotDimensionCollection_internal();
            }
            this._filters = coll._fromInner(innerColl);
        }
        return this._filters;
    }
    set filters(v) {
        if (this._filters !== null) {
            this._filters._setSyncTarget(null);
            this._filters = null;
        }
        let coll = new IgrPivotDimensionCollection();
        this._filters = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(PivotDimension.$type);
        let innerColl = this.i.b;
        if (!innerColl) {
            innerColl = new PivotDimensionCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._filters._setSyncTarget(syncColl);
    }
    /**
     * Pivot data keys used for data generation. Can be used for custom remote scenarios where the data is pre-populated.
    */
    get pivotKeys() {
        const r = this.i.f;
        if (r == null) {
            return null;
        }
        if (!r.externalObject) {
            let e = new IgrPivotKeys();
            if (r.$type) {
                e._implementation = r;
            }
            else {
                if (e.i.setNativeElement) {
                    e.i.setNativeElement(r);
                }
            }
            r.externalObject = e;
        }
        return r.externalObject;
    }
    set pivotKeys(v) {
        v == null ? this.i.f = null : this.i.f = v.i;
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        if (this.rowStrategy && this.rowStrategy.name && this.rowStrategy.name == name) {
            return this.rowStrategy;
        }
        if (this.columnStrategy && this.columnStrategy.name && this.columnStrategy.name == name) {
            return this.columnStrategy;
        }
        if (this.rows != null && this.rows.findByName && this.rows.findByName(name)) {
            return this.rows.findByName(name);
        }
        if (this.columns != null && this.columns.findByName && this.columns.findByName(name)) {
            return this.columns.findByName(name);
        }
        if (this.values != null && this.values.findByName && this.values.findByName(name)) {
            return this.values.findByName(name);
        }
        if (this.filters != null && this.filters.findByName && this.filters.findByName(name)) {
            return this.filters.findByName(name);
        }
        if (this.pivotKeys && this.pivotKeys.name && this.pivotKeys.name == name) {
            return this.pivotKeys;
        }
        return null;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
}
