import { GridColumnDataType_$type } from "./GridColumnDataType";
import { IgrPivotDimension } from "./igr-pivot-dimension";
import { PivotDateDimension as PivotDateDimension_internal } from "./PivotDateDimension";
import { ensureBool, ensureEnum, interfaceToInternal } from "igniteui-react-core";
import { GridResourceStrings } from "./GridResourceStrings";
import { PivotDateDimensionOptions } from "./PivotDateDimensionOptions";
export class IgrPivotDateDimension extends IgrPivotDimension {
    createImplementation() {
        let impl = new PivotDateDimension_internal();
        if (impl.setNativeElement) {
            impl.setNativeElement({});
        }
        return impl;
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
    /**
     * Enables/Disables a particular dimension from pivot structure.
    */
    get enabled() {
        return this.i.t;
    }
    set enabled(v) {
        this.i.t = ensureBool(v);
    }
    /**
     * Gets/Sets data type
    */
    get dataType() {
        return this.i.p;
    }
    set dataType(v) {
        this.i.p = ensureEnum(GridColumnDataType_$type, v);
    }
    /**
     * Gets/Sets the resource strings.
     * @remarks
     * By default it uses EN resources.
    */
    get resourceStrings() {
        return this.i.q.nativeElement;
    }
    set resourceStrings(v) {
        this.i.q = interfaceToInternal(v, () => new GridResourceStrings());
    }
    /**
     * Gets/Sets the base dimension that is used by this class to determine the other dimensions and their values.
     * Having base dimension set is required in order for the Date Dimensions to show.
    */
    get baseDimension() {
        const r = this.i.s;
        if (r == null) {
            return null;
        }
        if (!r.externalObject) {
            let e = new IgrPivotDimension();
            if (r.$type) {
                e._implementation = r;
            }
            else {
                if (e.i.setNativeElement) {
                    e.i.setNativeElement(r);
                }
            }
            r.externalObject = e;
        }
        return r.externalObject;
    }
    set baseDimension(v) {
        v == null ? this.i.s = null : this.i.s = v.i;
    }
    /**
     * Gets/Sets the options for the predefined date dimensions whether to show quarter, years and etc.
    */
    get options() {
        return this.i.r.nativeElement;
    }
    set options(v) {
        this.i.r = interfaceToInternal(v, () => new PivotDateDimensionOptions());
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.resourceStrings && this.resourceStrings.name && this.resourceStrings.name == name) {
            return this.resourceStrings;
        }
        if (this.baseDimension && this.baseDimension.name && this.baseDimension.name == name) {
            return this.baseDimension;
        }
        if (this.options && this.options.name && this.options.name == name) {
            return this.options;
        }
        return null;
    }
}
