import { IgrPivotAggregator } from "./igr-pivot-aggregator";
import { IgrPivotAggregatorCollection } from "./igr-pivot-aggregator-collection";
import { GridColumnDataType_$type } from "./GridColumnDataType";
import { PivotValue as PivotValue_internal } from "./PivotValue";
import { PivotAggregatorCollection as PivotAggregatorCollection_internal } from "./PivotAggregatorCollection";
import { PivotAggregator } from "./PivotAggregator";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
import { ensureBool, ensureEnum } from "igniteui-react-core";
/**
 * Configuration of a pivot value aggregation.
*/
export class IgrPivotValue {
    createImplementation() {
        let impl = new PivotValue_internal();
        if (impl.setNativeElement) {
            impl.setNativeElement({});
        }
        return impl;
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this.mounted = false;
        this._aggregateList = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    /**
     * Field name to use in order to extract value.
    */
    get member() {
        return this.i.l;
    }
    set member(v) {
        this.i.l = v;
    }
    /**
     * Display name to show instead of member for the column header of this value. *
    */
    get displayName() {
        return this.i.k;
    }
    set displayName(v) {
        this.i.k = v;
    }
    /**
     * Active aggregator definition with key, label and aggregator.
    */
    get aggregate() {
        const r = this.i.b;
        if (r == null) {
            return null;
        }
        if (!r.externalObject) {
            let e = new IgrPivotAggregator();
            if (r.$type) {
                e._implementation = r;
            }
            else {
                if (e.i.setNativeElement) {
                    e.i.setNativeElement(r);
                }
            }
            r.externalObject = e;
        }
        return r.externalObject;
    }
    set aggregate(v) {
        v == null ? this.i.b = null : this.i.b = v.i;
    }
    /**
     * List of aggregates to show in aggregate drop-down.
    */
    get aggregateList() {
        if (this._aggregateList === null) {
            let coll = new IgrPivotAggregatorCollection();
            let innerColl = this.i.c;
            if (!innerColl) {
                innerColl = new PivotAggregatorCollection_internal();
            }
            this._aggregateList = coll._fromInner(innerColl);
        }
        return this._aggregateList;
    }
    set aggregateList(v) {
        if (this._aggregateList !== null) {
            this._aggregateList._setSyncTarget(null);
            this._aggregateList = null;
        }
        let coll = new IgrPivotAggregatorCollection();
        this._aggregateList = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(PivotAggregator.$type);
        let innerColl = this.i.c;
        if (!innerColl) {
            innerColl = new PivotAggregatorCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._aggregateList._setSyncTarget(syncColl);
    }
    /**
     * Enables/Disables a particular value from pivot aggregation.
    */
    get enabled() {
        return this.i.g;
    }
    set enabled(v) {
        this.i.g = ensureBool(v);
    }
    /**
     * Allow conditionally styling of the IgxPivotGrid cells.
    */
    get styles() {
        return this.i.j;
    }
    set styles(v) {
        this.i.j = v;
    }
    /**
     * Enables a data type specific template of the cells
    */
    get dataType() {
        return this.i.a;
    }
    set dataType(v) {
        this.i.a = ensureEnum(GridColumnDataType_$type, v);
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        if (this.aggregate && this.aggregate.name && this.aggregate.name == name) {
            return this.aggregate;
        }
        if (this.aggregateList != null && this.aggregateList.findByName && this.aggregateList.findByName(name)) {
            return this.aggregateList.findByName(name);
        }
        return null;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
}
