import { GroupSummaryDisplayMode_$type } from "./GroupSummaryDisplayMode";
import { IgrDefinitionBase } from "./igr-definition-base";
import { SectionHeader } from "./SectionHeader";
import { brushToString, stringToBrush, ensureBool, ensureEnum } from "igniteui-react-core";
/**
 * Used to configure the appearance of the section header cells.
*/
export class IgrSectionHeader extends IgrDefinitionBase {
    createImplementation() {
        return new SectionHeader();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    get selectedBackground() {
        return brushToString(this.i.fg);
    }
    set selectedBackground(v) {
        this.i.fg = stringToBrush(v);
    }
    get actualSelectedBackground() {
        return brushToString(this.i.ff);
    }
    set actualSelectedBackground(v) {
        this.i.ff = stringToBrush(v);
    }
    /**
     * Gets or sets the amount of left padding to use for the cell content for this column.
    */
    get paddingLeft() {
        return this.i.ey;
    }
    set paddingLeft(v) {
        this.i.ey = +v;
    }
    /**
     * Gets or sets the amount of top padding to use for the cell content for this column.
    */
    get paddingTop() {
        return this.i.e0;
    }
    set paddingTop(v) {
        this.i.e0 = +v;
    }
    /**
     * Gets or sets the amount of right padding to use for the cell content of this column.
    */
    get paddingRight() {
        return this.i.ez;
    }
    set paddingRight(v) {
        this.i.ez = +v;
    }
    /**
     * Gets or sets the amount of bottom padding to use for the cell content of this column.
    */
    get paddingBottom() {
        return this.i.ex;
    }
    set paddingBottom(v) {
        this.i.ex = +v;
    }
    get isCollapsable() {
        return this.i.er;
    }
    set isCollapsable(v) {
        this.i.er = ensureBool(v);
    }
    get summaryDisplayMode() {
        return this.i.eo;
    }
    set summaryDisplayMode(v) {
        this.i.eo = ensureEnum(GroupSummaryDisplayMode_$type, v);
    }
}
