import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrToggleViewEventArgs } from "./igr-toggle-view-event-args";
import { IgrToggleViewCancelableEventArgs } from "./igr-toggle-view-cancelable-event-args";
import { ToggleDirective as ToggleDirective_internal } from "./ToggleDirective";
import { interfaceToInternal } from "igniteui-react-core";
import { OverlaySettings } from "./OverlaySettings";
export class IgrToggleDirective {
    createImplementation() {
        return new ToggleDirective_internal();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this.mounted = false;
        this._opened = null;
        this._opened_wrapped = null;
        this._opening = null;
        this._opening_wrapped = null;
        this._closed = null;
        this._closed_wrapped = null;
        this._closing = null;
        this._closing_wrapped = null;
        this._appended = null;
        this._appended_wrapped = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    /**
     * Identifier which is registered into `IgxNavigationService`
     * ```typescript
     * let myToggleId = this.toggle.id;
     * ```
    */
    get id() {
        return this.i.j;
    }
    set id(v) {
        this.i.j = v;
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
    /**
     * Opens the toggle.
     * ```typescript
     * this.myToggle.open();
     * ```
    
    */
    open(overlaySettings) {
        this.i.n((overlaySettings == null ? null : interfaceToInternal(overlaySettings, () => new OverlaySettings())));
    }
    /**
     * Opens or closes the toggle, depending on its current state.
     * ```typescript
     * this.myToggle.toggle();
     * ```
    
    */
    toggle(overlaySettings) {
        this.i.t((overlaySettings == null ? null : interfaceToInternal(overlaySettings, () => new OverlaySettings())));
    }
    /**
     * Repositions the toggle.
     * ```typescript
     * this.myToggle.reposition();
     * ```
    
    */
    reposition() {
        this.i.q();
    }
    setOffset(deltaX, deltaY) {
        this.i.s(deltaX, deltaY);
    }
    get opened() {
        return this._opened;
    }
    set opened(ev) {
        if (this._opened_wrapped !== null) {
            this.i.opened = delegateRemove(this.i.opened, this._opened_wrapped);
            this._opened_wrapped = null;
            this._opened = null;
        }
        this._opened = ev;
        this._opened_wrapped = (o, e) => {
            let outerArgs = new IgrToggleViewEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeOpened) {
                this.beforeOpened(this, outerArgs);
            }
            if (this._opened) {
                this._opened(this, outerArgs);
            }
        };
        this.i.opened = delegateCombine(this.i.opened, this._opened_wrapped);
        ;
    }
    get opening() {
        return this._opening;
    }
    set opening(ev) {
        if (this._opening_wrapped !== null) {
            this.i.opening = delegateRemove(this.i.opening, this._opening_wrapped);
            this._opening_wrapped = null;
            this._opening = null;
        }
        this._opening = ev;
        this._opening_wrapped = (o, e) => {
            let outerArgs = new IgrToggleViewCancelableEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeOpening) {
                this.beforeOpening(this, outerArgs);
            }
            if (this._opening) {
                this._opening(this, outerArgs);
            }
        };
        this.i.opening = delegateCombine(this.i.opening, this._opening_wrapped);
        ;
    }
    get closed() {
        return this._closed;
    }
    set closed(ev) {
        if (this._closed_wrapped !== null) {
            this.i.closed = delegateRemove(this.i.closed, this._closed_wrapped);
            this._closed_wrapped = null;
            this._closed = null;
        }
        this._closed = ev;
        this._closed_wrapped = (o, e) => {
            let outerArgs = new IgrToggleViewEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeClosed) {
                this.beforeClosed(this, outerArgs);
            }
            if (this._closed) {
                this._closed(this, outerArgs);
            }
        };
        this.i.closed = delegateCombine(this.i.closed, this._closed_wrapped);
        ;
    }
    get closing() {
        return this._closing;
    }
    set closing(ev) {
        if (this._closing_wrapped !== null) {
            this.i.closing = delegateRemove(this.i.closing, this._closing_wrapped);
            this._closing_wrapped = null;
            this._closing = null;
        }
        this._closing = ev;
        this._closing_wrapped = (o, e) => {
            let outerArgs = new IgrToggleViewCancelableEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeClosing) {
                this.beforeClosing(this, outerArgs);
            }
            if (this._closing) {
                this._closing(this, outerArgs);
            }
        };
        this.i.closing = delegateCombine(this.i.closing, this._closing_wrapped);
        ;
    }
    get appended() {
        return this._appended;
    }
    set appended(ev) {
        if (this._appended_wrapped !== null) {
            this.i.appended = delegateRemove(this.i.appended, this._appended_wrapped);
            this._appended_wrapped = null;
            this._appended = null;
        }
        this._appended = ev;
        this._appended_wrapped = (o, e) => {
            let outerArgs = new IgrToggleViewEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeAppended) {
                this.beforeAppended(this, outerArgs);
            }
            if (this._appended) {
                this._appended(this, outerArgs);
            }
        };
        this.i.appended = delegateCombine(this.i.appended, this._appended_wrapped);
        ;
    }
}
