import * as React from 'react';
import { IgrTreeGridRecord } from "./igr-tree-grid-record";
import { IgrRowType } from "./igr-row-type";
import { IgrCellType } from "./igr-cell-type";
import { IgrGridBaseDirective } from "./igr-grid-base-directive";
import { TreeGrid } from "./TreeGrid";
import { ensureBool } from "igniteui-react-core";
import { ReactTemplateAdapter } from "igniteui-react-core";
import { html } from "lit-html";
export class IgrTreeGrid extends IgrGridBaseDirective {
    createImplementation() {
        let impl = new TreeGrid();
        let nat;
        if (typeof document !== 'undefined') {
            nat = document.createElement("igc-tree-grid");
        }
        else {
            nat = {
                style: {}
            };
        }
        nat.style.width = "100%";
        nat.style.height = "100%";
        impl.setNativeElement(nat);
        return impl;
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._getMainRef = this._getMainRef.bind(this);
    }
    componentDidMount() {
        this.mounted = true;
        super.componentDidMount();
        this._elRef.appendChild(this.i.nativeElement);
    }
    render() {
        let children = this._contentChildrenManager.getChildren(this.props.children);
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        if (this.props.height) {
            style.height = this.props.height;
        }
        if (this.props.width) {
            style.width = this.props.width;
        }
        let div = React.createElement("div", {
            ref: this._getMainRef,
            id: this.props.id,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    get childDataKey() {
        return this.i.hc;
    }
    set childDataKey(v) {
        this.i.hc = v;
    }
    get foreignKey() {
        return this.i.hd;
    }
    set foreignKey(v) {
        this.i.hd = v;
    }
    get hasChildrenKey() {
        return this.i.he;
    }
    set hasChildrenKey(v) {
        this.i.he = v;
    }
    get cascadeOnDelete() {
        return this.i.g6;
    }
    set cascadeOnDelete(v) {
        this.i.g6 = ensureBool(v);
    }
    get id() {
        return this.i.hf;
    }
    set id(v) {
        this.i.hf = v;
    }
    /**
     * Returns an array of the root level `ITreeGridRecord`s.
     * ```typescript
     * // gets the root record with index=2
     * const states = this.grid.rootRecords[2];
     * ```
     * @memberof IgxTreeGridComponent
    */
    get rootRecords() {
        if (!this.i.g0) {
            return undefined;
        }
        let ret = [];
        for (let i = 0; i < this.i.g0.length; i++) {
            let impl = this.i.g0[i];
            if (!impl.externalObject) {
                if (impl instanceof IgrTreeGridRecord) {
                    ret.push(impl);
                    continue;
                }
                let e = new IgrTreeGridRecord();
                e._implementation = impl;
                impl.externalObject = e;
            }
            ret.push(impl.externalObject);
        }
        return ret;
    }
    set rootRecords(v) {
        let arr = [];
        for (let i = 0; i < v.length; i++) {
            arr.push(v[i].i);
        }
        this.i.g0 = arr;
    }
    /**
     * Returns an array of processed (filtered and sorted) root `ITreeGridRecord`s.
     * ```typescript
     * // gets the processed root record with index=2
     * const states = this.grid.processedRootRecords[2];
     * ```
     * @memberof IgxTreeGridComponent
    */
    get processedRootRecords() {
        if (!this.i.gz) {
            return undefined;
        }
        let ret = [];
        for (let i = 0; i < this.i.gz.length; i++) {
            let impl = this.i.gz[i];
            if (!impl.externalObject) {
                if (impl instanceof IgrTreeGridRecord) {
                    ret.push(impl);
                    continue;
                }
                let e = new IgrTreeGridRecord();
                e._implementation = impl;
                impl.externalObject = e;
            }
            ret.push(impl.externalObject);
        }
        return ret;
    }
    set processedRootRecords(v) {
        let arr = [];
        for (let i = 0; i < v.length; i++) {
            arr.push(v[i].i);
        }
        this.i.gz = arr;
    }
    get data() {
        return this.i.gx;
    }
    set data(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.gx = v;
    }
    get expansionDepth() {
        return this.i.g9;
    }
    set expansionDepth(v) {
        this.i.g9 = +v;
    }
    get rowLoadingIndicatorTemplate() {
        return this._rowLoadingIndicatorTemplate;
    }
    set rowLoadingIndicatorTemplate(v) {
        this._rowLoadingIndicatorTemplate = v;
        if (!this._rowLoadingIndicatorTemplateAdapter) {
            this._rowLoadingIndicatorTemplateAdapter = new ReactTemplateAdapter(this._renderer, this._portalManager, "hb", { html: html });
        }
        this._rowLoadingIndicatorTemplateAdapter.setValue(this.i, this._rowLoadingIndicatorTemplate);
    }
    /**
     * Returns an array of the selected `IgxGridCell`s.
     * @example
     * ```typescript
     * const selectedCells = this.grid.selectedCells;
     * ```
    */
    get selectedCells() {
        if (!this.i.g1) {
            return undefined;
        }
        let ret = [];
        for (let i = 0; i < this.i.g1.length; i++) {
            let impl = this.i.g1[i];
            if (!impl.externalObject) {
                if (impl instanceof IgrCellType) {
                    ret.push(impl);
                    continue;
                }
                let e = new IgrCellType();
                e._implementation = impl;
                impl.externalObject = e;
            }
            ret.push(impl.externalObject);
        }
        return ret;
    }
    getDefaultExpandState(record) {
        this.i.hk((record == null ? null : record.i));
    }
    /**
     * Expands all rows.
     * ```typescript
     * this.grid.expandAll();
     * ```
     * @memberof IgxTreeGridComponent
    
    */
    expandAll() {
        this.i.hj();
    }
    /**
     * Collapses all rows.
     * ```typescript
     * this.grid.collapseAll();
     * ```
     * @memberof IgxTreeGridComponent
    
    */
    collapseAll() {
        this.i.hi();
    }
    addRow(data, parentRowID) {
        this.i.hg(data, parentRowID);
    }
    beginAddRowByIndex(index, asChild) {
        this.i.hh(index, asChild);
    }
    getSelectedData(formatters, headers) {
        let iv = this.i.gy(formatters, headers);
        return (iv);
    }
    /**
     * Returns the `IgxTreeGridRow` by index.
     * @example
     * ```typescript
     * const myRow = treeGrid.getRowByIndex(1);
     * ```
     * index
    
    * @param   * index
    */
    getRowByIndex(index) {
        let iv = this.i.g4(index);
        let ret = null;
        if (iv && iv.externalObject) {
            ret = iv.externalObject;
        }
        else {
            if (iv) {
                let e = new IgrRowType();
                e._implementation = iv;
                iv.externalObject = e;
                ret = e;
            }
        }
        return ret;
    }
    /**
     * Returns the `RowType` object by the specified primary key.
     * @example
     * ```typescript
     * const myRow = this.treeGrid.getRowByIndex(1);
     * ```
     * index
    
    * @param   * index
    */
    getRowByKey(key) {
        let iv = this.i.g5(key);
        let ret = null;
        if (iv && iv.externalObject) {
            ret = iv.externalObject;
        }
        else {
            if (iv) {
                let e = new IgrRowType();
                e._implementation = iv;
                iv.externalObject = e;
                ret = e;
            }
        }
        return ret;
    }
    getCellByColumn(rowIndex, columnField) {
        let iv = this.i.g2(rowIndex, columnField);
        let ret = null;
        if (iv && iv.externalObject) {
            ret = iv.externalObject;
        }
        else {
            if (iv) {
                let e = new IgrCellType();
                e._implementation = iv;
                iv.externalObject = e;
                ret = e;
            }
        }
        return ret;
    }
    getCellByKey(rowSelector, columnField) {
        let iv = this.i.g3(rowSelector, columnField);
        let ret = null;
        if (iv && iv.externalObject) {
            ret = iv.externalObject;
        }
        else {
            if (iv) {
                let e = new IgrCellType();
                e._implementation = iv;
                iv.externalObject = e;
                ret = e;
            }
        }
        return ret;
    }
    pinRow(rowID, index) {
        let iv = this.i.g7(rowID, index);
        return (iv);
    }
    unpinRow(rowID) {
        let iv = this.i.g8(rowID);
        return (iv);
    }
}
