import { __extends } from "tslib";
import * as React from 'react';
import { IgrGridActionsBaseDirectiveCollection } from "./igr-grid-actions-base-directive-collection";
import { IgrDisplayDensityBaseElement } from "./igr-display-density-base-element";
import { ActionStrip } from "./ActionStrip";
import { ContentChildrenManager } from "igniteui-react-core";
import { CollectionAdapter, ensureBool, interfaceToInternal } from "igniteui-react-core";
import { GridActionsBaseDirective } from "./GridActionsBaseDirective";
import { NotifyCollectionChangedAction } from "igniteui-react-core";
import { ActionStripResourceStrings } from "./ActionStripResourceStrings";
var IgrActionStrip = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrActionStrip, _super);
    function IgrActionStrip(props) {
        var _this = _super.call(this, props) || this;
        _this._actionButtons = null;
        _this._getMainRef = _this._getMainRef.bind(_this);
        return _this;
    }
    IgrActionStrip.prototype.createImplementation = function () {
        var impl = new ActionStrip();
        var nat;
        if (typeof document !== 'undefined') {
            nat = document.createElement("igc-action-strip");
        }
        else {
            nat = {
                style: {}
            };
        }
        impl.setNativeElement(nat);
        return impl;
    };
    Object.defineProperty(IgrActionStrip.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrActionStrip.prototype.onImplementationCreated = function () {
        _super.prototype.onImplementationCreated.call(this);
        this._portalManager.getPortal(this._renderer.getWrapper(this._implementation.nativeElement), "ChildContent", function (p) { }, true);
    };
    IgrActionStrip.prototype._initializeAdapters = function () {
        var _this = this;
        if (!this._contentChildrenManager) {
            var resolveNested_1 = (function (props, propName, nestedPropName) {
                var _a;
                var prop = props[propName];
                if (Array.isArray(prop)) {
                    return prop.map(function (x) {
                        var _a;
                        return (_a = x[nestedPropName]) !== null && _a !== void 0 ? _a : resolveNested_1(x.props, propName, nestedPropName);
                    }).join("_");
                }
                else if (prop) {
                    return (_a = prop.props[nestedPropName]) !== null && _a !== void 0 ? _a : resolveNested_1(prop.props, propName, nestedPropName);
                }
                else {
                    return props[nestedPropName];
                }
            });
            this._contentChildrenManager = new ContentChildrenManager(function (ch) {
                var key = ch.key || ch.props.name;
                if (!key) {
                    var type = (ch.type);
                    var instance = new type;
                    var name_1 = instance.i.$type.name;
                    switch (name_1) {
                        case "GridEditingActions": return "IgrGridEditingActions";
                        case "GridPinningActions": return "IgrGridPinningActions";
                        default: return undefined;
                    }
                }
                return key;
            }, function (ch) {
                var key = ch.key || ch.props.name;
                if (!key) {
                    var type = (ch.type);
                    var instance = new type;
                    var name_2 = instance.i.$type.name;
                    switch (name_2) {
                        case "GridEditingActions": return "IgrGridEditingActions";
                        case "GridPinningActions": return "IgrGridPinningActions";
                        default: return undefined;
                    }
                }
                return key;
            }, function () {
                if (_this._updateContentChildren) {
                    _this._updateContentChildren();
                }
                else if (_this._updateAdapters) {
                    _this._updateAdapters();
                }
            });
        }
        this._actionButtonsAdapter = new CollectionAdapter(this.contentActionButtons, this.i.j, this.actualActionButtons, function (c) { return c.i; }, function (i) {
            if (_this._initializeElement) {
                _this._initializeElement(i);
            }
        }, function (i) {
            if (_this._destroyElement) {
                _this._destroyElement(i);
            }
        });
        if (_super.prototype["_initializeAdapters"]) {
            _super.prototype["_initializeAdapters"].call(this);
        }
    };
    IgrActionStrip.prototype._updateAdapters = function () {
        if (_super.prototype["_updateAdapters"]) {
            _super.prototype["_updateAdapters"].call(this);
        }
        var contentChildrenActual = this._contentChildrenManager.contentChildrenActual;
        this.contentActionButtons.length = 0;
        for (var i = 0; i < contentChildrenActual.length; i++) {
            if ((GridActionsBaseDirective.$type).isAssignableFrom(contentChildrenActual[i].i.$type)) {
                this.contentActionButtons.push(contentChildrenActual[i]);
            }
        }
        if (this._actionButtonsAdapter != null) {
            this._actionButtonsAdapter.notifyContentChanged();
        }
    };
    IgrActionStrip.prototype.componentDidMount = function () {
        this.mounted = true;
        _super.prototype.componentDidMount.call(this);
    };
    IgrActionStrip.prototype.render = function () {
        var children = this._contentChildrenManager.getChildren(this.props.children);
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("div", {
            ref: this._getMainRef,
            id: this.props.id,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    };
    IgrActionStrip.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrActionStrip.prototype, "actualActionButtons", {
        get: function () {
            if (!this._actualActionButtons) {
                this._actualActionButtons = [];
            }
            return this._actualActionButtons;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrActionStrip.prototype, "contentActionButtons", {
        get: function () {
            if (!this._contentActionButtons) {
                this._contentActionButtons = [];
            }
            return this._contentActionButtons;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrActionStrip.prototype, "actionButtons", {
        /**
         * ActionButton as ContentChildren inside the Action Strip
         * @hidden
         * @internal
        */
        get: function () {
            var _this = this;
            if (this._actionButtons === null) {
                var coll = new IgrGridActionsBaseDirectiveCollection();
                var inner = coll._innerColl;
                this._actionButtons = coll;
                inner.addListener(function (sender, e) {
                    switch (e.action) {
                        case NotifyCollectionChangedAction.Add:
                            _this._actionButtonsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                            break;
                        case NotifyCollectionChangedAction.Remove:
                            _this._actionButtonsAdapter.removeManualItemAt(e.oldStartingIndex);
                            break;
                        case NotifyCollectionChangedAction.Replace:
                            _this._actionButtonsAdapter.removeManualItemAt(e.oldStartingIndex);
                            _this._actionButtonsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                            break;
                        case NotifyCollectionChangedAction.Reset:
                            _this._actionButtonsAdapter.clearManualItems();
                            break;
                    }
                });
                ;
            }
            return this._actionButtons;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrActionStrip.prototype, "hidden", {
        get: function () {
            return this.i.k;
        },
        set: function (v) {
            this.i.k = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrActionStrip.prototype, "resourceStrings", {
        /**
         * Gets/Sets the resource strings.
         * @remarks
         * By default it uses EN resources.
        */
        get: function () {
            return this.i.i.nativeElement;
        },
        set: function (v) {
            this.i.i = interfaceToInternal(v, function () { return new ActionStripResourceStrings(); });
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrActionStrip.prototype, "name", {
        get: function () {
            return this.i.l;
        },
        set: function (v) {
            this.i.l = v;
        },
        enumerable: false,
        configurable: true
    });
    IgrActionStrip.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.actionButtons != null && this.actionButtons.findByName && this.actionButtons.findByName(name)) {
            return this.actionButtons.findByName(name);
        }
        if (this.resourceStrings && this.resourceStrings.name && this.resourceStrings.name == name) {
            return this.resourceStrings;
        }
        return null;
    };
    /**
     * Showing the Action Strip and appending it the specified context element.
     * context
     * @example
     * ```typescript
     * this.actionStrip.show(row);
     * ```
    
    * @param   * context
    */
    IgrActionStrip.prototype.show = function (context) {
        this.i.n(context);
    };
    /**
     * Hiding the Action Strip and removing it from its current context element.
     * @example
     * ```typescript
     * this.actionStrip.hide();
     * ```
    
    */
    IgrActionStrip.prototype.hide = function () {
        this.i.m();
    };
    return IgrActionStrip;
}(IgrDisplayDensityBaseElement));
export { IgrActionStrip };
