import { __extends, __values } from "tslib";
import * as React from 'react';
import { GridColumnDataType_$type } from "./GridColumnDataType";
import { IgrFilteringOperand } from "./igr-filtering-operand";
import { Column } from "./Column";
import { TypeRegistrar } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { NamePatcher, getModifiedProps, isValidProp, ensureBool, ensureEnum, interfaceToInternal, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
import { SortingStrategy } from "./SortingStrategy";
import { IgrSummaryTemplateContext } from "./igr-summary-template-context";
import { ReactTemplateAdapter } from "igniteui-react-core";
import { html } from "lit-html";
import { IgrCellTemplateContext } from "./igr-cell-template-context";
import { IgrColumnTemplateContext } from "./igr-column-template-context";
import { ColumnPipeArgs } from "./ColumnPipeArgs";
var IgrColumn = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrColumn, _super);
    function IgrColumn(props) {
        var _this = _super.call(this, props) || this;
        _this.mounted = false;
        _this.__p = null;
        _this._hasUserValues = new Set();
        _this._stylingContainer = null;
        _this._stylingParent = null;
        _this._inStyling = false;
        if (_this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(_this));
        }
        _this._getMainRef = _this._getMainRef.bind(_this);
        _this._implementation = _this.createImplementation();
        _this._portalManager = new PortalManager("templates", function () {
            if (_this.mounted) {
                _this.setState({});
            }
        });
        if (typeof window !== 'undefined' && typeof document !== 'undefined') {
            _this._renderer = new ReactRenderer(_this._implementation.nativeElement, document, false, null, _this._portalManager);
        }
        _this._implementation.externalObject = _this;
        _this.onImplementationCreated();
        if (_this._initializeAdapters) {
            _this._initializeAdapters();
        }
        return _this;
    }
    IgrColumn.prototype.createImplementation = function () {
        var impl = new Column();
        var nat;
        if (typeof document !== 'undefined') {
            nat = document.createElement("igc-column");
        }
        else {
            nat = {
                style: {}
            };
        }
        impl.setNativeElement(nat);
        return impl;
    };
    Object.defineProperty(IgrColumn.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        } /**
                                     * @hidden
                                     */,
        enumerable: false,
        configurable: true
    });
    IgrColumn._createFromInternal = function (internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        var name = internal.$type.name;
        var externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    };
    IgrColumn.prototype.onImplementationCreated = function () {
    };
    IgrColumn.prototype.componentDidMount = function () {
        var e_1, _a;
        this.mounted = true;
        try {
            for (var _b = __values(Object.keys(this.props)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = this.props[p];
                }
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
    };
    IgrColumn.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        var e_2, _a;
        var mod = getModifiedProps(this.props, nextProps);
        try {
            for (var _b = __values(Object.keys(mod)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = mod[p];
                }
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
        return true;
    };
    IgrColumn.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var div = React.createElement("div", {
            ref: this._getMainRef,
            className: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    };
    IgrColumn.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrColumn.prototype, "field", {
        get: function () {
            return this.i.a2;
        },
        set: function (v) {
            this.i.a2 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "header", {
        get: function () {
            return this.i.a3;
        },
        set: function (v) {
            this.i.a3 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "title", {
        get: function () {
            return this.i.a9;
        },
        set: function (v) {
            this.i.a9 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "sortable", {
        get: function () {
            return this.i.z;
        },
        set: function (v) {
            this.i.z = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "selectable", {
        /**
         * Returns if the column is selectable.
         * ```typescript
         * let columnSelectable = this.column.selectable;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this.i.x;
        },
        set: function (v) {
            this.i.x = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "groupable", {
        get: function () {
            return this.i.p;
        },
        set: function (v) {
            this.i.p = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "editable", {
        /**
         * Gets whether the column is editable.
         * Default value is `false`.
         * ```typescript
         * let isEditable = this.column.editable;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this.i.m;
        },
        set: function (v) {
            this.i.m = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "filterable", {
        get: function () {
            return this.i.n;
        },
        set: function (v) {
            this.i.n = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "resizable", {
        get: function () {
            return this.i.v;
        },
        set: function (v) {
            this.i.v = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "autosizeHeader", {
        get: function () {
            return this.i.j;
        },
        set: function (v) {
            this.i.j = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "hasSummary", {
        /**
         * Gets a value indicating whether the summary for the column is enabled.
         * ```typescript
         * let hasSummary = this.column.hasSummary;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this.i.q;
        },
        set: function (v) {
            this.i.q = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "hidden", {
        /**
         * Gets whether the column is hidden.
         * ```typescript
         * let isHidden = this.column.hidden;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this.i.r;
        },
        set: function (v) {
            this.i.r = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "selected", {
        /**
         * Returns if the column is selected.
         * ```typescript
         * let isSelected = this.column.selected;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this.i.y;
        },
        set: function (v) {
            this.i.y = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "disableHiding", {
        /**
         * Gets whether the hiding is disabled.
         * ```typescript
         * let isHidingDisabled =  this.column.disableHiding;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this.i.k;
        },
        set: function (v) {
            this.i.k = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "disablePinning", {
        /**
         * Gets whether the pinning is disabled.
         * ```typescript
         * let isPinningDisabled =  this.column.disablePinning;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this.i.l;
        },
        set: function (v) {
            this.i.l = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "movable", {
        /**
         * @deprecated Use the Grid's `moving` property instead.
        */
        get: function () {
            return this.i.s;
        },
        set: function (v) {
            this.i.s = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "width", {
        /**
         * Gets the `width` of the column.
         * ```typescript
         * let columnWidth = this.column.width;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this.i.ba;
        },
        set: function (v) {
            this.i.ba = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "maxWidth", {
        get: function () {
            return this.i.a6;
        },
        set: function (v) {
            this.i.a6 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "headerClasses", {
        get: function () {
            return this.i.a4;
        },
        set: function (v) {
            this.i.a4 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "headerStyles", {
        get: function () {
            return this.i.am;
        },
        set: function (v) {
            this.i.am = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "headerGroupClasses", {
        get: function () {
            return this.i.a5;
        },
        set: function (v) {
            this.i.a5 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "headerGroupStyles", {
        get: function () {
            return this.i.al;
        },
        set: function (v) {
            this.i.al = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "cellClasses", {
        get: function () {
            return this.i.aj;
        },
        set: function (v) {
            this.i.aj = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "cellStyles", {
        get: function () {
            return this.i.ak;
        },
        set: function (v) {
            this.i.ak = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "formatter", {
        /**
         * Applies display format to cell values in the column. Does not modify the underlying data.
         * @remark
         * Note: As the formatter is used in places like the Excel style filtering dialog, in certain
         * scenarios (remote filtering for example), the row data argument can be `undefined`.
         * In this example, we check to see if the column name is Salary, and then provide a method as the column formatter
         * to format the value into a currency string.
         * @example
         * ```typescript
         * columnInit(column: IgxColumnComponent) {
         * if (column.field == "Salary") {
         * column.formatter = (salary => this.format(salary));
         * }
         * }
         * format(value: number) : string {
         * return formatCurrency(value, "en-us", "$");
         * }
         * ```
         * @example
         * ```typescript
         * const column = this.grid.getColumnByName('Address');
         * const addressFormatter = (address: string, rowData: any) => data.privacyEnabled ? 'unknown' : address;
         * column.formatter = addressFormatter;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this.i.b;
        },
        set: function (v) {
            this.i.b = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "summaryFormatter", {
        get: function () {
            return this.i.g;
        },
        set: function (v) {
            this.i.g = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "filteringIgnoreCase", {
        get: function () {
            return this.i.o;
        },
        set: function (v) {
            this.i.o = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "sortingIgnoreCase", {
        get: function () {
            return this.i.aa;
        },
        set: function (v) {
            this.i.aa = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "searchable", {
        get: function () {
            return this.i.w;
        },
        set: function (v) {
            this.i.w = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "dataType", {
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = ensureEnum(GridColumnDataType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "rowEnd", {
        get: function () {
            return this.i.af;
        },
        set: function (v) {
            this.i.af = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "colEnd", {
        get: function () {
            return this.i.ad;
        },
        set: function (v) {
            this.i.ad = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "rowStart", {
        get: function () {
            return this.i.ag;
        },
        set: function (v) {
            this.i.ag = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "colStart", {
        get: function () {
            return this.i.ae;
        },
        set: function (v) {
            this.i.ae = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "additionalTemplateContext", {
        get: function () {
            return this.i.ai;
        },
        set: function (v) {
            this.i.ai = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "minWidth", {
        get: function () {
            return this.i.a7;
        },
        set: function (v) {
            this.i.a7 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "pinned", {
        /**
         * Gets whether the column is `pinned`.
         * ```typescript
         * let isPinned = this.column.pinned;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this.i.u;
        },
        set: function (v) {
            this.i.u = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "summaries", {
        /**
         * Gets the column `summaries`.
         * ```typescript
         * let columnSummaries = this.column.summaries;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this.i.ap;
        },
        set: function (v) {
            this.i.ap = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "filters", {
        /**
         * Gets the column `filters`.
         * ```typescript
         * let columnFilters = this.column.filters'
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            var r = this.i.d;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrFilteringOperand();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.d = null : this.i.d = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "sortStrategy", {
        /**
         * Gets the column `sortStrategy`.
         * ```typescript
         * let sortStrategy = this.column.sortStrategy
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this.i.f.nativeElement;
        },
        set: function (v) {
            this.i.f = interfaceToInternal(v, function () { return new SortingStrategy(); });
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "summaryTemplate", {
        /**
         * Returns a reference to the `summaryTemplate`.
         * ```typescript
         * let summaryTemplate = this.column.summaryTemplate;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this._summaryTemplate;
        },
        set: function (v) {
            this._summaryTemplate = v;
            if (!this._summaryTemplateAdapter) {
                this._summaryTemplateAdapter = new ReactTemplateAdapter(this._renderer, this._portalManager, "a1", { html: html }, function () { return new IgrSummaryTemplateContext(); });
            }
            this._summaryTemplateAdapter.setValue(this.i, this._summaryTemplate);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "bodyTemplate", {
        /**
         * Returns a reference to the `bodyTemplate`.
         * ```typescript
         * let bodyTemplate = this.column.bodyTemplate;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this._bodyTemplate;
        },
        set: function (v) {
            this._bodyTemplate = v;
            if (!this._bodyTemplateAdapter) {
                this._bodyTemplateAdapter = new ReactTemplateAdapter(this._renderer, this._portalManager, "aw", { html: html }, function () { return new IgrCellTemplateContext(); });
            }
            this._bodyTemplateAdapter.setValue(this.i, this._bodyTemplate);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "headerTemplate", {
        /**
         * Returns a reference to the header template.
         * ```typescript
         * let headerTemplate = this.column.headerTemplate;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this._headerTemplate;
        },
        set: function (v) {
            this._headerTemplate = v;
            if (!this._headerTemplateAdapter) {
                this._headerTemplateAdapter = new ReactTemplateAdapter(this._renderer, this._portalManager, "az", { html: html }, function () { return new IgrColumnTemplateContext(); });
            }
            this._headerTemplateAdapter.setValue(this.i, this._headerTemplate);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "inlineEditorTemplate", {
        /**
         * Returns a reference to the inline editor template.
         * ```typescript
         * let inlineEditorTemplate = this.column.inlineEditorTemplate;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this._inlineEditorTemplate;
        },
        set: function (v) {
            this._inlineEditorTemplate = v;
            if (!this._inlineEditorTemplateAdapter) {
                this._inlineEditorTemplateAdapter = new ReactTemplateAdapter(this._renderer, this._portalManager, "a0", { html: html }, function () { return new IgrCellTemplateContext(); });
            }
            this._inlineEditorTemplateAdapter.setValue(this.i, this._inlineEditorTemplate);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "errorTemplate", {
        /**
         * Returns a reference to the validation error template.
         * ```typescript
         * let errorTemplate = this.column.errorTemplate;
         * ```
        */
        get: function () {
            return this._errorTemplate;
        },
        set: function (v) {
            this._errorTemplate = v;
            if (!this._errorTemplateAdapter) {
                this._errorTemplateAdapter = new ReactTemplateAdapter(this._renderer, this._portalManager, "ax", { html: html }, function () { return new IgrCellTemplateContext(); });
            }
            this._errorTemplateAdapter.setValue(this.i, this._errorTemplate);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "filterCellTemplate", {
        /**
         * Returns a reference to the `filterCellTemplate`.
         * ```typescript
         * let filterCellTemplate = this.column.filterCellTemplate;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this._filterCellTemplate;
        },
        set: function (v) {
            this._filterCellTemplate = v;
            if (!this._filterCellTemplateAdapter) {
                this._filterCellTemplateAdapter = new ReactTemplateAdapter(this._renderer, this._portalManager, "ay", { html: html }, function () { return new IgrColumnTemplateContext(); });
            }
            this._filterCellTemplateAdapter.setValue(this.i, this._filterCellTemplate);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "visibleWhenCollapsed", {
        get: function () {
            return this.i.ac;
        },
        set: function (v) {
            this.i.ac = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "pipeArgs", {
        get: function () {
            return this.i.c.nativeElement;
        },
        set: function (v) {
            this.i.c = interfaceToInternal(v, function () { return new ColumnPipeArgs(); });
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "parent", {
        /**
         * Sets/gets the parent column.
         * ```typescript
         * let parentColumn = this.column.parent;
         * ```
         * ```typescript
         * this.column.parent = higherLevelColumn;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            return this.i.ao;
        },
        set: function (v) {
            this.i.ao = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "columnChildren", {
        /**
         * Gets the children columns array.
         * ```typescript
         * let columnChildren = this.column.columnChildren;
         * ```
         * @memberof IgxColumnComponent
        */
        get: function () {
            if (!this.i.a) {
                return undefined;
            }
            var ret = [];
            for (var i = 0; i < this.i.a.length; i++) {
                var impl = this.i.a[i];
                if (!impl.externalObject) {
                    if (impl instanceof IgrColumn) {
                        ret.push(impl);
                        continue;
                    }
                    var e = IgrColumn._createFromInternal(impl);
                    e._implementation = impl;
                    impl.externalObject = e;
                }
                ret.push(impl.externalObject);
            }
            return ret;
        },
        set: function (v) {
            var arr = [];
            for (var i = 0; i < v.length; i++) {
                arr.push(v[i].i);
            }
            this.i.a = arr;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrColumn.prototype, "name", {
        get: function () {
            return this.i.a8;
        },
        set: function (v) {
            this.i.a8 = v;
        },
        enumerable: false,
        configurable: true
    });
    IgrColumn.prototype.findByName = function (name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        if (this.filters && this.filters.name && this.filters.name == name) {
            return this.filters;
        }
        if (this.sortStrategy && this.sortStrategy.name && this.sortStrategy.name == name) {
            return this.sortStrategy;
        }
        if (this.pipeArgs && this.pipeArgs.name && this.pipeArgs.name == name) {
            return this.pipeArgs;
        }
        return null;
    };
    Object.defineProperty(IgrColumn.prototype, "hasUserValues", {
        get: function () {
            return this._hasUserValues;
        },
        enumerable: false,
        configurable: true
    });
    IgrColumn.prototype.__m = function (propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    };
    IgrColumn.prototype._styling = function (container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        var genericPrefix = "";
        var typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("Column");
        var additionalPrefixes = [];
        var prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        var b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            var basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            var parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            var parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    };
    IgrColumn.prototype.setNativeElement = function (element) {
        this.i.setNativeElement(element);
    };
    /**
     * Pins the column at the provided index in the pinned area.
     * Defaults to index `0` if not provided, or to the initial index in the pinned area.
     * Returns `true` if the column is successfully pinned. Returns `false` if the column cannot be pinned.
     * Column cannot be pinned if:
     * - Is already pinned
     * - index argument is out of range
     * - The pinned area exceeds 80% of the grid width
     * ```typescript
     * let success = this.column.pin();
     * ```
     * @memberof IgxColumnComponent
    
    */
    IgrColumn.prototype.pin = function (index) {
        var iv = this.i.t(index);
        return (iv);
    };
    /**
     * Unpins the column and place it at the provided index in the unpinned area.
     * Defaults to index `0` if not provided, or to the initial index in the unpinned area.
     * Returns `true` if the column is successfully unpinned. Returns `false` if the column cannot be unpinned.
     * Column cannot be unpinned if:
     * - Is already unpinned
     * - index argument is out of range
     * ```typescript
     * let success = this.column.unpin();
     * ```
     * @memberof IgxColumnComponent
    
    */
    IgrColumn.prototype.unpin = function (index) {
        var iv = this.i.ab(index);
        return (iv);
    };
    /**
     * Moves a column to the specified visible index.
     * If passed index is invalid, or if column would receive a different visible index after moving, moving is not performed.
     * If passed index would move the column to a different column group. moving is not performed.
     * @example
     * ```typescript
     * column.move(index);
     * ```
     * @memberof IgxColumnComponent
    
    */
    IgrColumn.prototype.move = function (index) {
        this.i.bc(index);
    };
    /**
     * Autosize the column to the longest currently visible cell value, including the header cell.
     * ```typescript
     * @ViewChild('grid') grid: IgxGridComponent;
     * let column = this.grid.columnList.filter(c => c.field === 'ID')[0];
     * column.autosize();
     * ```
     * @memberof IgxColumnComponent
     * byHeaderOnly Set if column should be autosized based only on the header content.
    
    * @param byHeaderOnly  * Set if column should be autosized based only on the header content.
    */
    IgrColumn.prototype.autosize = function (byHeaderOnly) {
        this.i.bb(byHeaderOnly);
    };
    return IgrColumn;
}(React.Component));
export { IgrColumn };
