import { FilteringLogic_$type } from "./FilteringLogic";
import { FilteringExpressionsTreeType_$type } from "./FilteringExpressionsTreeType";
import { IgrFilteringExpressionsTreeOrFilteringExpression } from "./igr-filtering-expressions-tree-or-filtering-expression";
import { FilteringExpressionsTreeDetail as FilteringExpressionsTreeDetail_internal } from "./FilteringExpressionsTreeDetail";
import { ensureEnum } from "igniteui-react-core";
var IgrFilteringExpressionsTreeDetail = /** @class */ /*@__PURE__*/ (function () {
    function IgrFilteringExpressionsTreeDetail() {
        this.mounted = false;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrFilteringExpressionsTreeDetail.prototype.createImplementation = function () {
        return new FilteringExpressionsTreeDetail_internal();
    };
    Object.defineProperty(IgrFilteringExpressionsTreeDetail.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrFilteringExpressionsTreeDetail.prototype.onImplementationCreated = function () {
    };
    IgrFilteringExpressionsTreeDetail.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrFilteringExpressionsTreeDetail.prototype, "filteringOperands", {
        /**
         * Sets/gets the filtering operands.
         * ```typescript
         * const gridExpressionsTree = new FilteringExpressionsTree(FilteringLogic.And);
         * const expression = [
         * {
         * condition: IgxStringFilteringOperand.instance().condition('contains'),
         * fieldName: 'Column Field',
         * searchVal: 'Value',
         * ignoreCase: false
         * }];
         * gridExpressionsTree.filteringOperands.push(expression);
         * this.grid.filteringExpressionsTree = gridExpressionsTree;
         * ```
         * ```typescript
         * let filteringOperands = gridExpressionsTree.filteringOperands;
         * ```
         * @memberof FilteringExpressionsTree
        */
        get: function () {
            if (!this.i.a) {
                return undefined;
            }
            var ret = [];
            for (var i = 0; i < this.i.a.length; i++) {
                var impl = this.i.a[i];
                if (!impl.externalObject) {
                    if (impl instanceof IgrFilteringExpressionsTreeOrFilteringExpression) {
                        ret.push(impl);
                        continue;
                    }
                    var e = new IgrFilteringExpressionsTreeOrFilteringExpression();
                    e._implementation = impl;
                    impl.externalObject = e;
                }
                ret.push(impl.externalObject);
            }
            return ret;
        },
        set: function (v) {
            var arr = [];
            for (var i = 0; i < v.length; i++) {
                arr.push(v[i].i);
            }
            this.i.a = arr;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrFilteringExpressionsTreeDetail.prototype, "operator", {
        /**
         * Sets/gets the operator.
         * ```typescript
         * gridExpressionsTree.operator = FilteringLogic.And;
         * ```
         * ```typescript
         * let operator = gridExpressionsTree.operator;
         * ```
         * @memberof FilteringExpressionsTree
        */
        get: function () {
            return this.i.d;
        },
        set: function (v) {
            this.i.d = ensureEnum(FilteringLogic_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrFilteringExpressionsTreeDetail.prototype, "fieldName", {
        /**
         * Sets/gets the field name of the column where the filtering expression is placed.
         * ```typescript
         * gridExpressionTree.fieldName = 'Column Field';
         * ```
         * ```typescript
         * let columnField = expressionTree.fieldName;
         * ```
         * @memberof FilteringExpressionsTree
        */
        get: function () {
            return this.i.k;
        },
        set: function (v) {
            this.i.k = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrFilteringExpressionsTreeDetail.prototype, "type", {
        /**
         * Sets/gets the type of the filtering expressions tree.
         * ```typescript
         * gridExpressionTree.type = FilteringExpressionsTree.Advanced;
         * ```
         * ```typescript
         * let type = expressionTree.type;
         * ```
         * @memberof FilteringExpressionsTree
        */
        get: function () {
            return this.i.c;
        },
        set: function (v) {
            this.i.c = ensureEnum(FilteringExpressionsTreeType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    IgrFilteringExpressionsTreeDetail.prototype.findByName = function (name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    };
    IgrFilteringExpressionsTreeDetail.prototype.setNativeElement = function (element) {
        this.i.setNativeElement(element);
    };
    /**
     * Checks if filtering expressions tree is empty.
     * expressionTree filtering expressions tree.
    
    * @param expressionTree  * filtering expressions tree.
    */
    IgrFilteringExpressionsTreeDetail.prototype.empty = function (expressionTree) {
        var iv = this.i.g((expressionTree == null ? null : expressionTree.i));
        return (iv);
    };
    /**
     * Returns the filtering expression for a column with the provided fieldName.
     * ```typescript
     * let filteringExpression = gridExpressionTree.find('Column Field');
     * ```
     * @memberof FilteringExpressionsTree
    
    */
    IgrFilteringExpressionsTreeDetail.prototype.find = function (fieldName) {
        var iv = this.i.b(fieldName);
        var ret = null;
        if (iv && iv.externalObject) {
            ret = iv.externalObject;
        }
        else {
            if (iv) {
                var e = new IgrFilteringExpressionsTreeOrFilteringExpression();
                e._implementation = iv;
                iv.externalObject = e;
                ret = e;
            }
        }
        return ret;
    };
    /**
     * Returns the index of the filtering expression for a column with the provided fieldName.
     * ```typescript
     * let filteringExpressionIndex = gridExpressionTree.findIndex('Column Field');
     * ```
     * @memberof FilteringExpressionsTree
    
    */
    IgrFilteringExpressionsTreeDetail.prototype.findIndex = function (fieldName) {
        var iv = this.i.h(fieldName);
        return (iv);
    };
    return IgrFilteringExpressionsTreeDetail;
}());
export { IgrFilteringExpressionsTreeDetail };
