import { __extends } from "tslib";
import * as React from 'react';
import { IgrGridToolbarContentCollection } from "./igr-grid-toolbar-content-collection";
import { IgrDisplayDensityBaseElement } from "./igr-display-density-base-element";
import { GridToolbar } from "./GridToolbar";
import { ContentChildrenManager } from "igniteui-react-core";
import { CollectionAdapter, ensureBool } from "igniteui-react-core";
import { GridToolbarContent } from "./GridToolbarContent";
import { NotifyCollectionChangedAction } from "igniteui-react-core";
/**
 * Provides a context-aware container component for UI operations for the grid components.
 * @igxModule IgxGridToolbarModule
 * @igxParent IgxGridComponent, IgxTreeGridComponent, IgxHierarchicalGridComponent, IgxPivotGridComponent
*/
var IgrGridToolbar = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrGridToolbar, _super);
    function IgrGridToolbar(props) {
        var _this = _super.call(this, props) || this;
        _this._tools = null;
        _this._getMainRef = _this._getMainRef.bind(_this);
        return _this;
    }
    IgrGridToolbar.prototype.createImplementation = function () {
        var impl = new GridToolbar();
        var nat;
        if (typeof document !== 'undefined') {
            nat = document.createElement("igc-grid-toolbar");
        }
        else {
            nat = {
                style: {}
            };
        }
        impl.setNativeElement(nat);
        return impl;
    };
    Object.defineProperty(IgrGridToolbar.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrGridToolbar.prototype.onImplementationCreated = function () {
        _super.prototype.onImplementationCreated.call(this);
        this._portalManager.getPortal(this._renderer.getWrapper(this._implementation.nativeElement), "ChildContent", function (p) { }, true);
    };
    IgrGridToolbar.prototype._initializeAdapters = function () {
        var _this = this;
        if (!this._contentChildrenManager) {
            var resolveNested_1 = (function (props, propName, nestedPropName) {
                var _a;
                var prop = props[propName];
                if (Array.isArray(prop)) {
                    return prop.map(function (x) {
                        var _a;
                        return (_a = x[nestedPropName]) !== null && _a !== void 0 ? _a : resolveNested_1(x.props, propName, nestedPropName);
                    }).join("_");
                }
                else if (prop) {
                    return (_a = prop.props[nestedPropName]) !== null && _a !== void 0 ? _a : resolveNested_1(prop.props, propName, nestedPropName);
                }
                else {
                    return props[nestedPropName];
                }
            });
            this._contentChildrenManager = new ContentChildrenManager(function (ch) {
                var key = ch.key || ch.props.name;
                if (!key) {
                    var type = (ch.type);
                    var instance = new type;
                    var name_1 = instance.i.$type.name;
                    switch (name_1) {
                        case "GridToolbarActions": return "IgrGridToolbarActions";
                        case "GridToolbarTitle": return "IgrGridToolbarTitle";
                        default: return undefined;
                    }
                }
                return key;
            }, function (ch) {
                var key = ch.key || ch.props.name;
                if (!key) {
                    var type = (ch.type);
                    var instance = new type;
                    var name_2 = instance.i.$type.name;
                    switch (name_2) {
                        case "GridToolbarActions": return "IgrGridToolbarActions";
                        case "GridToolbarTitle": return "IgrGridToolbarTitle";
                        default: return undefined;
                    }
                }
                return key;
            }, function () {
                if (_this._updateContentChildren) {
                    _this._updateContentChildren();
                }
                else if (_this._updateAdapters) {
                    _this._updateAdapters();
                }
            });
        }
        this._toolsAdapter = new CollectionAdapter(this.contentTools, this.i.k, this.actualTools, function (c) { return c.i; }, function (i) {
            if (_this._initializeElement) {
                _this._initializeElement(i);
            }
        }, function (i) {
            if (_this._destroyElement) {
                _this._destroyElement(i);
            }
        });
        if (_super.prototype["_initializeAdapters"]) {
            _super.prototype["_initializeAdapters"].call(this);
        }
    };
    IgrGridToolbar.prototype._updateAdapters = function () {
        if (_super.prototype["_updateAdapters"]) {
            _super.prototype["_updateAdapters"].call(this);
        }
        var contentChildrenActual = this._contentChildrenManager.contentChildrenActual;
        this.contentTools.length = 0;
        for (var i = 0; i < contentChildrenActual.length; i++) {
            if ((GridToolbarContent.$type).isAssignableFrom(contentChildrenActual[i].i.$type)) {
                this.contentTools.push(contentChildrenActual[i]);
            }
        }
        if (this._toolsAdapter != null) {
            this._toolsAdapter.notifyContentChanged();
        }
    };
    IgrGridToolbar.prototype.componentDidMount = function () {
        this.mounted = true;
        _super.prototype.componentDidMount.call(this);
    };
    IgrGridToolbar.prototype.render = function () {
        var children = this._contentChildrenManager.getChildren(this.props.children);
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("div", {
            ref: this._getMainRef,
            id: this.props.id,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    };
    IgrGridToolbar.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrGridToolbar.prototype, "showProgress", {
        /**
         * When enabled, shows the indeterminate progress bar.
         * @remarks
         * By default this will be toggled, when the default exporter component is present
         * and an exporting is in progress.
        */
        get: function () {
            return this.i.l;
        },
        set: function (v) {
            this.i.l = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGridToolbar.prototype, "grid", {
        /**
         * Gets/sets the grid component for the toolbar component.
         * @remarks
         * Usually you should not set this property in the context of the default grid/tree grid.
         * The only grids that demands this to be set are the hierarchical child grids. For additional
         * information check the toolbar topic.
        */
        get: function () {
            var r = this.i.i;
            if (r == null) {
                return null;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.i = null : this.i.i = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGridToolbar.prototype, "name", {
        get: function () {
            return this.i.m;
        },
        set: function (v) {
            this.i.m = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGridToolbar.prototype, "actualTools", {
        get: function () {
            if (!this._actualTools) {
                this._actualTools = [];
            }
            return this._actualTools;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGridToolbar.prototype, "contentTools", {
        get: function () {
            if (!this._contentTools) {
                this._contentTools = [];
            }
            return this._contentTools;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGridToolbar.prototype, "tools", {
        get: function () {
            var _this = this;
            if (this._tools === null) {
                var coll = new IgrGridToolbarContentCollection();
                var inner = coll._innerColl;
                this._tools = coll;
                inner.addListener(function (sender, e) {
                    switch (e.action) {
                        case NotifyCollectionChangedAction.Add:
                            _this._toolsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                            break;
                        case NotifyCollectionChangedAction.Remove:
                            _this._toolsAdapter.removeManualItemAt(e.oldStartingIndex);
                            break;
                        case NotifyCollectionChangedAction.Replace:
                            _this._toolsAdapter.removeManualItemAt(e.oldStartingIndex);
                            _this._toolsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                            break;
                        case NotifyCollectionChangedAction.Reset:
                            _this._toolsAdapter.clearManualItems();
                            break;
                    }
                });
                ;
            }
            return this._tools;
        },
        enumerable: false,
        configurable: true
    });
    IgrGridToolbar.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.grid && this.grid.name && this.grid.name == name) {
            return this.grid;
        }
        if (this.tools != null && this.tools.findByName && this.tools.findByName(name)) {
            return this.tools.findByName(name);
        }
        return null;
    };
    IgrGridToolbar.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.grid && this.grid._styling) {
            this.grid._styling(container, component, this);
        }
        this._inStyling = false;
    };
    return IgrGridToolbar;
}(IgrDisplayDensityBaseElement));
export { IgrGridToolbar };
