import { __extends } from "tslib";
import * as React from 'react';
import { IgrRowIslandCollection } from "./igr-row-island-collection";
import { IgrRowType } from "./igr-row-type";
import { IgrCellType } from "./igr-cell-type";
import { IgrHierarchicalGridBaseDirective } from "./igr-hierarchical-grid-base-directive";
import { HierarchicalGrid } from "./HierarchicalGrid";
import { ContentChildrenManager } from "igniteui-react-core";
import { CollectionAdapter, ensureBool } from "igniteui-react-core";
import { RowIsland } from "./RowIsland";
import { NotifyCollectionChangedAction } from "igniteui-react-core";
/**
 * Hierarchical grid
 * @igxModule IgxHierarchicalGridModule
*/
var IgrHierarchicalGrid = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrHierarchicalGrid, _super);
    function IgrHierarchicalGrid(props) {
        var _this = _super.call(this, props) || this;
        _this._childLayoutList = null;
        _this._getMainRef = _this._getMainRef.bind(_this);
        return _this;
    }
    IgrHierarchicalGrid.prototype.createImplementation = function () {
        var impl = new HierarchicalGrid();
        var nat;
        if (typeof document !== 'undefined') {
            nat = document.createElement("igc-hierarchical-grid");
        }
        else {
            nat = {
                style: {}
            };
        }
        nat.style.width = "100%";
        nat.style.height = "100%";
        impl.setNativeElement(nat);
        return impl;
    };
    Object.defineProperty(IgrHierarchicalGrid.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrHierarchicalGrid.prototype._initializeAdapters = function () {
        var _this = this;
        if (!this._contentChildrenManager) {
            var resolveNested_1 = (function (props, propName, nestedPropName) {
                var _a;
                var prop = props[propName];
                if (Array.isArray(prop)) {
                    return prop.map(function (x) {
                        var _a;
                        return (_a = x[nestedPropName]) !== null && _a !== void 0 ? _a : resolveNested_1(x.props, propName, nestedPropName);
                    }).join("_");
                }
                else if (prop) {
                    return (_a = prop.props[nestedPropName]) !== null && _a !== void 0 ? _a : resolveNested_1(prop.props, propName, nestedPropName);
                }
                else {
                    return props[nestedPropName];
                }
            });
            this._contentChildrenManager = new ContentChildrenManager(function (ch) {
                var key = ch.key || ch.props.name;
                if (!key) {
                    var type = (ch.type);
                    var instance = new type;
                    var name_1 = instance.i.$type.name;
                    switch (name_1) {
                        case "RowIsland": return ch.props.childDataKey;
                        case "ActionStrip": return "IgrActionStrip";
                        case "GridToolbar": return "IgrGridToolbar";
                        case "Paginator": return "IgrPaginator";
                        case "Column": return ch.props.field;
                        case "ColumnGroup": return resolveNested_1(ch.props, "children", "field");
                        case "ColumnLayout": return resolveNested_1(ch.props, "children", "field");
                        case "GridState": return "IgrGridState";
                        default: return undefined;
                    }
                }
                return key;
            }, function (ch) {
                var key = ch.key || ch.props.name;
                if (!key) {
                    var type = (ch.type);
                    var instance = new type;
                    var name_2 = instance.i.$type.name;
                    switch (name_2) {
                        case "RowIsland": return ch.props.childDataKey;
                        case "ActionStrip": return "IgrActionStrip";
                        case "GridToolbar": return "IgrGridToolbar";
                        case "Paginator": return "IgrPaginator";
                        case "Column": return ch.props.field;
                        case "ColumnGroup": return resolveNested_1(ch.props, "children", "field");
                        case "ColumnLayout": return resolveNested_1(ch.props, "children", "field");
                        case "GridState": return "IgrGridState";
                        default: return undefined;
                    }
                }
                return key;
            }, function () {
                if (_this._updateContentChildren) {
                    _this._updateContentChildren();
                }
                else if (_this._updateAdapters) {
                    _this._updateAdapters();
                }
            });
        }
        this._childLayoutListAdapter = new CollectionAdapter(this.contentChildLayoutList, this.i.g6, this.actualChildLayoutList, function (c) { return c.i; }, function (i) {
            if (_this._initializeElement) {
                _this._initializeElement(i);
            }
        }, function (i) {
            if (_this._destroyElement) {
                _this._destroyElement(i);
            }
        });
        if (_super.prototype["_initializeAdapters"]) {
            _super.prototype["_initializeAdapters"].call(this);
        }
    };
    IgrHierarchicalGrid.prototype._updateAdapters = function () {
        if (_super.prototype["_updateAdapters"]) {
            _super.prototype["_updateAdapters"].call(this);
        }
        var contentChildrenActual = this._contentChildrenManager.contentChildrenActual;
        this.contentChildLayoutList.length = 0;
        for (var i = 0; i < contentChildrenActual.length; i++) {
            if ((RowIsland.$type).isAssignableFrom(contentChildrenActual[i].i.$type)) {
                this.contentChildLayoutList.push(contentChildrenActual[i]);
            }
        }
        if (this._childLayoutListAdapter != null) {
            this._childLayoutListAdapter.notifyContentChanged();
        }
    };
    IgrHierarchicalGrid.prototype.componentDidMount = function () {
        this.mounted = true;
        _super.prototype.componentDidMount.call(this);
        this._elRef.appendChild(this.i.nativeElement);
    };
    IgrHierarchicalGrid.prototype.render = function () {
        var children = this._contentChildrenManager.getChildren(this.props.children);
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        if (this.props.height) {
            style.height = this.props.height;
        }
        if (this.props.width) {
            style.width = this.props.width;
        }
        var div = React.createElement("div", {
            ref: this._getMainRef,
            id: this.props.id,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    };
    IgrHierarchicalGrid.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrHierarchicalGrid.prototype, "actualChildLayoutList", {
        get: function () {
            if (!this._actualChildLayoutList) {
                this._actualChildLayoutList = [];
            }
            return this._actualChildLayoutList;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrHierarchicalGrid.prototype, "contentChildLayoutList", {
        get: function () {
            if (!this._contentChildLayoutList) {
                this._contentChildLayoutList = [];
            }
            return this._contentChildLayoutList;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrHierarchicalGrid.prototype, "childLayoutList", {
        /**
         * @hidden
        */
        get: function () {
            var _this = this;
            if (this._childLayoutList === null) {
                var coll = new IgrRowIslandCollection();
                var inner = coll._innerColl;
                this._childLayoutList = coll;
                inner.addListener(function (sender, e) {
                    switch (e.action) {
                        case NotifyCollectionChangedAction.Add:
                            _this._childLayoutListAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                            break;
                        case NotifyCollectionChangedAction.Remove:
                            _this._childLayoutListAdapter.removeManualItemAt(e.oldStartingIndex);
                            break;
                        case NotifyCollectionChangedAction.Replace:
                            _this._childLayoutListAdapter.removeManualItemAt(e.oldStartingIndex);
                            _this._childLayoutListAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                            break;
                        case NotifyCollectionChangedAction.Reset:
                            _this._childLayoutListAdapter.clearManualItems();
                            break;
                    }
                });
                ;
            }
            return this._childLayoutList;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrHierarchicalGrid.prototype, "id", {
        get: function () {
            return this.i.he;
        },
        set: function (v) {
            this.i.he = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrHierarchicalGrid.prototype, "data", {
        get: function () {
            return this.i.g2;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.g2 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrHierarchicalGrid.prototype, "totalItemCount", {
        /**
         * Gets/Sets the total number of records in the data source.
         * @remarks
         * This property is required for remote grid virtualization to function when it is bound to remote data.
         * @example
         * ```typescript
         * const itemCount = this.grid1.totalItemCount;
         * this.grid1.totalItemCount = 55;
         * ```
        */
        get: function () {
            return this.i.hc;
        },
        set: function (v) {
            this.i.hc = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrHierarchicalGrid.prototype, "expandChildren", {
        get: function () {
            return this.i.g9;
        },
        set: function (v) {
            this.i.g9 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrHierarchicalGrid.prototype, "foreignKey", {
        /**
         * Gets the unique identifier of the parent row. It may be a `string` or `number` if `primaryKey` of the
         * parent grid is set or an object reference of the parent record otherwise.
         * ```typescript
         * const foreignKey = this.grid.foreignKey;
         * ```
         * @memberof IgxHierarchicalGridComponent
        */
        get: function () {
            return this.i.hd;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrHierarchicalGrid.prototype, "selectedCells", {
        /**
         * Returns an array of the selected `IgxGridCell`s.
         * @example
         * ```typescript
         * const selectedCells = this.grid.selectedCells;
         * ```
        */
        get: function () {
            if (!this.i.g3) {
                return undefined;
            }
            var ret = [];
            for (var i = 0; i < this.i.g3.length; i++) {
                var impl = this.i.g3[i];
                if (!impl.externalObject) {
                    if (impl instanceof IgrCellType) {
                        ret.push(impl);
                        continue;
                    }
                    var e = new IgrCellType();
                    e._implementation = impl;
                    impl.externalObject = e;
                }
                ret.push(impl.externalObject);
            }
            return ret;
        },
        enumerable: false,
        configurable: true
    });
    IgrHierarchicalGrid.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.childLayoutList != null && this.childLayoutList.findByName && this.childLayoutList.findByName(name)) {
            return this.childLayoutList.findByName(name);
        }
        return null;
    };
    /**
     * Returns the `RowType` by index.
     * @example
     * ```typescript
     * const myRow = this.grid1.getRowByIndex(1);
     * ```
     * index
    
    * @param   * index
    */
    IgrHierarchicalGrid.prototype.getRowByIndex = function (index) {
        var iv = this.i.g7(index);
        var ret = null;
        if (iv && iv.externalObject) {
            ret = iv.externalObject;
        }
        else {
            if (iv) {
                var e = new IgrRowType();
                e._implementation = iv;
                iv.externalObject = e;
                ret = e;
            }
        }
        return ret;
    };
    /**
     * Returns the `RowType` by key.
     * @example
     * ```typescript
     * const myRow = this.grid1.getRowByKey(1);
     * ```
     * key
    
    * @param   * key
    */
    IgrHierarchicalGrid.prototype.getRowByKey = function (key) {
        var iv = this.i.g8(key);
        var ret = null;
        if (iv && iv.externalObject) {
            ret = iv.externalObject;
        }
        else {
            if (iv) {
                var e = new IgrRowType();
                e._implementation = iv;
                iv.externalObject = e;
                ret = e;
            }
        }
        return ret;
    };
    IgrHierarchicalGrid.prototype.getCellByColumn = function (rowIndex, columnField) {
        var iv = this.i.g4(rowIndex, columnField);
        var ret = null;
        if (iv && iv.externalObject) {
            ret = iv.externalObject;
        }
        else {
            if (iv) {
                var e = new IgrCellType();
                e._implementation = iv;
                iv.externalObject = e;
                ret = e;
            }
        }
        return ret;
    };
    IgrHierarchicalGrid.prototype.getCellByKey = function (rowSelector, columnField) {
        var iv = this.i.g5(rowSelector, columnField);
        var ret = null;
        if (iv && iv.externalObject) {
            ret = iv.externalObject;
        }
        else {
            if (iv) {
                var e = new IgrCellType();
                e._implementation = iv;
                iv.externalObject = e;
                ret = e;
            }
        }
        return ret;
    };
    IgrHierarchicalGrid.prototype.pinRow = function (rowID, index) {
        var iv = this.i.ha(rowID, index);
        return (iv);
    };
    IgrHierarchicalGrid.prototype.unpinRow = function (rowID) {
        var iv = this.i.hb(rowID);
        return (iv);
    };
    IgrHierarchicalGrid.prototype.getDefaultExpandState = function (record) {
        this.i.hf(record);
    };
    return IgrHierarchicalGrid;
}(IgrHierarchicalGridBaseDirective));
export { IgrHierarchicalGrid };
