import { __extends } from "tslib";
import { IgrCellInfo } from "./igr-cell-info";
import { NumericCellModel as NumericCellModel_internal } from "./NumericCellModel";
import { ensureBool, arrayFindByName } from "igniteui-react-core";
/**
 * Backing information for a numeric cell in the grid.
*/
var IgrNumericCellInfo = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrNumericCellInfo, _super);
    function IgrNumericCellInfo() {
        return _super.call(this) || this;
    }
    IgrNumericCellInfo.prototype.createImplementation = function () {
        return new NumericCellModel_internal();
    };
    Object.defineProperty(IgrNumericCellInfo.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericCellInfo.prototype, "numericValue", {
        /**
         * Sets or gets the numeric value to use for the cell.
        */
        get: function () {
            return this.i.ls;
        },
        set: function (v) {
            this.i.ls = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericCellInfo.prototype, "hasDecimalValue", {
        /**
         * Sets or gets whether there is a decimal numeric value to use for the cell.
        */
        get: function () {
            return this.i.lo;
        },
        set: function (v) {
            this.i.lo = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericCellInfo.prototype, "formatStringOverride", {
        /**
         * The format string to apply to the value
        */
        get: function () {
            return this.i.mm;
        },
        set: function (v) {
            this.i.mm = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericCellInfo.prototype, "formatSpecifiers", {
        get: function () {
            return this.i.lk;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.lk = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericCellInfo.prototype, "formatOverride", {
        /**
         * The format options to apply to the value
        */
        get: function () {
            return this.i.me;
        },
        set: function (v) {
            this.i.me = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericCellInfo.prototype, "negativePrefix", {
        /**
         * Sets or gets the text prepended to a negative numeric value
        */
        get: function () {
            return this.i.ms;
        },
        set: function (v) {
            this.i.ms = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericCellInfo.prototype, "positivePrefix", {
        /**
         * Sets or gets the text prepended to a positive numeric value
        */
        get: function () {
            return this.i.mx;
        },
        set: function (v) {
            this.i.mx = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericCellInfo.prototype, "negativeSuffix", {
        /**
         * Sets or gets the text appended to a negative numeric value
        */
        get: function () {
            return this.i.mu;
        },
        set: function (v) {
            this.i.mu = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericCellInfo.prototype, "positiveSuffix", {
        /**
         * Sets or gets the text appended to a positive numeric value
        */
        get: function () {
            return this.i.mz;
        },
        set: function (v) {
            this.i.mz = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericCellInfo.prototype, "maxFractionDigits", {
        /**
         * The maximum number of decimal places to display when formatting
        */
        get: function () {
            return this.i.l0;
        },
        set: function (v) {
            this.i.l0 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericCellInfo.prototype, "minFractionDigits", {
        /**
         * The minimum number of decimal places to display when formatting
        */
        get: function () {
            return this.i.l2;
        },
        set: function (v) {
            this.i.l2 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericCellInfo.prototype, "minIntegerDigits", {
        /**
         * The minimum number of integer digits to display when formatting
        */
        get: function () {
            return this.i.l4;
        },
        set: function (v) {
            this.i.l4 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericCellInfo.prototype, "showGroupingSeparator", {
        /**
         * Sets or gets if the grouping separator is shown
        */
        get: function () {
            return this.i.lq;
        },
        set: function (v) {
            this.i.lq = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    IgrNumericCellInfo.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.formatSpecifiers != null && arrayFindByName(this.formatSpecifiers, name)) {
            return arrayFindByName(this.formatSpecifiers, name);
        }
        return null;
    };
    return IgrNumericCellInfo;
}(IgrCellInfo));
export { IgrNumericCellInfo };
