import { __extends } from "tslib";
import { EditorType_$type } from "./EditorType";
import { IgrDataGridColumn } from "./igr-data-grid-column";
import { NumericColumn } from "./NumericColumn";
import { ensureBool, ensureEnum, arrayFindByName } from "igniteui-react-core";
/**
 * Represents a Numeric grid column, used to allow the developer to display a formatted number in a cell.
*/
var IgrNumericColumn = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrNumericColumn, _super);
    function IgrNumericColumn(props) {
        return _super.call(this, props) || this;
    }
    IgrNumericColumn.prototype.createImplementation = function () {
        return new NumericColumn();
    };
    Object.defineProperty(IgrNumericColumn.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericColumn.prototype, "negativePrefix", {
        /**
         * Gets or sets the string to prefix a negative value. If FormatString is specificied this value is ignored.
        */
        get: function () {
            return this.i.mg;
        },
        set: function (v) {
            this.i.mg = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericColumn.prototype, "positivePrefix", {
        /**
         * Gets or sets the string to prefix a positive value. If FormatString is specificied this value is ignored.
        */
        get: function () {
            return this.i.mk;
        },
        set: function (v) {
            this.i.mk = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericColumn.prototype, "negativeSuffix", {
        /**
         * Gets or sets the string to suffix a negative value. If FormatString is specificied this value is ignored.
        */
        get: function () {
            return this.i.mi;
        },
        set: function (v) {
            this.i.mi = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericColumn.prototype, "positiveSuffix", {
        /**
         * Gets or sets the string to suffix a positive value. If FormatString is specificied this value is ignored.
        */
        get: function () {
            return this.i.mm;
        },
        set: function (v) {
            this.i.mm = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericColumn.prototype, "maxFractionDigits", {
        /**
         * Gets or sets the maximum fraction digits. If FormatString is specificied this value is ignored.
        */
        get: function () {
            return this.i.lv;
        },
        set: function (v) {
            this.i.lv = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericColumn.prototype, "minFractionDigits", {
        /**
         * Gets or sets the minimum fraction digits. If FormatString is specificied this value is ignored.
        */
        get: function () {
            return this.i.lw;
        },
        set: function (v) {
            this.i.lw = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericColumn.prototype, "minIntegerDigits", {
        /**
         * Gets or sets the minimum integer digits. If FormatString is specificied this value is ignored.
        */
        get: function () {
            return this.i.lx;
        },
        set: function (v) {
            this.i.lx = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericColumn.prototype, "showGroupingSeparator", {
        /**
         * Gets or sets whether to show a grouping separator. If FormatString is specificied this value is ignored.
        */
        get: function () {
            return this.i.lq;
        },
        set: function (v) {
            this.i.lq = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericColumn.prototype, "formatString", {
        /**
         * Gets or sets the format string to apply to the value. If set, the other value formatting properties on this column are ignored.
        */
        get: function () {
            return this.i.mb;
        },
        set: function (v) {
            this.i.mb = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericColumn.prototype, "formatSpecifiers", {
        get: function () {
            return this.i.lm;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.lm = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericColumn.prototype, "formatOverride", {
        /**
         * Gets or sets the INTL NumericFormat object to use for formatting the date values.
        */
        get: function () {
            return this.i.l0;
        },
        set: function (v) {
            this.i.l0 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericColumn.prototype, "editorType", {
        /**
         * Gets or sets the editor type used for editing cells in this column.
        */
        get: function () {
            return this.i.lo;
        },
        set: function (v) {
            this.i.lo = ensureEnum(EditorType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericColumn.prototype, "editorDataSource", {
        /**
         * Gets or sets the ComboBox data source.
        */
        get: function () {
            return this.i.lz;
        },
        set: function (v) {
            this.i.lz = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericColumn.prototype, "editorTextField", {
        /**
         * Gets or sets the ComboBox text field.
        */
        get: function () {
            return this.i.l6;
        },
        set: function (v) {
            this.i.l6 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrNumericColumn.prototype, "editorValueField", {
        /**
         * Gets or sets the ComboBox value field.
        */
        get: function () {
            return this.i.l7;
        },
        set: function (v) {
            this.i.l7 = v;
        },
        enumerable: false,
        configurable: true
    });
    IgrNumericColumn.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.formatSpecifiers != null && arrayFindByName(this.formatSpecifiers, name)) {
            return arrayFindByName(this.formatSpecifiers, name);
        }
        return null;
    };
    return IgrNumericColumn;
}(IgrDataGridColumn));
export { IgrNumericColumn };
