import { __extends } from "tslib";
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrNumberEventArgs } from "igniteui-react";
import { IgrPageCancellableEventArgs } from "./igr-page-cancellable-event-args";
import { IgrPageEventArgs } from "./igr-page-event-args";
import { IgrDisplayDensityBaseElement } from "./igr-display-density-base-element";
import { Paginator } from "./Paginator";
import { interfaceToInternal } from "igniteui-react-core";
import { OverlaySettings } from "./OverlaySettings";
import { PaginatorResourceStrings } from "./PaginatorResourceStrings";
/**
 * Paginator component description
 * @igxParent IgxGridComponent, IgxTreeGridComponent, IgxHierarchicalGridComponent, IgxPivotGridComponent, *
*/
var IgrPaginator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrPaginator, _super);
    function IgrPaginator(props) {
        var _this = _super.call(this, props) || this;
        _this._perPageChange = null;
        _this._perPageChange_wrapped = null;
        _this._pageChange = null;
        _this._pageChange_wrapped = null;
        _this._paging = null;
        _this._paging_wrapped = null;
        _this._pagingDone = null;
        _this._pagingDone_wrapped = null;
        _this._getMainRef = _this._getMainRef.bind(_this);
        return _this;
    }
    IgrPaginator.prototype.createImplementation = function () {
        var impl = new Paginator();
        var nat;
        if (typeof document !== 'undefined') {
            nat = document.createElement("igc-paginator");
        }
        else {
            nat = {
                style: {}
            };
        }
        impl.setNativeElement(nat);
        return impl;
    };
    Object.defineProperty(IgrPaginator.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrPaginator.prototype.componentDidMount = function () {
        this.mounted = true;
        _super.prototype.componentDidMount.call(this);
    };
    IgrPaginator.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("div", {
            ref: this._getMainRef,
            id: this.props.id,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    };
    IgrPaginator.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrPaginator.prototype, "totalPages", {
        /**
         * Total pages calculated from totalRecords and perPage
        */
        get: function () {
            return this.i.r;
        },
        set: function (v) {
            this.i.r = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPaginator.prototype, "page", {
        /**
         * An @Input property, sets current page of the `IgxPaginatorComponent`.
         * The default is 0.
         * ```typescript
         * let page = this.paginator.page;
         * ```
         * @memberof IgxPaginatorComponent
        */
        get: function () {
            return this.i.p;
        },
        set: function (v) {
            this.i.p = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPaginator.prototype, "perPage", {
        /**
         * An @Input property, sets number of visible items per page in the `IgxPaginatorComponent`.
         * The default is 15.
         * ```typescript
         * let itemsPerPage = this.paginator.perPage;
         * ```
         * @memberof IgxPaginatorComponent
        */
        get: function () {
            return this.i.q;
        },
        set: function (v) {
            this.i.q = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPaginator.prototype, "totalRecords", {
        /**
         * An @Input property that sets the total records.
         * ```typescript
         * let totalRecords = this.paginator.totalRecords;
         * ```
         * @memberof IgxPaginatorComponent
        */
        get: function () {
            return this.i.s;
        },
        set: function (v) {
            this.i.s = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPaginator.prototype, "selectOptions", {
        /**
         * An @Input property that sets custom options in the select of the paginator
         * ```typescript
         * let options = this.paginator.selectOptions;
         * ```
         * @memberof IgxPaginatorComponent
        */
        get: function () {
            return this.i.i;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.i = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPaginator.prototype, "overlaySettings", {
        get: function () {
            return this.i.l.nativeElement;
        },
        set: function (v) {
            this.i.l = interfaceToInternal(v, function () { return new OverlaySettings(); });
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPaginator.prototype, "resourceStrings", {
        /**
         * An accessor that sets the resource strings.
         * By default it uses EN resources.
        */
        get: function () {
            return this.i.o.nativeElement;
        },
        set: function (v) {
            this.i.o = interfaceToInternal(v, function () { return new PaginatorResourceStrings(); });
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPaginator.prototype, "name", {
        get: function () {
            return this.i.t;
        },
        set: function (v) {
            this.i.t = v;
        },
        enumerable: false,
        configurable: true
    });
    IgrPaginator.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.overlaySettings && this.overlaySettings.name && this.overlaySettings.name == name) {
            return this.overlaySettings;
        }
        if (this.resourceStrings && this.resourceStrings.name && this.resourceStrings.name == name) {
            return this.resourceStrings;
        }
        return null;
    };
    /**
     * Goes to the next page of the `IgxPaginatorComponent`, if the paginator is not already at the last page.
     * ```typescript
     * this.paginator.nextPage();
     * ```
     * @memberof IgxPaginatorComponent
    
    */
    IgrPaginator.prototype.nextPage = function () {
        this.i.u();
    };
    /**
     * Goes to the previous page of the `IgxPaginatorComponent`, if the paginator is not already at the first page.
     * ```typescript
     * this.paginator.previousPage();
     * ```
     * @memberof IgxPaginatorComponent
    
    */
    IgrPaginator.prototype.previousPage = function () {
        this.i.aa();
    };
    /**
     * Goes to the desired page index.
     * ```typescript
     * this.paginator.paginate(1);
     * ```
     * val
     * @memberof IgxPaginatorComponent
    
    * @param   * val
    */
    IgrPaginator.prototype.paginate = function (val) {
        this.i.w(val);
    };
    Object.defineProperty(IgrPaginator.prototype, "perPageChange", {
        get: function () {
            return this._perPageChange;
        },
        set: function (ev) {
            var _this = this;
            if (this._perPageChange_wrapped !== null) {
                this.i.perPageChange = delegateRemove(this.i.perPageChange, this._perPageChange_wrapped);
                this._perPageChange_wrapped = null;
                this._perPageChange = null;
            }
            this._perPageChange = ev;
            this._perPageChange_wrapped = function (o, e) {
                var outerArgs = new IgrNumberEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforePerPageChange) {
                    _this.beforePerPageChange(_this, outerArgs);
                }
                if (_this._perPageChange) {
                    _this._perPageChange(_this, outerArgs);
                }
            };
            this.i.perPageChange = delegateCombine(this.i.perPageChange, this._perPageChange_wrapped);
            if (this.i.perPageChangeChanged) {
                this.i.perPageChangeChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPaginator.prototype, "pageChange", {
        get: function () {
            return this._pageChange;
        },
        set: function (ev) {
            var _this = this;
            if (this._pageChange_wrapped !== null) {
                this.i.pageChange = delegateRemove(this.i.pageChange, this._pageChange_wrapped);
                this._pageChange_wrapped = null;
                this._pageChange = null;
            }
            this._pageChange = ev;
            this._pageChange_wrapped = function (o, e) {
                var outerArgs = new IgrNumberEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforePageChange) {
                    _this.beforePageChange(_this, outerArgs);
                }
                if (_this._pageChange) {
                    _this._pageChange(_this, outerArgs);
                }
            };
            this.i.pageChange = delegateCombine(this.i.pageChange, this._pageChange_wrapped);
            if (this.i.pageChangeChanged) {
                this.i.pageChangeChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPaginator.prototype, "paging", {
        get: function () {
            return this._paging;
        },
        set: function (ev) {
            var _this = this;
            if (this._paging_wrapped !== null) {
                this.i.paging = delegateRemove(this.i.paging, this._paging_wrapped);
                this._paging_wrapped = null;
                this._paging = null;
            }
            this._paging = ev;
            this._paging_wrapped = function (o, e) {
                var outerArgs = new IgrPageCancellableEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforePaging) {
                    _this.beforePaging(_this, outerArgs);
                }
                if (_this._paging) {
                    _this._paging(_this, outerArgs);
                }
            };
            this.i.paging = delegateCombine(this.i.paging, this._paging_wrapped);
            if (this.i.pagingChanged) {
                this.i.pagingChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPaginator.prototype, "pagingDone", {
        get: function () {
            return this._pagingDone;
        },
        set: function (ev) {
            var _this = this;
            if (this._pagingDone_wrapped !== null) {
                this.i.pagingDone = delegateRemove(this.i.pagingDone, this._pagingDone_wrapped);
                this._pagingDone_wrapped = null;
                this._pagingDone = null;
            }
            this._pagingDone = ev;
            this._pagingDone_wrapped = function (o, e) {
                var outerArgs = new IgrPageEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforePagingDone) {
                    _this.beforePagingDone(_this, outerArgs);
                }
                if (_this._pagingDone) {
                    _this._pagingDone(_this, outerArgs);
                }
            };
            this.i.pagingDone = delegateCombine(this.i.pagingDone, this._pagingDone_wrapped);
            if (this.i.pagingDoneChanged) {
                this.i.pagingDoneChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrPaginator;
}(IgrDisplayDensityBaseElement));
export { IgrPaginator };
