import { IgrPivotAggregator } from "./igr-pivot-aggregator";
import { IgrPivotAggregatorCollection } from "./igr-pivot-aggregator-collection";
import { GridColumnDataType_$type } from "./GridColumnDataType";
import { PivotValueDetail as PivotValueDetail_internal } from "./PivotValueDetail";
import { PivotAggregatorCollection as PivotAggregatorCollection_internal } from "./PivotAggregatorCollection";
import { PivotAggregator } from "./PivotAggregator";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
import { ensureBool, ensureEnum } from "igniteui-react-core";
/**
 * Configuration of a pivot value aggregation.
*/
var IgrPivotValueDetail = /** @class */ /*@__PURE__*/ (function () {
    function IgrPivotValueDetail() {
        this.mounted = false;
        this._aggregateList = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrPivotValueDetail.prototype.createImplementation = function () {
        return new PivotValueDetail_internal();
    };
    Object.defineProperty(IgrPivotValueDetail.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrPivotValueDetail.prototype.onImplementationCreated = function () {
    };
    IgrPivotValueDetail.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrPivotValueDetail.prototype, "member", {
        /**
         * Field name to use in order to extract value.
        */
        get: function () {
            return this.i.l;
        },
        set: function (v) {
            this.i.l = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPivotValueDetail.prototype, "displayName", {
        /**
         * Display name to show instead of member for the column header of this value. *
        */
        get: function () {
            return this.i.k;
        },
        set: function (v) {
            this.i.k = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPivotValueDetail.prototype, "aggregate", {
        /**
         * Active aggregator definition with key, label and aggregator.
        */
        get: function () {
            var r = this.i.b;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrPivotAggregator();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.b = null : this.i.b = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPivotValueDetail.prototype, "aggregateList", {
        /**
         * List of aggregates to show in aggregate drop-down.
        */
        get: function () {
            if (this._aggregateList === null) {
                var coll = new IgrPivotAggregatorCollection();
                var innerColl = this.i.c;
                if (!innerColl) {
                    innerColl = new PivotAggregatorCollection_internal();
                }
                this._aggregateList = coll._fromInner(innerColl);
            }
            return this._aggregateList;
        },
        set: function (v) {
            if (this._aggregateList !== null) {
                this._aggregateList._setSyncTarget(null);
                this._aggregateList = null;
            }
            var coll = new IgrPivotAggregatorCollection();
            this._aggregateList = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(PivotAggregator.$type);
            var innerColl = this.i.c;
            if (!innerColl) {
                innerColl = new PivotAggregatorCollection_internal();
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._aggregateList._setSyncTarget(syncColl);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPivotValueDetail.prototype, "enabled", {
        /**
         * Enables/Disables a particular value from pivot aggregation.
        */
        get: function () {
            return this.i.g;
        },
        set: function (v) {
            this.i.g = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPivotValueDetail.prototype, "styles", {
        /**
         * Allow conditionally styling of the IgxPivotGrid cells.
        */
        get: function () {
            return this.i.j;
        },
        set: function (v) {
            this.i.j = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPivotValueDetail.prototype, "dataType", {
        /**
         * Enables a data type specific template of the cells
        */
        get: function () {
            return this.i.a;
        },
        set: function (v) {
            this.i.a = ensureEnum(GridColumnDataType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    IgrPivotValueDetail.prototype.findByName = function (name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        if (this.aggregate && this.aggregate.name && this.aggregate.name == name) {
            return this.aggregate;
        }
        if (this.aggregateList != null && this.aggregateList.findByName && this.aggregateList.findByName(name)) {
            return this.aggregateList.findByName(name);
        }
        return null;
    };
    IgrPivotValueDetail.prototype.setNativeElement = function (element) {
        this.i.setNativeElement(element);
    };
    return IgrPivotValueDetail;
}());
export { IgrPivotValueDetail };
