import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrToggleViewEventArgs } from "./igr-toggle-view-event-args";
import { IgrToggleViewCancelableEventArgs } from "./igr-toggle-view-cancelable-event-args";
import { ToggleDirective as ToggleDirective_internal } from "./ToggleDirective";
import { interfaceToInternal } from "igniteui-react-core";
import { OverlaySettings } from "./OverlaySettings";
var IgrToggleDirective = /** @class */ /*@__PURE__*/ (function () {
    function IgrToggleDirective() {
        this.mounted = false;
        this._opened = null;
        this._opened_wrapped = null;
        this._opening = null;
        this._opening_wrapped = null;
        this._closed = null;
        this._closed_wrapped = null;
        this._closing = null;
        this._closing_wrapped = null;
        this._appended = null;
        this._appended_wrapped = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrToggleDirective.prototype.createImplementation = function () {
        return new ToggleDirective_internal();
    };
    Object.defineProperty(IgrToggleDirective.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrToggleDirective.prototype.onImplementationCreated = function () {
    };
    IgrToggleDirective.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrToggleDirective.prototype, "id", {
        /**
         * Identifier which is registered into `IgxNavigationService`
         * ```typescript
         * let myToggleId = this.toggle.id;
         * ```
        */
        get: function () {
            return this.i.j;
        },
        set: function (v) {
            this.i.j = v;
        },
        enumerable: false,
        configurable: true
    });
    IgrToggleDirective.prototype.findByName = function (name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    };
    IgrToggleDirective.prototype.setNativeElement = function (element) {
        this.i.setNativeElement(element);
    };
    /**
     * Opens the toggle.
     * ```typescript
     * this.myToggle.open();
     * ```
    
    */
    IgrToggleDirective.prototype.open = function (overlaySettings) {
        this.i.n((overlaySettings == null ? null : interfaceToInternal(overlaySettings, function () { return new OverlaySettings(); })));
    };
    /**
     * Opens or closes the toggle, depending on its current state.
     * ```typescript
     * this.myToggle.toggle();
     * ```
    
    */
    IgrToggleDirective.prototype.toggle = function (overlaySettings) {
        this.i.t((overlaySettings == null ? null : interfaceToInternal(overlaySettings, function () { return new OverlaySettings(); })));
    };
    /**
     * Repositions the toggle.
     * ```typescript
     * this.myToggle.reposition();
     * ```
    
    */
    IgrToggleDirective.prototype.reposition = function () {
        this.i.q();
    };
    IgrToggleDirective.prototype.setOffset = function (deltaX, deltaY) {
        this.i.s(deltaX, deltaY);
    };
    Object.defineProperty(IgrToggleDirective.prototype, "opened", {
        get: function () {
            return this._opened;
        },
        set: function (ev) {
            var _this = this;
            if (this._opened_wrapped !== null) {
                this.i.opened = delegateRemove(this.i.opened, this._opened_wrapped);
                this._opened_wrapped = null;
                this._opened = null;
            }
            this._opened = ev;
            this._opened_wrapped = function (o, e) {
                var outerArgs = new IgrToggleViewEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeOpened) {
                    _this.beforeOpened(_this, outerArgs);
                }
                if (_this._opened) {
                    _this._opened(_this, outerArgs);
                }
            };
            this.i.opened = delegateCombine(this.i.opened, this._opened_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToggleDirective.prototype, "opening", {
        get: function () {
            return this._opening;
        },
        set: function (ev) {
            var _this = this;
            if (this._opening_wrapped !== null) {
                this.i.opening = delegateRemove(this.i.opening, this._opening_wrapped);
                this._opening_wrapped = null;
                this._opening = null;
            }
            this._opening = ev;
            this._opening_wrapped = function (o, e) {
                var outerArgs = new IgrToggleViewCancelableEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeOpening) {
                    _this.beforeOpening(_this, outerArgs);
                }
                if (_this._opening) {
                    _this._opening(_this, outerArgs);
                }
            };
            this.i.opening = delegateCombine(this.i.opening, this._opening_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToggleDirective.prototype, "closed", {
        get: function () {
            return this._closed;
        },
        set: function (ev) {
            var _this = this;
            if (this._closed_wrapped !== null) {
                this.i.closed = delegateRemove(this.i.closed, this._closed_wrapped);
                this._closed_wrapped = null;
                this._closed = null;
            }
            this._closed = ev;
            this._closed_wrapped = function (o, e) {
                var outerArgs = new IgrToggleViewEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeClosed) {
                    _this.beforeClosed(_this, outerArgs);
                }
                if (_this._closed) {
                    _this._closed(_this, outerArgs);
                }
            };
            this.i.closed = delegateCombine(this.i.closed, this._closed_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToggleDirective.prototype, "closing", {
        get: function () {
            return this._closing;
        },
        set: function (ev) {
            var _this = this;
            if (this._closing_wrapped !== null) {
                this.i.closing = delegateRemove(this.i.closing, this._closing_wrapped);
                this._closing_wrapped = null;
                this._closing = null;
            }
            this._closing = ev;
            this._closing_wrapped = function (o, e) {
                var outerArgs = new IgrToggleViewCancelableEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeClosing) {
                    _this.beforeClosing(_this, outerArgs);
                }
                if (_this._closing) {
                    _this._closing(_this, outerArgs);
                }
            };
            this.i.closing = delegateCombine(this.i.closing, this._closing_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToggleDirective.prototype, "appended", {
        get: function () {
            return this._appended;
        },
        set: function (ev) {
            var _this = this;
            if (this._appended_wrapped !== null) {
                this.i.appended = delegateRemove(this.i.appended, this._appended_wrapped);
                this._appended_wrapped = null;
                this._appended = null;
            }
            this._appended = ev;
            this._appended_wrapped = function (o, e) {
                var outerArgs = new IgrToggleViewEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeAppended) {
                    _this.beforeAppended(_this, outerArgs);
                }
                if (_this._appended) {
                    _this._appended(_this, outerArgs);
                }
            };
            this.i.appended = delegateCombine(this.i.appended, this._appended_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrToggleDirective;
}());
export { IgrToggleDirective };
