
import { IgcBaseToolbarDirective } from './igc-base-toolbar-directive';
import { IgcExporterEventArgs } from './igc-exporter-event-args';
import { GridToolbarExporterType } from './grid-toolbar-exporter-type';
import { IgcToggleDirective } from './igc-toggle-directive';
import { EventEmitterMixin, LitElement, Constructor, AbstractConstructor } from './common';





/* blazorElement */
/* wcElementTag: igc-grid-toolbar-exporter */
/* blazorIndirectRender */
/* jsonAPIManageItemInMarkup */
/* singleInstanceIdentifier */
/**
 * Provides a pre-configured exporter component for the grid.
 *
 * @remarks
 * This component still needs the actual exporter service(s) provided in the DI chain
 * in order to export something.
 *
 * @igxModule IgxGridToolbarModule
 * @igxParent IgxGridToolbarComponent
 *
 */

    export declare class IgcGridToolbarExporterComponent extends EventEmitterMixin<IgcGridToolbarExporterComponentEventMap, AbstractConstructor<IgcBaseToolbarDirective>>(IgcBaseToolbarDirective)

    {

          

    /**
     * Show entry for CSV export.
     */
    public set exportCSV(value: boolean);
          public get exportCSV(): boolean;
  
          

    /**
     * Show entry for Excel export.
     */
    public set exportExcel(value: boolean);
          public get exportExcel(): boolean;
  
          

    /**
     * The name for the exported file.
     */
    public set filename(value: string);
          public get filename(): string;
  
          

    /**
     * Indicates whether there is an export in progress.
     */
    public set isExporting(value: boolean);
          public get isExporting(): boolean;
  
            

    /* alternateName: exportGrid */
    public export(type: GridToolbarExporterType, toggleRef?: IgcToggleDirective): void;

    }

export declare interface IgcGridToolbarExporterComponentEventMap {
            
        		    /**
		     * Emitted when starting an export operation. Re-emitted additionally
		     * by the grid itself.
		     */
exportStarted: CustomEvent<IgcExporterEventArgs>;

        		    /**
		     * Emitted on successful ending of an export operation.
		     */
 exportEnded: CustomEvent;

}
        