
import { IgcToggleViewEventArgs } from './igc-toggle-view-event-args';
import { IgcToggleViewCancelableEventArgs } from './igc-toggle-view-cancelable-event-args';
import { IgcOverlaySettings } from './igc-overlay-settings';
import { EventEmitterMixin, LitElement, Constructor, AbstractConstructor } from './common';





    export declare class IgcToggleDirective extends EventEmitterMixin<IgcToggleDirectiveEventMap, Constructor<LitElement>>(LitElement)

    {

          

    /**
     * Identifier which is registered into `IgxNavigationService`
     *
     * ```typescript
     * let myToggleId = this.toggle.id;
     * ```
     */
    public set id(value: string);
          public get id(): string;
  
                

    /**
     * Returns the id of the overlay the content is rendered in.
     * ```typescript
     * this.myToggle.overlayId;
     * ```
     */
    public get overlayId(): string;
        
            

    /**
     * Opens the toggle.
     *
     * ```typescript
     * this.myToggle.open();
     * ```
     */
    public open(overlaySettings?: IgcOverlaySettings): void;

            

    /**
     * Opens or closes the toggle, depending on its current state.
     *
     * ```typescript
     * this.myToggle.toggle();
     * ```
     */
    public toggle(overlaySettings?: IgcOverlaySettings): void;

            

    /**
     * Repositions the toggle.
     * ```typescript
     * this.myToggle.reposition();
     * ```
     */
    public reposition(): void;

            

    /**
     * Offsets the content along the corresponding axis by the provided amount
     */
    public setOffset(deltaX: number, deltaY: number): void;

    }

export declare interface IgcToggleDirectiveEventMap {
            
        		    /**
		     * Emits an event after the toggle container is opened.
		     *
		     * ```typescript
		     * onToggleOpened(event) {
		     *    alert("Toggle opened!");
		     * }
		     * ```
		     *
		     * ```html
		     * <div
		     *   igxToggle
		     *   (onOpened)='onToggleOpened($event)'>
		     * </div>
		     * ```
		     */
opened: CustomEvent<IgcToggleViewEventArgs>;

        		    /**
		     * Emits an event before the toggle container is opened.
		     *
		     * ```typescript
		     * onToggleOpening(event) {
		     *  alert("Toggle opening!");
		     * }
		     * ```
		     *
		     * ```html
		     * <div
		     *   igxToggle
		     *   (onOpening)='onToggleOpening($event)'>
		     * </div>
		     * ```
		     */
opening: CustomEvent<IgcToggleViewCancelableEventArgs>;

        		    /**
		     * Emits an event after the toggle container is closed.
		     *
		     * ```typescript
		     * onToggleClosed(event) {
		     *  alert("Toggle closed!");
		     * }
		     * ```
		     *
		     * ```html
		     * <div
		     *   igxToggle
		     *   (onClosed)='onToggleClosed($event)'>
		     * </div>
		     * ```
		     */
closed: CustomEvent<IgcToggleViewEventArgs>;

        		    /**
		     * Emits an event before the toggle container is closed.
		     *
		     * ```typescript
		     * onToggleClosing(event) {
		     *  alert("Toggle closing!");
		     * }
		     * ```
		     *
		     * ```html
		     * <div
		     *  igxToggle
		     *  (closing)='onToggleClosing($event)'>
		     * </div>
		     * ```
		     */
closing: CustomEvent<IgcToggleViewCancelableEventArgs>;

        		    /**
		     * Emits an event after the toggle element is appended to the overlay container.
		     *
		     * ```typescript
		     * onAppended() {
		     *  alert("Content appended!");
		     * }
		     * ```
		     *
		     * ```html
		     * <div
		     *   igxToggle
		     *   (onAppended)='onToggleAppended()'>
		     * </div>
		     * ```
		     */
appended: CustomEvent<IgcToggleViewEventArgs>;

}
        