import { IgrOverlaySettings } from "./igr-overlay-settings";
import { IgrToggleViewCancelableEventArgs } from "./igr-toggle-view-cancelable-event-args";
import { IgrToggleViewEventArgs } from "./igr-toggle-view-event-args";
import { IgrColumnToggledEventArgs } from "./igr-column-toggled-event-args";
import { IgrGridToolbarBaseAction, IIgrGridToolbarBaseActionProps } from "./igr-grid-toolbar-base-action";
import { BaseToolbarDirective } from "./BaseToolbarDirective";
/**
 * Base class for the pinning/hiding column and exporter actions.
 * @hidden @internal
*/
export declare abstract class IgrBaseToolbarDirective<P extends IIgrBaseToolbarDirectiveProps = IIgrBaseToolbarDirectiveProps> extends IgrGridToolbarBaseAction<P> {
    /**
                                 * @hidden
                                 */
    get i(): BaseToolbarDirective;
    constructor(props: P);
    /**
     * Sets the height of the column list in the dropdown.
    */
    get columnListHeight(): string;
    set columnListHeight(v: string);
    /**
     * Title text for the column action component
    */
    get title(): string;
    set title(v: string);
    /**
     * The placeholder text for the search input.
    */
    get prompt(): string;
    set prompt(v: string);
    /**
     * Sets overlay settings
    */
    get overlaySettings(): IgrOverlaySettings;
    set overlaySettings(v: IgrOverlaySettings);
    get name(): string;
    set name(v: string);
    findByName(name: string): any;
    setNativeElement(element: any): void;
    private _opening;
    private _opening_wrapped;
    /**
     * Emits an event before the toggle container is opened.
    */
    get opening(): (s: IgrBaseToolbarDirective, e: IgrToggleViewCancelableEventArgs) => void;
    set opening(ev: (s: IgrBaseToolbarDirective, e: IgrToggleViewCancelableEventArgs) => void);
    private _opened;
    private _opened_wrapped;
    /**
     * Emits an event after the toggle container is opened.
    */
    get opened(): (s: IgrBaseToolbarDirective, e: IgrToggleViewEventArgs) => void;
    set opened(ev: (s: IgrBaseToolbarDirective, e: IgrToggleViewEventArgs) => void);
    private _closing;
    private _closing_wrapped;
    /**
     * Emits an event before the toggle container is closed.
    */
    get closing(): (s: IgrBaseToolbarDirective, e: IgrToggleViewEventArgs) => void;
    set closing(ev: (s: IgrBaseToolbarDirective, e: IgrToggleViewEventArgs) => void);
    private _closed;
    private _closed_wrapped;
    /**
     * Emits an event after the toggle container is closed.
    */
    get closed(): (s: IgrBaseToolbarDirective, e: IgrToggleViewEventArgs) => void;
    set closed(ev: (s: IgrBaseToolbarDirective, e: IgrToggleViewEventArgs) => void);
    private _columnToggle;
    private _columnToggle_wrapped;
    /**
     * Emits when after a column's checked state is changed
    */
    get columnToggle(): (s: IgrBaseToolbarDirective, e: IgrColumnToggledEventArgs) => void;
    set columnToggle(ev: (s: IgrBaseToolbarDirective, e: IgrColumnToggledEventArgs) => void);
}
export interface IIgrBaseToolbarDirectiveProps extends IIgrGridToolbarBaseActionProps {
    /**
     * Sets the height of the column list in the dropdown.
    */
    columnListHeight?: string;
    /**
     * Title text for the column action component
    */
    title?: string;
    /**
     * The placeholder text for the search input.
    */
    prompt?: string;
    /**
     * Sets overlay settings
    */
    overlaySettings?: IgrOverlaySettings;
    name?: string;
    /**
     * Emits an event before the toggle container is opened.
    */
    opening?: (s: IgrBaseToolbarDirective, e: IgrToggleViewCancelableEventArgs) => void;
    /**
     * Emits an event after the toggle container is opened.
    */
    opened?: (s: IgrBaseToolbarDirective, e: IgrToggleViewEventArgs) => void;
    /**
     * Emits an event before the toggle container is closed.
    */
    closing?: (s: IgrBaseToolbarDirective, e: IgrToggleViewEventArgs) => void;
    /**
     * Emits an event after the toggle container is closed.
    */
    closed?: (s: IgrBaseToolbarDirective, e: IgrToggleViewEventArgs) => void;
    /**
     * Emits when after a column's checked state is changed
    */
    columnToggle?: (s: IgrBaseToolbarDirective, e: IgrColumnToggledEventArgs) => void;
}
