import * as React from 'react';
import { DataSourceSchemaPropertyType } from "igniteui-react-core";
import { IgrOperatorSelectorValueChangedEventArgs } from "./igr-operator-selector-value-changed-event-args";
import { IgrOperatorSelectorOpeningEventArgs } from "./igr-operator-selector-opening-event-args";
import { IgrOperatorSelectorClosingEventArgs } from "./igr-operator-selector-closing-event-args";
import { ComparisonOperatorSelector } from "./ComparisonOperatorSelector";
import { ContentChildrenManager } from "igniteui-react-core";
import { ColumnComparisonConditionOperatorType } from "./ColumnComparisonConditionOperatorType";
/**
 * A dropdown selector for choosing which comparison operator to use.
*/
export declare class IgrDataGridComparisonOperatorSelector<P extends IIgrDataGridComparisonOperatorSelectorProps = IIgrDataGridComparisonOperatorSelectorProps> extends React.Component<P, {}> {
    protected createImplementation(): ComparisonOperatorSelector;
    protected _implementation: any;
    protected mounted: boolean;
    /**
     * @hidden
     */
    get i(): ComparisonOperatorSelector; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgrDataGridComparisonOperatorSelector;
    protected onImplementationCreated(): void;
    protected _contentChildrenManager: ContentChildrenManager;
    constructor(props: P);
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    render(): any;
    /**
     * Gets or sets the value of the selector.
    */
    get value(): ColumnComparisonConditionOperatorType;
    set value(v: ColumnComparisonConditionOperatorType);
    /**
     * Gets the ID for the custom filter that is selected. Value must be 'Custom' for this property to be valid.
    */
    get customFilterID(): string;
    set customFilterID(v: string);
    /**
     * Gets the index for the custom filter that is selected. Value must be 'Custom' for this property to be valid.
    */
    get customFilterIndex(): number;
    set customFilterIndex(v: number);
    /**
     * Gets or sets the data type. Used to determine what operators are available.
    */
    get dataType(): DataSourceSchemaPropertyType;
    set dataType(v: DataSourceSchemaPropertyType);
    get maxHeight(): number;
    set maxHeight(v: number);
    /**
     * Gets or sets the text color.
    */
    get textColor(): string;
    set textColor(v: string);
    /**
     * Gets or sets the background color.
    */
    get background(): string;
    set background(v: string);
    get operatorCaptionTrue(): string;
    get operatorCaptionFalse(): string;
    get operatorCaptionEquals(): string;
    get operatorCaptionNotEquals(): string;
    get operatorCaptionLessThan(): string;
    get operatorCaptionLessThanOrEqual(): string;
    get operatorCaptionGreaterThan(): string;
    get operatorCaptionGreaterThanOrEqual(): string;
    get operatorCaptionTop(): string;
    get operatorCaptionBottom(): string;
    get operatorCaptionTopPercentile(): string;
    get operatorCaptionBottomPercentile(): string;
    get operatorCaptionToday(): string;
    get operatorCaptionTomorrow(): string;
    get operatorCaptionYesterday(): string;
    get operatorCaptionThisWeek(): string;
    get operatorCaptionNextWeek(): string;
    get operatorCaptionLastWeek(): string;
    get operatorCaptionThisMonth(): string;
    get operatorCaptionNextMonth(): string;
    get operatorCaptionLastMonth(): string;
    get operatorCaptionThisQuarter(): string;
    get operatorCaptionNextQuarter(): string;
    get operatorCaptionLastQuarter(): string;
    get operatorCaptionThisYear(): string;
    get operatorCaptionNextYear(): string;
    get operatorCaptionLastYear(): string;
    get operatorCaptionYearToDate(): string;
    get operatorCaptionQ1(): string;
    get operatorCaptionQ2(): string;
    get operatorCaptionQ3(): string;
    get operatorCaptionQ4(): string;
    get operatorCaptionMonth(): string;
    get operatorCaptionYear(): string;
    get operatorCaptionStartsWith(): string;
    get operatorCaptionDoesNotStartWith(): string;
    get operatorCaptionEndsWith(): string;
    get operatorCaptionDoesNotEndWith(): string;
    get operatorCaptionContains(): string;
    get operatorCaptionDoesNotContain(): string;
    get operatorCaptionEmpty(): string;
    get operatorCaptionNotEmpty(): string;
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    provideContainer(container: any): void;
    dispose(): void;
    getDropdownHeight(): number;
    toggle(): void;
    close(): void;
    addCustomOperator(name: string, icon: string, id: string, index: number): void;
    clearCustomOperators(): void;
    selectCustomFilter(id: string, index: number): void;
    private _valueChanged;
    private _valueChanged_wrapped;
    get valueChanged(): (s: IgrDataGridComparisonOperatorSelector, e: IgrOperatorSelectorValueChangedEventArgs) => void;
    set valueChanged(ev: (s: IgrDataGridComparisonOperatorSelector, e: IgrOperatorSelectorValueChangedEventArgs) => void);
    private _opening;
    private _opening_wrapped;
    get opening(): (s: IgrDataGridComparisonOperatorSelector, e: IgrOperatorSelectorOpeningEventArgs) => void;
    set opening(ev: (s: IgrDataGridComparisonOperatorSelector, e: IgrOperatorSelectorOpeningEventArgs) => void);
    private _opened;
    private _opened_wrapped;
    get opened(): (s: IgrDataGridComparisonOperatorSelector, e: IgrOperatorSelectorOpeningEventArgs) => void;
    set opened(ev: (s: IgrDataGridComparisonOperatorSelector, e: IgrOperatorSelectorOpeningEventArgs) => void);
    private _closing;
    private _closing_wrapped;
    get closing(): (s: IgrDataGridComparisonOperatorSelector, e: IgrOperatorSelectorClosingEventArgs) => void;
    set closing(ev: (s: IgrDataGridComparisonOperatorSelector, e: IgrOperatorSelectorClosingEventArgs) => void);
}
export interface IIgrDataGridComparisonOperatorSelectorProps {
    children?: React.ReactNode;
    /**
     * Gets or sets the value of the selector.
    */
    value?: ColumnComparisonConditionOperatorType;
    /**
     * Gets the ID for the custom filter that is selected. Value must be 'Custom' for this property to be valid.
    */
    customFilterID?: string;
    /**
     * Gets the index for the custom filter that is selected. Value must be 'Custom' for this property to be valid.
    */
    customFilterIndex?: number | string;
    /**
     * Gets or sets the data type. Used to determine what operators are available.
    */
    dataType?: DataSourceSchemaPropertyType | string;
    maxHeight?: number | string;
    /**
     * Gets or sets the text color.
    */
    textColor?: string;
    /**
     * Gets or sets the background color.
    */
    background?: string;
    valueChanged?: (s: IgrDataGridComparisonOperatorSelector, e: IgrOperatorSelectorValueChangedEventArgs) => void;
    opening?: (s: IgrDataGridComparisonOperatorSelector, e: IgrOperatorSelectorOpeningEventArgs) => void;
    opened?: (s: IgrDataGridComparisonOperatorSelector, e: IgrOperatorSelectorOpeningEventArgs) => void;
    closing?: (s: IgrDataGridComparisonOperatorSelector, e: IgrOperatorSelectorClosingEventArgs) => void;
}
