import { DateTimeFormats } from "./DateTimeFormats";
import { EditorType } from "./EditorType";
import { IgrDataGridColumn, IIgrDataGridColumnProps } from "./igr-data-grid-column";
import { DateTimeColumn } from "./DateTimeColumn";
/**
 * A column for displaying date/time values.
*/
export declare class IgrDateTimeColumn extends IgrDataGridColumn<IIgrDateTimeColumnProps> {
    protected createImplementation(): DateTimeColumn;
    /**
                                 * @hidden
                                 */
    get i(): DateTimeColumn;
    constructor(props: IIgrDateTimeColumnProps);
    /**
     * Gets or sets the date time format to use for this column. If FormatString is specificied this value is ignored.
    */
    get dateTimeFormat(): DateTimeFormats;
    set dateTimeFormat(v: DateTimeFormats);
    /**
     * Gets or sets the format string to apply to the value. If set, the other value formatting properties on this column are ignored.
    */
    get formatString(): string;
    set formatString(v: string);
    /**
     * Gets or sets the format string to use when editing dates.
    */
    get editorFormatString(): string;
    set editorFormatString(v: string);
    get formatSpecifiers(): any[];
    set formatSpecifiers(v: any[]);
    /**
     * Gets or sets the INTL DateTimeFormat object to use for formatting the date values.
    */
    get formatOverride(): any;
    set formatOverride(v: any);
    /**
     * Gets or sets the ShowTodayButton property to detirmine if the today button is shown
    */
    get showTodayButton(): boolean;
    set showTodayButton(v: boolean);
    /**
     * Gets or sets the editor type used for editing cells in this column.
    */
    get editorType(): EditorType;
    set editorType(v: EditorType);
    /**
     * Gets or sets the ComboBox data source.
    */
    get editorDataSource(): any;
    set editorDataSource(v: any);
    /**
     * Gets or sets the ComboBox text field.
    */
    get editorTextField(): string;
    set editorTextField(v: string);
    /**
     * Gets or sets the ComboBox value field.
    */
    get editorValueField(): string;
    set editorValueField(v: string);
    findByName(name: string): any;
}
export interface IIgrDateTimeColumnProps extends IIgrDataGridColumnProps {
    /**
     * Gets or sets the date time format to use for this column. If FormatString is specificied this value is ignored.
    */
    dateTimeFormat?: DateTimeFormats | string;
    /**
     * Gets or sets the format string to apply to the value. If set, the other value formatting properties on this column are ignored.
    */
    formatString?: string;
    /**
     * Gets or sets the format string to use when editing dates.
    */
    editorFormatString?: string;
    formatSpecifiers?: any[];
    /**
     * Gets or sets the INTL DateTimeFormat object to use for formatting the date values.
    */
    formatOverride?: any;
    /**
     * Gets or sets the ShowTodayButton property to detirmine if the today button is shown
    */
    showTodayButton?: boolean | string;
    /**
     * Gets or sets the editor type used for editing cells in this column.
    */
    editorType?: EditorType | string;
    /**
     * Gets or sets the ComboBox data source.
    */
    editorDataSource?: any;
    /**
     * Gets or sets the ComboBox text field.
    */
    editorTextField?: string;
    /**
     * Gets or sets the ComboBox value field.
    */
    editorValueField?: string;
}
