import { ExporterOptionsBase as ExporterOptionsBase_internal } from "./ExporterOptionsBase";
import { ContentChildrenManager } from "igniteui-react-core";
export declare abstract class IgrExporterOptionsBase {
    protected createImplementation(): ExporterOptionsBase_internal;
    protected _implementation: any;
    protected mounted: boolean;
    /**
     * @hidden
     */
    get i(): ExporterOptionsBase_internal; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgrExporterOptionsBase;
    protected onImplementationCreated(): void;
    protected _contentChildrenManager: ContentChildrenManager;
    constructor();
    protected _provideImplementation(i: any): void;
    /**
     * Specifies whether hidden columns should be exported.
     * ```typescript
     * let ignoreColumnsVisibility = this.exportOptions.ignoreColumnsVisibility;
     * this.exportOptions.ignoreColumnsVisibility = true;
     * ```
     * @memberof IgxExporterOptionsBase
    */
    get ignoreColumnsVisibility(): boolean;
    set ignoreColumnsVisibility(v: boolean);
    /**
     * Specifies whether filtered out rows should be exported.
     * ```typescript
     * let ignoreFiltering = this.exportOptions.ignoreFiltering;
     * this.exportOptions.ignoreFiltering = true;
     * ```
     * @memberof IgxExporterOptionsBase
    */
    get ignoreFiltering(): boolean;
    set ignoreFiltering(v: boolean);
    /**
     * Specifies if the exporter should ignore the current column order in the IgxGrid.
     * ```typescript
     * let ignoreColumnsOrder = this.exportOptions.ignoreColumnsOrder;
     * this.exportOptions.ignoreColumnsOrder = true;
     * ```
     * @memberof IgxExporterOptionsBase
    */
    get ignoreColumnsOrder(): boolean;
    set ignoreColumnsOrder(v: boolean);
    /**
     * Specifies whether the exported data should be sorted as in the provided IgxGrid.
     * When you export grouped data, setting ignoreSorting to true will cause
     * the grouping to fail because it relies on the sorting of the records.
     * ```typescript
     * let ignoreSorting = this.exportOptions.ignoreSorting;
     * this.exportOptions.ignoreSorting = true;
     * ```
     * @memberof IgxExporterOptionsBase
    */
    get ignoreSorting(): boolean;
    set ignoreSorting(v: boolean);
    /**
     * Specifies whether the exported data should be grouped as in the provided IgxGrid.
     * ```typescript
     * let ignoreGrouping = this.exportOptions.ignoreGrouping;
     * this.exportOptions.ignoreGrouping = true;
     * ```
     * @memberof IgxExporterOptionsBase
    */
    get ignoreGrouping(): boolean;
    set ignoreGrouping(v: boolean);
    /**
     * Specifies whether the exported data should include multi column headers as in the provided IgxGrid.
     * ```typescript
     * let ignoreMultiColumnHeaders = this.exportOptions.ignoreMultiColumnHeaders;
     * this.exportOptions.ignoreMultiColumnHeaders = true;
     * ```
     * @memberof IgxExporterOptionsBase
    */
    get ignoreMultiColumnHeaders(): boolean;
    set ignoreMultiColumnHeaders(v: boolean);
    /**
     * Specifies whether the exported data should include column summaries.
     * ```typescript
     * let exportSummaries = this.exportOptions.exportSummaries;
     * this.exportOptions.exportSummaries = true;
     * ```
     * @memberof IgxExporterOptionsBase
    */
    get exportSummaries(): boolean;
    set exportSummaries(v: boolean);
    /**
     * Specifies whether the exported data should have frozen headers.
     * ```typescript
     * let freezeHeaders = this.exportOptions.freezeHeaders;
     * this.exportOptions.freezeHeaders = true;
     * ```
     * @memberof IgxExporterOptionsBase
    */
    get freezeHeaders(): boolean;
    set freezeHeaders(v: boolean);
    /**
     * Specifies whether the headers should be exported if there is no data.
     * ```typescript
     * let alwaysExportHeaders = this.exportOptions.alwaysExportHeaders;
     * this.exportOptions.alwaysExportHeaders = false;
     * ```
     * @memberof IgxExporterOptionsBase
    */
    get alwaysExportHeaders(): boolean;
    set alwaysExportHeaders(v: boolean);
    /**
     * Gets the file name which will be used for the exporting operation.
     * ```typescript
     * let fileName = this.exportOptions.fileName;
     * ```
     * @memberof IgxExporterOptionsBase
    */
    get fileName(): string;
    set fileName(v: string);
    findByName(name: string): any;
    setNativeElement(element: any): void;
}
