import { FilteringLogic } from "./FilteringLogic";
import { FilteringExpressionsTreeType } from "./FilteringExpressionsTreeType";
import { IgrFilteringExpressionsTreeOrFilteringExpression } from "./igr-filtering-expressions-tree-or-filtering-expression";
import { FilteringExpressionsTree as FilteringExpressionsTree_internal } from "./FilteringExpressionsTree";
import { ContentChildrenManager } from "igniteui-react-core";
export declare class IgrFilteringExpressionsTree {
    protected createImplementation(): FilteringExpressionsTree_internal;
    protected _implementation: any;
    protected mounted: boolean;
    /**
     * @hidden
     */
    get i(): FilteringExpressionsTree_internal;
    protected onImplementationCreated(): void;
    protected _contentChildrenManager: ContentChildrenManager;
    constructor();
    protected _provideImplementation(i: any): void;
    /**
     * Sets/gets the filtering operands.
     * ```typescript
     * const gridExpressionsTree = new FilteringExpressionsTree(FilteringLogic.And);
     * const expression = [
     * {
     * condition: IgxStringFilteringOperand.instance().condition('contains'),
     * fieldName: 'Column Field',
     * searchVal: 'Value',
     * ignoreCase: false
     * }];
     * gridExpressionsTree.filteringOperands.push(expression);
     * this.grid.filteringExpressionsTree = gridExpressionsTree;
     * ```
     * ```typescript
     * let filteringOperands = gridExpressionsTree.filteringOperands;
     * ```
     * @memberof FilteringExpressionsTree
    */
    get filteringOperands(): IgrFilteringExpressionsTreeOrFilteringExpression[];
    set filteringOperands(v: IgrFilteringExpressionsTreeOrFilteringExpression[]);
    /**
     * Sets/gets the operator.
     * ```typescript
     * gridExpressionsTree.operator = FilteringLogic.And;
     * ```
     * ```typescript
     * let operator = gridExpressionsTree.operator;
     * ```
     * @memberof FilteringExpressionsTree
    */
    get operator(): FilteringLogic;
    set operator(v: FilteringLogic);
    /**
     * Sets/gets the field name of the column where the filtering expression is placed.
     * ```typescript
     * gridExpressionTree.fieldName = 'Column Field';
     * ```
     * ```typescript
     * let columnField = expressionTree.fieldName;
     * ```
     * @memberof FilteringExpressionsTree
    */
    get fieldName(): string;
    set fieldName(v: string);
    /**
     * Sets/gets the type of the filtering expressions tree.
     * ```typescript
     * gridExpressionTree.type = FilteringExpressionsTree.Advanced;
     * ```
     * ```typescript
     * let type = expressionTree.type;
     * ```
     * @memberof FilteringExpressionsTree
    */
    get type(): FilteringExpressionsTreeType;
    set type(v: FilteringExpressionsTreeType);
    findByName(name: string): any;
    setNativeElement(element: any): void;
    /**
     * Checks if filtering expressions tree is empty.
     * expressionTree filtering expressions tree.
    
    * @param expressionTree  * filtering expressions tree.
    */
    empty(expressionTree: IgrFilteringExpressionsTree): boolean;
    /**
     * Returns the filtering expression for a column with the provided fieldName.
     * ```typescript
     * let filteringExpression = gridExpressionTree.find('Column Field');
     * ```
     * @memberof FilteringExpressionsTree
    
    */
    find(fieldName: string): IgrFilteringExpressionsTreeOrFilteringExpression;
    /**
     * Returns the index of the filtering expression for a column with the provided fieldName.
     * ```typescript
     * let filteringExpressionIndex = gridExpressionTree.findIndex('Column Field');
     * ```
     * @memberof FilteringExpressionsTree
    
    */
    findIndex(fieldName: string): number;
}
