import * as React from 'react';
import { IgrGridBaseDirective } from "./igr-grid-base-directive";
import { IgrGridToolbarContentCollection } from "./igr-grid-toolbar-content-collection";
import { IgrDisplayDensityBaseElement, IIgrDisplayDensityBaseElementProps } from "./igr-display-density-base-element";
import { GridToolbar } from "./GridToolbar";
import { IgrGridToolbarContent } from "./igr-grid-toolbar-content";
/**
 * Provides a context-aware container component for UI operations for the grid components.
 * @igxModule IgxGridToolbarModule
 * @igxParent IgxGridComponent, IgxTreeGridComponent, IgxHierarchicalGridComponent, IgxPivotGridComponent
*/
export declare class IgrGridToolbar extends IgrDisplayDensityBaseElement<IIgrGridToolbarProps> {
    protected createImplementation(): GridToolbar;
    /**
                                 * @hidden
                                 */
    get i(): GridToolbar;
    protected onImplementationCreated(): void;
    protected _initializeAdapters(): void;
    protected _updateAdapters(): void;
    constructor(props: IIgrGridToolbarProps);
    componentDidMount(): void;
    render(): React.DetailedReactHTMLElement<any, HTMLElement>;
    protected _elRef: HTMLElement;
    protected _getMainRef(ref: any): void;
    /**
     * When enabled, shows the indeterminate progress bar.
     * @remarks
     * By default this will be toggled, when the default exporter component is present
     * and an exporting is in progress.
    */
    get showProgress(): boolean;
    set showProgress(v: boolean);
    /**
     * Gets/sets the grid component for the toolbar component.
     * @remarks
     * Usually you should not set this property in the context of the default grid/tree grid.
     * The only grids that demands this to be set are the hierarchical child grids. For additional
     * information check the toolbar topic.
    */
    get grid(): IgrGridBaseDirective;
    set grid(v: IgrGridBaseDirective);
    get name(): string;
    set name(v: string);
    private _tools;
    private _actualTools;
    get actualTools(): IgrGridToolbarContent[];
    private _contentTools;
    get contentTools(): IgrGridToolbarContent[];
    private _toolsAdapter;
    get tools(): IgrGridToolbarContentCollection;
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
}
export interface IIgrGridToolbarProps extends IIgrDisplayDensityBaseElementProps {
    /**
     * When enabled, shows the indeterminate progress bar.
     * @remarks
     * By default this will be toggled, when the default exporter component is present
     * and an exporting is in progress.
    */
    showProgress?: boolean | string;
    /**
     * Gets/sets the grid component for the toolbar component.
     * @remarks
     * Usually you should not set this property in the context of the default grid/tree grid.
     * The only grids that demands this to be set are the hierarchical child grids. For additional
     * information check the toolbar topic.
    */
    grid?: IgrGridBaseDirective;
    name?: string;
}
