import { SortIndicatorStyle } from "./SortIndicatorStyle";
import { IgrDefinitionBase, IIgrDefinitionBaseProps } from "./igr-definition-base";
import { Header } from "./Header";
/**
 * Represents a base class used to configure the appearance of the column header cells.
*/
export declare abstract class IgrHeader<P extends IIgrHeaderProps = IIgrHeaderProps> extends IgrDefinitionBase<P> {
    /**
                                 * @hidden
                                 */
    get i(): Header;
    constructor(props: P);
    /**
     * Gets or sets the color to use for the sort indicator icon
    */
    get sortIndicatorColor(): string;
    set sortIndicatorColor(v: string);
    /**
     * Gets the actual background color that is used for the cells when they are selected
    */
    get actualSortIndicatorColor(): string;
    set actualSortIndicatorColor(v: string);
    get sortIndicatorStyle(): SortIndicatorStyle;
    set sortIndicatorStyle(v: SortIndicatorStyle);
    get actualSortIndicatorStyle(): SortIndicatorStyle;
    set actualSortIndicatorStyle(v: SortIndicatorStyle);
    /**
     * Gets or sets the amount of left padding to use for the cell content.
    */
    get paddingLeft(): number;
    set paddingLeft(v: number);
    /**
     * Gets or sets the amount of top padding to use for the cell content.
    */
    get paddingTop(): number;
    set paddingTop(v: number);
    /**
     * Gets or sets the amount of right padding to use for the cell content.
    */
    get paddingRight(): number;
    set paddingRight(v: number);
    /**
     * Gets or sets the amount of bottom padding to use for the cell content.
    */
    get paddingBottom(): number;
    set paddingBottom(v: number);
}
export interface IIgrHeaderProps extends IIgrDefinitionBaseProps {
    /**
     * Gets or sets the color to use for the sort indicator icon
    */
    sortIndicatorColor?: string;
    /**
     * Gets the actual background color that is used for the cells when they are selected
    */
    actualSortIndicatorColor?: string;
    sortIndicatorStyle?: SortIndicatorStyle | string;
    actualSortIndicatorStyle?: SortIndicatorStyle | string;
    /**
     * Gets or sets the amount of left padding to use for the cell content.
    */
    paddingLeft?: number | string;
    /**
     * Gets or sets the amount of top padding to use for the cell content.
    */
    paddingTop?: number | string;
    /**
     * Gets or sets the amount of right padding to use for the cell content.
    */
    paddingRight?: number | string;
    /**
     * Gets or sets the amount of bottom padding to use for the cell content.
    */
    paddingBottom?: number | string;
}
