import { ImageStretchOptions } from "./ImageStretchOptions";
import { EditorType } from "./EditorType";
import { IgrDataGridColumn, IIgrDataGridColumnProps } from "./igr-data-grid-column";
import { ImageColumn } from "./ImageColumn";
/**
 * Represents an Image grid column, used to allow the developer to display an image in a cell.
*/
export declare class IgrImageColumn extends IgrDataGridColumn<IIgrImageColumnProps> {
    protected createImplementation(): ImageColumn;
    /**
                                 * @hidden
                                 */
    get i(): ImageColumn;
    constructor(props: IIgrImageColumnProps);
    /**
     * Gets or sets the stretch option to use when rendering images
    */
    get imageStretchOption(): ImageStretchOptions;
    set imageStretchOption(v: ImageStretchOptions);
    /**
     * Gets or sets the editor type used for editing cells in this column.
    */
    get editorType(): EditorType;
    set editorType(v: EditorType);
    /**
     * Gets or sets the ComboBox data source.
    */
    get editorDataSource(): any;
    set editorDataSource(v: any);
    /**
     * Gets or sets the ComboBox text field.
    */
    get editorTextField(): string;
    set editorTextField(v: string);
    /**
     * Gets or sets the ComboBox value field.
    */
    get editorValueField(): string;
    set editorValueField(v: string);
}
export interface IIgrImageColumnProps extends IIgrDataGridColumnProps {
    /**
     * Gets or sets the stretch option to use when rendering images
    */
    imageStretchOption?: ImageStretchOptions | string;
    /**
     * Gets or sets the editor type used for editing cells in this column.
    */
    editorType?: EditorType | string;
    /**
     * Gets or sets the ComboBox data source.
    */
    editorDataSource?: any;
    /**
     * Gets or sets the ComboBox text field.
    */
    editorTextField?: string;
    /**
     * Gets or sets the ComboBox value field.
    */
    editorValueField?: string;
}
