import { EditorType } from "./EditorType";
import { IgrDataGridColumn, IIgrDataGridColumnProps } from "./igr-data-grid-column";
import { NumericColumn } from "./NumericColumn";
/**
 * Represents a Numeric grid column, used to allow the developer to display a formatted number in a cell.
*/
export declare class IgrNumericColumn extends IgrDataGridColumn<IIgrNumericColumnProps> {
    protected createImplementation(): NumericColumn;
    /**
                                 * @hidden
                                 */
    get i(): NumericColumn;
    constructor(props: IIgrNumericColumnProps);
    /**
     * Gets or sets the string to prefix a negative value. If FormatString is specificied this value is ignored.
    */
    get negativePrefix(): string;
    set negativePrefix(v: string);
    /**
     * Gets or sets the string to prefix a positive value. If FormatString is specificied this value is ignored.
    */
    get positivePrefix(): string;
    set positivePrefix(v: string);
    /**
     * Gets or sets the string to suffix a negative value. If FormatString is specificied this value is ignored.
    */
    get negativeSuffix(): string;
    set negativeSuffix(v: string);
    /**
     * Gets or sets the string to suffix a positive value. If FormatString is specificied this value is ignored.
    */
    get positiveSuffix(): string;
    set positiveSuffix(v: string);
    /**
     * Gets or sets the maximum fraction digits. If FormatString is specificied this value is ignored.
    */
    get maxFractionDigits(): number;
    set maxFractionDigits(v: number);
    /**
     * Gets or sets the minimum fraction digits. If FormatString is specificied this value is ignored.
    */
    get minFractionDigits(): number;
    set minFractionDigits(v: number);
    /**
     * Gets or sets the minimum integer digits. If FormatString is specificied this value is ignored.
    */
    get minIntegerDigits(): number;
    set minIntegerDigits(v: number);
    /**
     * Gets or sets whether to show a grouping separator. If FormatString is specificied this value is ignored.
    */
    get showGroupingSeparator(): boolean;
    set showGroupingSeparator(v: boolean);
    /**
     * Gets or sets the format string to apply to the value. If set, the other value formatting properties on this column are ignored.
    */
    get formatString(): string;
    set formatString(v: string);
    get formatSpecifiers(): any[];
    set formatSpecifiers(v: any[]);
    /**
     * Gets or sets the INTL NumericFormat object to use for formatting the date values.
    */
    get formatOverride(): any;
    set formatOverride(v: any);
    /**
     * Gets or sets the editor type used for editing cells in this column.
    */
    get editorType(): EditorType;
    set editorType(v: EditorType);
    /**
     * Gets or sets the ComboBox data source.
    */
    get editorDataSource(): any;
    set editorDataSource(v: any);
    /**
     * Gets or sets the ComboBox text field.
    */
    get editorTextField(): string;
    set editorTextField(v: string);
    /**
     * Gets or sets the ComboBox value field.
    */
    get editorValueField(): string;
    set editorValueField(v: string);
    findByName(name: string): any;
}
export interface IIgrNumericColumnProps extends IIgrDataGridColumnProps {
    /**
     * Gets or sets the string to prefix a negative value. If FormatString is specificied this value is ignored.
    */
    negativePrefix?: string;
    /**
     * Gets or sets the string to prefix a positive value. If FormatString is specificied this value is ignored.
    */
    positivePrefix?: string;
    /**
     * Gets or sets the string to suffix a negative value. If FormatString is specificied this value is ignored.
    */
    negativeSuffix?: string;
    /**
     * Gets or sets the string to suffix a positive value. If FormatString is specificied this value is ignored.
    */
    positiveSuffix?: string;
    /**
     * Gets or sets the maximum fraction digits. If FormatString is specificied this value is ignored.
    */
    maxFractionDigits?: number | string;
    /**
     * Gets or sets the minimum fraction digits. If FormatString is specificied this value is ignored.
    */
    minFractionDigits?: number | string;
    /**
     * Gets or sets the minimum integer digits. If FormatString is specificied this value is ignored.
    */
    minIntegerDigits?: number | string;
    /**
     * Gets or sets whether to show a grouping separator. If FormatString is specificied this value is ignored.
    */
    showGroupingSeparator?: boolean | string;
    /**
     * Gets or sets the format string to apply to the value. If set, the other value formatting properties on this column are ignored.
    */
    formatString?: string;
    formatSpecifiers?: any[];
    /**
     * Gets or sets the INTL NumericFormat object to use for formatting the date values.
    */
    formatOverride?: any;
    /**
     * Gets or sets the editor type used for editing cells in this column.
    */
    editorType?: EditorType | string;
    /**
     * Gets or sets the ComboBox data source.
    */
    editorDataSource?: any;
    /**
     * Gets or sets the ComboBox text field.
    */
    editorTextField?: string;
    /**
     * Gets or sets the ComboBox value field.
    */
    editorValueField?: string;
}
