import * as React from 'react';
import { IgrOverlaySettings } from "./igr-overlay-settings";
import { IgrPaginatorResourceStrings } from "./igr-paginator-resource-strings";
import { IgrNumberEventArgs } from "igniteui-react";
import { IgrPageCancellableEventArgs } from "./igr-page-cancellable-event-args";
import { IgrPageEventArgs } from "./igr-page-event-args";
import { IgrDisplayDensityBaseElement, IIgrDisplayDensityBaseElementProps } from "./igr-display-density-base-element";
import { Paginator } from "./Paginator";
/**
 * Paginator component description
 * @igxParent IgxGridComponent, IgxTreeGridComponent, IgxHierarchicalGridComponent, IgxPivotGridComponent, *
*/
export declare class IgrPaginator extends IgrDisplayDensityBaseElement<IIgrPaginatorProps> {
    protected createImplementation(): Paginator;
    /**
                                 * @hidden
                                 */
    get i(): Paginator;
    constructor(props: IIgrPaginatorProps);
    componentDidMount(): void;
    render(): React.DetailedReactHTMLElement<any, HTMLElement>;
    protected _elRef: HTMLElement;
    protected _getMainRef(ref: any): void;
    /**
     * Total pages calculated from totalRecords and perPage
    */
    get totalPages(): number;
    set totalPages(v: number);
    /**
     * An @Input property, sets current page of the `IgxPaginatorComponent`.
     * The default is 0.
     * ```typescript
     * let page = this.paginator.page;
     * ```
     * @memberof IgxPaginatorComponent
    */
    get page(): number;
    set page(v: number);
    /**
     * An @Input property, sets number of visible items per page in the `IgxPaginatorComponent`.
     * The default is 15.
     * ```typescript
     * let itemsPerPage = this.paginator.perPage;
     * ```
     * @memberof IgxPaginatorComponent
    */
    get perPage(): number;
    set perPage(v: number);
    /**
     * An @Input property that sets the total records.
     * ```typescript
     * let totalRecords = this.paginator.totalRecords;
     * ```
     * @memberof IgxPaginatorComponent
    */
    get totalRecords(): number;
    set totalRecords(v: number);
    /**
     * An @Input property that sets custom options in the select of the paginator
     * ```typescript
     * let options = this.paginator.selectOptions;
     * ```
     * @memberof IgxPaginatorComponent
    */
    get selectOptions(): number[];
    set selectOptions(v: number[]);
    get overlaySettings(): IgrOverlaySettings;
    set overlaySettings(v: IgrOverlaySettings);
    /**
     * An accessor that sets the resource strings.
     * By default it uses EN resources.
    */
    get resourceStrings(): IgrPaginatorResourceStrings;
    set resourceStrings(v: IgrPaginatorResourceStrings);
    get name(): string;
    set name(v: string);
    findByName(name: string): any;
    /**
     * Goes to the next page of the `IgxPaginatorComponent`, if the paginator is not already at the last page.
     * ```typescript
     * this.paginator.nextPage();
     * ```
     * @memberof IgxPaginatorComponent
    
    */
    nextPage(): void;
    /**
     * Goes to the previous page of the `IgxPaginatorComponent`, if the paginator is not already at the first page.
     * ```typescript
     * this.paginator.previousPage();
     * ```
     * @memberof IgxPaginatorComponent
    
    */
    previousPage(): void;
    /**
     * Goes to the desired page index.
     * ```typescript
     * this.paginator.paginate(1);
     * ```
     * val
     * @memberof IgxPaginatorComponent
    
    * @param   * val
    */
    paginate(val: number): void;
    private _perPageChange;
    private _perPageChange_wrapped;
    get perPageChange(): (s: IgrPaginator, e: IgrNumberEventArgs) => void;
    set perPageChange(ev: (s: IgrPaginator, e: IgrNumberEventArgs) => void);
    private _pageChange;
    private _pageChange_wrapped;
    get pageChange(): (s: IgrPaginator, e: IgrNumberEventArgs) => void;
    set pageChange(ev: (s: IgrPaginator, e: IgrNumberEventArgs) => void);
    private _paging;
    private _paging_wrapped;
    get paging(): (s: IgrPaginator, e: IgrPageCancellableEventArgs) => void;
    set paging(ev: (s: IgrPaginator, e: IgrPageCancellableEventArgs) => void);
    private _pagingDone;
    private _pagingDone_wrapped;
    get pagingDone(): (s: IgrPaginator, e: IgrPageEventArgs) => void;
    set pagingDone(ev: (s: IgrPaginator, e: IgrPageEventArgs) => void);
}
export interface IIgrPaginatorProps extends IIgrDisplayDensityBaseElementProps {
    /**
     * Total pages calculated from totalRecords and perPage
    */
    totalPages?: number | string;
    /**
     * An @Input property, sets current page of the `IgxPaginatorComponent`.
     * The default is 0.
     * ```typescript
     * let page = this.paginator.page;
     * ```
     * @memberof IgxPaginatorComponent
    */
    page?: number | string;
    /**
     * An @Input property, sets number of visible items per page in the `IgxPaginatorComponent`.
     * The default is 15.
     * ```typescript
     * let itemsPerPage = this.paginator.perPage;
     * ```
     * @memberof IgxPaginatorComponent
    */
    perPage?: number | string;
    /**
     * An @Input property that sets the total records.
     * ```typescript
     * let totalRecords = this.paginator.totalRecords;
     * ```
     * @memberof IgxPaginatorComponent
    */
    totalRecords?: number | string;
    /**
     * An @Input property that sets custom options in the select of the paginator
     * ```typescript
     * let options = this.paginator.selectOptions;
     * ```
     * @memberof IgxPaginatorComponent
    */
    selectOptions?: number[];
    overlaySettings?: IgrOverlaySettings;
    /**
     * An accessor that sets the resource strings.
     * By default it uses EN resources.
    */
    resourceStrings?: IgrPaginatorResourceStrings;
    name?: string;
    perPageChange?: (s: IgrPaginator, e: IgrNumberEventArgs) => void;
    pageChange?: (s: IgrPaginator, e: IgrNumberEventArgs) => void;
    paging?: (s: IgrPaginator, e: IgrPageCancellableEventArgs) => void;
    pagingDone?: (s: IgrPaginator, e: IgrPageEventArgs) => void;
}
