import { IgrColumnPropertySetter } from "./igr-column-property-setter";
import { IgrColumnExchanger } from "./igr-column-exchanger";
import { ResponsivePhase as ResponsivePhase_internal } from "./ResponsivePhase";
import { ContentChildrenManager } from "igniteui-react-core";
/**
 * Describes one phase of a responsive state to apply to the grid.
*/
export declare class IgrResponsivePhase {
    protected createImplementation(): ResponsivePhase_internal;
    protected _implementation: any;
    protected mounted: boolean;
    /**
     * @hidden
     */
    get i(): ResponsivePhase_internal;
    protected onImplementationCreated(): void;
    protected _contentChildrenManager: ContentChildrenManager;
    constructor();
    protected _provideImplementation(i: any): void;
    /**
     * The name of this responsive phase
    */
    get name(): string;
    set name(v: string);
    /**
     * The amount of time to delay the responsive phase from starting, in milliseconds
    */
    get delayMilliseconds(): number;
    set delayMilliseconds(v: number);
    findByName(name: string): any;
    /**
     * Adds a column property setter to the phase.
    
    * @param setter  * The setter to add.
    */
    addColumnPropertySetter(setter: IgrColumnPropertySetter): IgrResponsivePhase;
    /**
     * Adds a column property setter to the phase, and returns it.
    
    */
    columnPropertySetter(): IgrColumnPropertySetter;
    /**
     * Adds a column exchanger the the phase.
    
    * @param exchanger  * The exchanger to add.
    */
    addColumnExchanger(exchanger: IgrColumnExchanger): IgrResponsivePhase;
    /**
     * Adds a column exchanger to the phase and returns it.
    
    */
    columnExchanger(): IgrResponsivePhase;
}
