import { IgrResponsiveStateEnteringEventArgs } from "./igr-responsive-state-entering-event-args";
import { IgrResponsiveStateEnteredEventArgs } from "./igr-responsive-state-entered-event-args";
import { IgrResponsiveStateExitedEventArgs } from "./igr-responsive-state-exited-event-args";
import { IgrResponsivePhase } from "./igr-responsive-phase";
import { ResponsiveState as ResponsiveState_internal } from "./ResponsiveState";
import { ContentChildrenManager } from "igniteui-react-core";
/**
 * Describes a state that the grid can enter based on a set of responsive conditions.
*/
export declare class IgrResponsiveState {
    protected createImplementation(): ResponsiveState_internal;
    protected _implementation: any;
    protected mounted: boolean;
    /**
     * @hidden
     */
    get i(): ResponsiveState_internal;
    protected onImplementationCreated(): void;
    protected _contentChildrenManager: ContentChildrenManager;
    constructor();
    protected _provideImplementation(i: any): void;
    /**
     * The name of the responsive state
    */
    get name(): string;
    set name(v: string);
    /**
     * Gets or sets the minimum width for which this state is active.
    */
    get minimumWidth(): number;
    set minimumWidth(v: number);
    /**
     * Gets or sets the maximum width for which this state is active.
    */
    get maximumWidth(): number;
    set maximumWidth(v: number);
    /**
     * Configures this responsive state to only be manually actived
    */
    get isManualState(): boolean;
    set isManualState(v: boolean);
    findByName(name: string): any;
    /**
     * Adds a responsive phase to the state.
    
    * @param phase  * The phase to add.
    */
    addResponsivePhase(phase: IgrResponsivePhase): IgrResponsiveState;
    /**
     * Adds a responsive phase to the state and returns it.
    
    */
    responsivePhase(): IgrResponsivePhase;
    private _stateEntering;
    private _stateEntering_wrapped;
    /**
     * Called when a state is being entered.
    */
    get stateEntering(): (s: IgrResponsiveState, e: IgrResponsiveStateEnteringEventArgs) => void;
    set stateEntering(ev: (s: IgrResponsiveState, e: IgrResponsiveStateEnteringEventArgs) => void);
    private _stateEntered;
    private _stateEntered_wrapped;
    /**
     * Called when a state is entered.
    */
    get stateEntered(): (s: IgrResponsiveState, e: IgrResponsiveStateEnteredEventArgs) => void;
    set stateEntered(ev: (s: IgrResponsiveState, e: IgrResponsiveStateEnteredEventArgs) => void);
    private _stateExited;
    private _stateExited_wrapped;
    /**
     * Called when a state is exited.
    */
    get stateExited(): (s: IgrResponsiveState, e: IgrResponsiveStateExitedEventArgs) => void;
    set stateExited(ev: (s: IgrResponsiveState, e: IgrResponsiveStateExitedEventArgs) => void);
}
